@@ -41,6 +41,7 @@ OC.L10N.register(
     "Go back" : "Gaan terug",
     "Email address" : "E-posadres",
     "Cancel" : "Kanselleer",
+    "Accounts" : "Accounts",
     "Add mail account" : "Voeg posrekening toe",
     "General" : "Algemeen",
     "Register" : "Registreer",
@@ -102,6 +103,18 @@ OC.L10N.register(
     "Date" : "Datum",
     "Tags" : "Etikette",
     "Custom" : "Eie",
+    "Message source" : "Boodskapbron",
+    "Recipient" : "Ontvanger",
+    "Priority" : "Prioriteit",
+    "Reset" : "Herstel",
+    "Client ID" : "Klant-ID",
+    "User" : "Gebruiker",
+    "Host" : "Gasheer",
+    "Port" : "Poort",
+    "Valid until" : "Geldig tot",
+    "Certificate" : "Sertifikaat",
+    "Submit" : "Dien in",
+    "Connect your mail account" : "Koppel u posrekening",
     "All" : "Alle",
     "Drafts" : "Konsepte",
     "Favorites" : "Gunstelinge",
@@ -114,6 +127,7 @@ OC.L10N.register(
     "Forwarding to %s" : "Stuur aan na %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
     "Redirect" : "Herverwys",
-    "The link leads to %s" : "Die skakel lei na %s"
+    "The link leads to %s" : "Die skakel lei na %s",
+    "Actions" : "Aksies"
 },
 "nplurals=2; plural=(n != 1);");
