@@ -166,7 +166,7 @@ OC.L10N.register(
     "Confirm" : "Bekræft",
     "Plain text" : "Klartekst",
     "Rich text" : "Formateret tekst",
-    "No messages in this mailbox" : "Ingen beskeder i denne postkasse",
+    "No messages in this folder" : "Ingen beskeder i denne mappe",
     "No messages" : "Ingen beskeder",
     "Blind copy recipients only" : "Kun blinde kopi-modtagere",
     "No subject" : "Intet emne",
@@ -174,7 +174,6 @@ OC.L10N.register(
     "Set reminder for tomorrow" : "Sæt påmindelse for i morgen",
     "Set reminder for this weekend" : "Sæt påmindelse for denne weekend",
     "Set reminder for next week" : "Sæt påmindelse for næste weekend",
-    "No trash mailbox configured" : "Der er ikke konfigureret nogen papirkurvspostkasse",
     "Could not delete message" : "Kunne ikke slette beskeden",
     "This message is unread" : "Denne besked er ulæst",
     "Unfavorite" : "U-favorit",
@@ -230,10 +229,7 @@ OC.L10N.register(
     "More options" : "Flere muligheder",
     "Remove" : "Fjern",
     "email" : "e-mail",
-    "Could not open mailbox" : "Postkassen kunne ikke åbnes",
     "Loading messages …" : "Indlæser beskeder...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksering af dine beskeder. Dette kan tage lidt længere tid for større postkasser.",
-    "Choose target mailbox" : "Vælg målpostkasse",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
     "Important info" : "Vigtig information",
@@ -267,20 +263,14 @@ OC.L10N.register(
     "Remove account" : "Fjern konto",
     "Remove {email}" : "Fjern {email}",
     "Quota" : "Kvote",
-    "Show only subscribed mailboxes" : "Vis kun postkasser der abonneres på",
-    "Add mailbox" : "Tilføj postkasse",
     "Saving" : "Gemmer",
     "Move up" : "Flyt op",
     "Move down" : "Flyt ned",
-    "Show all subscribed mailboxes" : "Vis alle postkasser der abonneres på",
-    "Show all mailboxes" : "Vis alle postkasser",
     "Collapse mailboxes" : "Skjul postkasser ",
     "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
     "Clear mailbox {name}" : "Ryd postkasse {name}",
-    "Clear mailbox" : "Ryd postkasse",
     "Mark all as read" : "Markér alle som læst",
-    "Mark all messages of this mailbox as read" : "Markér alle beskeder i denne postkasse som læst",
-    "Add submailbox" : "Tilføj underpostkasse",
+    "Mark all messages of this folder as read" : "Markér alle beskeder i denne mappe som læst",
     "Rename" : "Omdøb",
     "Clear cache" : "Ryd cache",
     "Subscribed" : "Abonneret",
@@ -289,7 +279,6 @@ OC.L10N.register(
     "New message" : "Ny besked",
     "Draft" : "Kladde",
     "Reply" : "Besvar",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
     "Error sending your message" : "Fejl ved afsendelse af din besked",
     "Retry" : "Prøv igen",
@@ -305,7 +294,6 @@ OC.L10N.register(
     "Add" : "Tilføj",
     "Show less" : "Vis mindre",
     "Clear" : "Ryd",
-    "Search in mailbox" : "Søg i postkasse",
     "Close" : "Luk",
     "Search parameters" : "Søgeparametre",
     "Body" : "Krop",
@@ -406,7 +394,21 @@ OC.L10N.register(
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
     "Continue to %s" : "Videre til %s",
+    "No messages in this mailbox" : "Ingen beskeder i denne postkasse",
+    "No trash mailbox configured" : "Der er ikke konfigureret nogen papirkurvspostkasse",
     "Draft: " : "Kladde:",
+    "Could not open mailbox" : "Postkassen kunne ikke åbnes",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksering af dine beskeder. Dette kan tage lidt længere tid for større postkasser.",
+    "Choose target mailbox" : "Vælg målpostkasse",
+    "Show only subscribed mailboxes" : "Vis kun postkasser der abonneres på",
+    "Add mailbox" : "Tilføj postkasse",
+    "Show all subscribed mailboxes" : "Vis alle postkasser der abonneres på",
+    "Show all mailboxes" : "Vis alle postkasser",
+    "Clear mailbox" : "Ryd postkasse",
+    "Mark all messages of this mailbox as read" : "Markér alle beskeder i denne postkasse som læst",
+    "Add submailbox" : "Tilføj underpostkasse",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
+    "Search in mailbox" : "Søg i postkasse",
     "New test" : "Nyeste test",
     "Actions" : "Handlinger",
     "New action" : "Ny handling"
