@@ -133,7 +133,7 @@ OC.L10N.register(
     "Confirm" : "Επιβεβαίωση",
     "Plain text" : "Απλό κείμενο",
     "Rich text" : "Εμπλουτισμένο κείμενο",
-    "No messages in this mailbox" : "Δεν υπάρχουν μηνύματα σε αυτό το γραμματοκιβώτιο.",
+    "No messages in this folder" : "Δεν έχει μηνύματα ο φάκελος",
     "No messages" : "Κανένα μήνυμα",
     "Blind copy recipients only" : "Αποδέκτες με κρυφή κοινοποίηση μόνο",
     "No subject" : "Χωρίς θέμα",
@@ -145,7 +145,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Ορίστε υπενθύμιση για αυτό το Σαββατοκύριακο",
     "Next week – {timeLocale}" : "Επόμενη εβδομάδα – {timeLocale}",
     "Set reminder for next week" : "Ορίστε υπενθύμιση για την επόμενη εβδομάδα",
-    "No trash mailbox configured" : "Δεν έχει διαμορφωθεί γραμματοκιβώτιο απορριμμάτων",
     "Could not delete message" : "Δεν ήταν δυνατή η διαγραφή του μηνύματος",
     "Could not archive message" : "Δεν ήταν δυνατή η αρχειοθέτηση του μηνύματος",
     "Unfavorite" : "Μη αγαπημένο",
@@ -199,10 +198,7 @@ OC.L10N.register(
     "Remove" : "Αφαίρεση",
     "email" : "Ηλ.Ταχυδρομείο",
     "Itinerary for {type} is not supported yet" : "Η διαδρομή για {type} δεν υποστηρίζεται ακόμα",
-    "Could not open mailbox" : "Δεν ήταν δυνατό το άνοιγμα του γραμματοκιβωτίου",
     "Loading messages …" : "Φόρτωση μηνυμάτων ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Καταλογοποίηση των μηνυμάτων σας. Αυτό μπορεί να διαρκέσει περισσότερο για μεγαλύτερα γραμματοκιβώτια.",
-    "Choose target mailbox" : "Επιλέξτε γραμματοκιβώτιο προορισμού",
     "No more submailboxes in here" : "Δεν υπάρχουν άλλα υπο-γραμματοκιβώτια εδώ",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Τα μηνύματα θα επισημανθούν αυτόματα ως σημαντικά με βάση αυτά με τα οποία επισημαίνετε ως σημαντικά. Στην αρχή ίσως χρειαστεί να τα αλλάζετε χειροκίνητα, έως ότου εκπαιδευτεί το σύστημα, αλλά θα βελτιώνεται σταδιακά με την πάροδο του χρόνου.",
     "Important info" : "Σημαντική πλροφορία",
@@ -246,23 +242,18 @@ OC.L10N.register(
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Ο λογαριασμός για {email} και προσωρινά αποθηκευμένα δεδομένα email θα καταργηθεί από το Nextcloud, αλλά όχι από τον πάροχο email σας.",
     "Remove {email}" : "Αφαίρεση {email}",
     "Quota" : "Σύνολο χώρου",
-    "Show only subscribed mailboxes" : "Εμφάνιση μόνο εγγεγραμμένων γραμματοκιβωτίων",
-    "Add mailbox" : "Προσθήκη γραμματοκιβωτίου",
+    "Show only subscribed folders" : "Εμφάνιση μόνο εγγεγραμμένων φακέλων",
     "Saving" : "Αποθήκευση",
     "Move up" : "Μετακίνηση επάνω",
     "Move down" : "Μετακίνηση Κάτω",
-    "Show all subscribed mailboxes" : "Εμφάνιση όλων των εγγεγραμμένων γραμματοκιβωτίων",
-    "Show all mailboxes" : "Εμφάνιση όλων των γραμματοκιβωτίων",
+    "Show all subscribed folders" : "Εμφάνιση όλων των εγγεγραμμένων φακέλων",
     "Collapse mailboxes" : "Σύμπτυξη γραμματοκιβωτίων",
     "_{total} message_::_{total} messages_" : ["{total} μήνυμα","{total} μηνύματα"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} μη αναγνωσμένο από {total}","{unread} μη αναγνωσμένα από {total}"],
-    "The mailbox and all messages in it will be deleted." : "Το γραμματοκιβώτιο και όλα τα μηνύματα σε αυτό θα διαγραφούν.",
-    "Delete mailbox" : "Διαγραφή γραμματοκιβωτίου",
-    "Delete mailbox {name}" : "Διαγραφή γραμματοκιβωτίου {name}",
+    "Delete folder {name}" : "Διαγραφή του φακέλου {name}",
     "An error occurred, unable to rename the mailbox." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία του γραμματοκιβωτίου.",
     "Mark all as read" : "Σημείωση όλων ως αναγνωσμένων",
-    "Mark all messages of this mailbox as read" : "Επισήμανση όλων ως αναγνωσμένων",
-    "Add submailbox" : "Προσθήκη υπο-γραμματοκιβωτίου",
+    "Mark all messages of this folder as read" : "Σημείωση όλων των μυνημάτων ως αναγνωσμένων",
     "Rename" : "Μετονομασία",
     "Clear cache" : "Εκκαθάριση προσωρινής μνήμης",
     "Clear locally cached data, in case there are issues with synchronization." : "Εκκαθαρίστε τα δεδομένα κρυφής μνήμης, σε περίπτωση που υπάρχουν προβλήματα με το συγχρονισμό.",
@@ -273,7 +264,6 @@ OC.L10N.register(
     "Edit message" : "Επεξεργασία μηνύματος",
     "Draft" : "Πρόχειρο",
     "Reply" : "Απάντηση",
-    "No sent mailbox configured. Please pick one in the account settings." : "Δεν έχει διαμορφωθεί γραμματοκιβώτιο για τα απεσταλμένα μηνύματα. Επιλέξτε ένα από τις ρυθμίσεις λογαριασμού.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Προσπαθείτε να στείλετε σε πολλούς παραλήπτες σε Προς και/ή Κοιν. Εξετάστε το ενδεχόμενο να χρησιμοποιήσετε Κρυφή κοιν. για να αποκρύψετε τις διευθύνσεις παραληπτών.",
     "Message discarded" : "Το μήνυμα απορρίφθηκε",
     "Could not discard message" : "Δεν ήταν δυνατή η απόρριψη του μηνύματος",
@@ -389,7 +379,22 @@ OC.L10N.register(
     "Redirect" : "Ανακατεύθυνση",
     "The link leads to %s" : "Αυτός ο σύνδεσμος οδηγεί στο %s",
     "Continue to %s" : "Συνέχεια στο %s",
+    "No messages in this mailbox" : "Δεν υπάρχουν μηνύματα σε αυτό το γραμματοκιβώτιο.",
+    "No trash mailbox configured" : "Δεν έχει διαμορφωθεί γραμματοκιβώτιο απορριμμάτων",
     "Draft: " : "Πρόχειρο:",
+    "Could not open mailbox" : "Δεν ήταν δυνατό το άνοιγμα του γραμματοκιβωτίου",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Καταλογοποίηση των μηνυμάτων σας. Αυτό μπορεί να διαρκέσει περισσότερο για μεγαλύτερα γραμματοκιβώτια.",
+    "Choose target mailbox" : "Επιλέξτε γραμματοκιβώτιο προορισμού",
+    "Show only subscribed mailboxes" : "Εμφάνιση μόνο εγγεγραμμένων γραμματοκιβωτίων",
+    "Add mailbox" : "Προσθήκη γραμματοκιβωτίου",
+    "Show all subscribed mailboxes" : "Εμφάνιση όλων των εγγεγραμμένων γραμματοκιβωτίων",
+    "Show all mailboxes" : "Εμφάνιση όλων των γραμματοκιβωτίων",
+    "The mailbox and all messages in it will be deleted." : "Το γραμματοκιβώτιο και όλα τα μηνύματα σε αυτό θα διαγραφούν.",
+    "Delete mailbox" : "Διαγραφή γραμματοκιβωτίου",
+    "Delete mailbox {name}" : "Διαγραφή γραμματοκιβωτίου {name}",
+    "Mark all messages of this mailbox as read" : "Επισήμανση όλων ως αναγνωσμένων",
+    "Add submailbox" : "Προσθήκη υπο-γραμματοκιβωτίου",
+    "No sent mailbox configured. Please pick one in the account settings." : "Δεν έχει διαμορφωθεί γραμματοκιβώτιο για τα απεσταλμένα μηνύματα. Επιλέξτε ένα από τις ρυθμίσεις λογαριασμού.",
     "Actions" : "Ενέργειες",
     "New action" : "Νέα ενέργεια"
 },
