@@ -77,6 +77,7 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
     "Confirm" : "Konfirmi",
     "Plain text" : "Ebenaĵa teksto",
+    "No messages in this folder" : "Neniu mesaĝo en tiu dosierujo",
     "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
     "Unfavorite" : "Malpliŝatati",
     "Favorite" : "Pliŝatati",
@@ -95,8 +96,7 @@ OC.L10N.register(
     "Decline" : "Malakcepti",
     "Remove" : "Forigi",
     "email" : "retpoŝtadreso",
-    "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
+    "Choose target folder" : "Elekti celan dosierujon",
     "Other" : "Alia",
     "Forward" : "Antaŭen",
     "Translate" : "Traduku",
@@ -117,6 +117,7 @@ OC.L10N.register(
     "Move down" : "Movi malsupren",
     "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
     "Mark all as read" : "Marki ĉion kiel legita",
+    "Mark all messages of this folder as read" : "Marki ĉiujn mesaĝojn el tiu dosierujo kiel legitaj",
     "Rename" : "Alinomi",
     "Clear cache" : "Forviŝi la kaŝmemoron",
     "New message" : "Nova mesaĝo",
@@ -192,6 +193,8 @@ OC.L10N.register(
     "The link leads to %s" : "La ligilo iras al %s",
     "Continue to %s" : "Daŭrigi al %s",
     "Draft: " : "Malneto:",
+    "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
     "Actions" : "Agoj"
 },
 "nplurals=2; plural=(n != 1);");
