@@ -173,11 +173,10 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Plain text" : "Texto sin formato",
     "Rich text" : "Texto enriquecido",
-    "No messages in this mailbox" : "No hay mensajes en esta bandeja de entrada",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "No messages" : "Sin mensajes",
     "Blind copy recipients only" : "Copias ocultas para los destinatarios solamente",
     "No subject" : "Sin asunto",
-    "No trash mailbox configured" : "No se ha configurado una bandeja de papelera",
     "Could not delete message" : "No se pudo eliminar el mensaje",
     "Could not archive message" : "No se pudo archivar el mensaje",
     "Encrypted message" : "Mensaje cifrado",
@@ -242,12 +241,9 @@ OC.L10N.register(
     "Remove" : "Eliminar",
     "email" : "correo electrónico",
     "Itinerary for {type} is not supported yet" : "El itinerario de {type} aún no es compatible",
-    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivo en la configuración de la cuenta",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivos y/o eliminar este mensaje de la carpeta actual",
-    "Could not open mailbox" : "No se pudo abrir el buzón",
     "Loading messages …" : "Cargando mensajes...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexando tus mensajes. Esto puede llevar un poco más de tiempo para buzones más grandes.",
-    "Choose target mailbox" : "Selecciona el buzón de destino",
+    "Choose target folder" : "Selecciona la carpeta de destino.",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Los mensajes se marcarán automáticamente como importantes en función de los mensajes con los que interactúes o que marques como importantes. Al principio, es posible que debas cambiar manualmente la importancia para enseñar al sistema, pero mejorará con el tiempo.",
     "Important info" : "Información importante",
@@ -297,28 +293,18 @@ OC.L10N.register(
     "Provisioned account is disabled" : "La cuenta proporcionada está desactivada",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Inicia sesión usando una contraseña para habilitar esta cuenta. La sesión actual está utilizando autenticación sin contraseña, como SSO o WebAuthn.",
     "Quota" : "Cuota",
-    "Show only subscribed mailboxes" : "Mostrar solo buzones suscritos",
-    "Add mailbox" : "Agregar buzón",
     "Saving" : "Guardando",
     "Move up" : "Mover hacia arriba",
     "Move down" : "Mover hacia abajo",
-    "Show all subscribed mailboxes" : "Mostrar todos los buzones suscritos",
-    "Show all mailboxes" : "Mostrar todos los buzones",
     "Collapse mailboxes" : "Colapsar buzones",
     "_{total} message_::_{total} messages_" : ["{total} mensaje","{total} mensajes","{total} mensajes"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} sin leer de {total}","{unread} sin leer de {total}","{unread} sin leer de {total}"],
     "All messages in mailbox will be deleted." : "Se eliminarán todos los mensajes del buzón.",
     "Clear mailbox {name}" : "Limpiar buzón {name}",
-    "Clear mailbox" : "Limpiar buzón",
-    "The mailbox and all messages in it will be deleted." : "Se eliminará el buzón y todos los mensajes en él.",
-    "Delete mailbox" : "Eliminar buzón",
-    "Delete mailbox {name}" : "Eliminar buzón {name}",
     "An error occurred, unable to rename the mailbox." : "Se produjo un error, no se puede cambiar el nombre del buzón.",
     "Mark all as read" : "Marcar todos como leídos",
-    "Mark all messages of this mailbox as read" : "Marcar todos los mensajes de este buzón como leídos",
-    "Add submailbox" : "Agregar sub-buzón",
     "Rename" : "Renombrar",
-    "Move mailbox" : "Mover buzón",
+    "Move folder" : "Mover carpeta",
     "Clear cache" : "Borrar el caché",
     "Clear locally cached data, in case there are issues with synchronization." : "Borrar datos en caché local, en caso de problemas con la sincronización.",
     "Subscribed" : "Suscrito",
@@ -331,7 +317,6 @@ OC.L10N.register(
     "Message saved" : "Mensaje guardado",
     "Failed to save message" : "Error al guardar el mensaje",
     "Failed to save draft" : "Error al guardar el borrador",
-    "No sent mailbox configured. Please pick one in the account settings." : "No hay un buzón de envío configurado. Por favor, elige uno en la configuración de la cuenta.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Estás intentando enviar a muchos destinatarios en Para y/o Cc. Considera usar Bcc para ocultar las direcciones de los destinatarios.",
     "Message discarded" : "Mensaje descartado",
     "Could not discard message" : "No se pudo descartar el mensaje",
@@ -363,7 +348,6 @@ OC.L10N.register(
     "Show less" : "Mostrar menos",
     "Show more" : "Mostrar más",
     "Clear" : "Limpiar",
-    "Search in mailbox" : "Buscar en el correo",
     "Close" : "Cerrar",
     "Search parameters" : "Parámetros de búsqueda",
     "Body" : "Cuerpo",
@@ -589,7 +573,26 @@ OC.L10N.register(
     "The link leads to %s" : "La liga lleva a %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
     "Continue to %s" : "Continuar a %s",
+    "No messages in this mailbox" : "No hay mensajes en esta bandeja de entrada",
+    "No trash mailbox configured" : "No se ha configurado una bandeja de papelera",
     "Draft: " : "Borrador: ",
+    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivo en la configuración de la cuenta",
+    "Could not open mailbox" : "No se pudo abrir el buzón",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexando tus mensajes. Esto puede llevar un poco más de tiempo para buzones más grandes.",
+    "Choose target mailbox" : "Selecciona el buzón de destino",
+    "Show only subscribed mailboxes" : "Mostrar solo buzones suscritos",
+    "Add mailbox" : "Agregar buzón",
+    "Show all subscribed mailboxes" : "Mostrar todos los buzones suscritos",
+    "Show all mailboxes" : "Mostrar todos los buzones",
+    "Clear mailbox" : "Limpiar buzón",
+    "The mailbox and all messages in it will be deleted." : "Se eliminará el buzón y todos los mensajes en él.",
+    "Delete mailbox" : "Eliminar buzón",
+    "Delete mailbox {name}" : "Eliminar buzón {name}",
+    "Mark all messages of this mailbox as read" : "Marcar todos los mensajes de este buzón como leídos",
+    "Add submailbox" : "Agregar sub-buzón",
+    "Move mailbox" : "Mover buzón",
+    "No sent mailbox configured. Please pick one in the account settings." : "No hay un buzón de envío configurado. Por favor, elige uno en la configuración de la cuenta.",
+    "Search in mailbox" : "Buscar en el correo",
     "Actions" : "Acciones",
     "New action" : "Nueva acción"
 },
