@@ -109,7 +109,7 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Plain text" : "Texto simple",
     "Rich text" : "Texto enriquecido",
-    "No messages in this mailbox" : "No hay mensajes en esta bandeja",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "No messages" : "No hay mensajes",
     "Unfavorite" : "Desmarcar como favorito",
     "Favorite" : "Favorito",
@@ -140,12 +140,12 @@ OC.L10N.register(
     "Remove account" : "Eliminar cuenta",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
+    "Show all folders" : "Mostrar todas las carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
     "Reply" : "Responder",
-    "No sent mailbox configured. Please pick one in the account settings." : "No hay configurada una bandeja de enviados. Por favor, elija una en la configuración de la cuenta.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Está intentando enviar a muchos destinatarios en Para y/o Cc. Considera usar Cco para ocultar las direcciones de los destinatarios.",
     "Error sending your message" : "Error al enviar tu mensaje",
     "Retry" : "Reintentar",
@@ -195,7 +195,9 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "Continue to %s" : "Continuar a %s",
+    "No messages in this mailbox" : "No hay mensajes en esta bandeja",
     "Draft: " : "Borrador:",
+    "No sent mailbox configured. Please pick one in the account settings." : "No hay configurada una bandeja de enviados. Por favor, elija una en la configuración de la cuenta.",
     "Actions" : "Acciones"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
