@@ -98,7 +98,6 @@ OC.L10N.register(
     "Sieve script editor" : "Editor de scripts Sieve",
     "Mail server" : "Servidor de correo",
     "Sieve server" : "Servidor Sieve",
-    "Mailbox search" : "Búsqueda en el buzón de correo",
     "Update alias" : "Actualizar alias",
     "Rename alias" : "Renombrar alias",
     "Show update alias form" : "Mostrar formulario de actualización de alias",
@@ -228,7 +227,7 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "La etiqueta se eliminará de todos los mensajes.",
     "Plain text" : "Texto plano",
     "Rich text" : "Texto enriquecido",
-    "No messages in this mailbox" : "No hay mensajes en este buzón de correo",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "No messages" : "Sin mensajes",
     "Blind copy recipients only" : "Solo destinatarios de copia oculta",
     "No subject" : "Sin asunto",
@@ -236,7 +235,6 @@ OC.L10N.register(
     "Set reminder for tomorrow" : "Configurar recordatorio para mañana",
     "Set reminder for this weekend" : "Configurar recordatorio para este fin de semana",
     "Set reminder for next week" : "Configurar recordatorio para la próxima semana",
-    "No trash mailbox configured" : "No se ha configurado un buzón de papelera",
     "Could not delete message" : "No se pudo eliminar el mensaje",
     "Could not archive message" : "No se pudo archivar el mensaje",
     "Thread was snoozed" : "El hilo ha sido pausado",
@@ -301,12 +299,9 @@ OC.L10N.register(
     "Add internal address" : "Agregar dirección interna",
     "Add internal email or domain" : "Agregar dirección de correo interna o dominio",
     "Itinerary for {type} is not supported yet" : "El itinerario para {type} aún no es soportado",
-    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivado en las configuraciones de la cuenta",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivado y/o eliminar este mensaje de la carpeta actual",
-    "Could not open mailbox" : "No se pudo abrir el buzón",
     "Loading messages …" : "Cargando mensajes...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indizando tus mensajes. Esto puede tardar un poco para buzones grandes.",
-    "Choose target mailbox" : "Escoger buzón de destino",
+    "Choose target folder" : "Elegir carpeta destino",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
     "Follow up" : "Seguimiento",
     "Follow up info" : "Información de seguimiento",
@@ -329,9 +324,11 @@ OC.L10N.register(
     "Saving" : "Guardando",
     "Move up" : "Mover arriba",
     "Move down" : "Mover abajo",
-    "Clear mailbox" : "Vaciar buzón",
+    "Show all folders" : "Mostrar todas las carpetas",
+    "Delete folder" : "Eliminar carpeta",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
+    "Move folder" : "Mover carpeta",
     "Clear cache" : "Borrar el caché",
     "Subscribed" : "Suscrito",
     "New message" : "Mensaje nuevo",
@@ -395,7 +392,15 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "Continue to %s" : "Continuar a %s",
+    "Mailbox search" : "Búsqueda en el buzón de correo",
+    "No messages in this mailbox" : "No hay mensajes en este buzón de correo",
+    "No trash mailbox configured" : "No se ha configurado un buzón de papelera",
     "Draft: " : "Borrador:",
+    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivado en las configuraciones de la cuenta",
+    "Could not open mailbox" : "No se pudo abrir el buzón",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indizando tus mensajes. Esto puede tardar un poco para buzones grandes.",
+    "Choose target mailbox" : "Escoger buzón de destino",
+    "Clear mailbox" : "Vaciar buzón",
     "Actions" : "Acciones"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
