@@ -28,6 +28,7 @@ OC.L10N.register(
     "Signature" : "Firma",
     "Go back" : "Regresar",
     "Cancel" : "Cancelar",
+    "Accounts" : "Accounts",
     "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
@@ -80,6 +81,7 @@ OC.L10N.register(
     "Remove account" : "Eliminar cuenta",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
+    "Show all folders" : "Mostrar todas las carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
     "Clear cache" : "Borrar el caché",
