@@ -67,6 +67,7 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "Remove" : "Eliminar",
     "email" : "correo electrónico",
+    "Choose target folder" : "Seleccionar carpeta destino",
     "Other" : "Otro",
     "Forward" : "Adelante",
     "Translate" : "Traducir",
@@ -81,6 +82,7 @@ OC.L10N.register(
     "Remove account" : "Eliminar cuenta",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
+    "Show all folders" : "Mostrar todas las carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
