@@ -101,7 +101,6 @@ OC.L10N.register(
     "Sieve script editor" : "Sieve skriptikoostaja",
     "Mail server" : "E-posti server",
     "Sieve server" : "Sieve server",
-    "Mailbox search" : "Postkasti otsing",
     "Update alias" : "Uuenda aliast",
     "Rename alias" : "Muuda aliast",
     "Show update alias form" : "Näita uuendatud aliast",
@@ -236,7 +235,6 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "See silt saab olema eemaldatud kõikide kirjade juurest.",
     "Plain text" : "Vormindamata tekst",
     "Rich text" : "Vormindatud tekst",
-    "No messages in this mailbox" : "Selles postkastis pole kirju",
     "No messages" : "Kirju pole",
     "Blind copy recipients only" : "Vaid pimekoopia saajad",
     "No subject" : "Teemat pole",
@@ -249,7 +247,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
     "Next week – {timeLocale}" : "Järgmisel nädalal – {timeLocale}",
     "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
-    "No trash mailbox configured" : "Prügikasti kaust on määramata",
     "Could not delete message" : "Kirja kustutamine ei õnnestunud",
     "Could not archive message" : "Kirja arhiveerimine ei õnnestunud",
     "Thread was snoozed" : "Jutulõnga kuvamine on edasi lükatd",
@@ -332,14 +329,11 @@ OC.L10N.register(
     "Add internal address" : "Lisa sisene aadress",
     "Add internal email or domain" : "Lisa sisene e-posti aadress või domeen",
     "Itinerary for {type} is not supported yet" : "Reisiplaani tüüp pole veel toetatud: {type}",
-    "To archive a message please configure an archive mailbox in account settings" : "Kui tahad kirju arhiveerida, pead esmalt seadistustest valima arhiivikausta",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Sul pole õigusi selle kirja arhiveerimiseks ega siit kaustast kustutamiseks või teisaldamiseks",
     "Your IMAP server does not support storing the seen/unseen state." : "Sinu e-posti server ei luba salvestada kirjade nähtud/mittenähtud olekuid.",
     "Could not mark message as seen/unseen" : "Ei õnnestunud märkida kirja nähtuks/mittenähtuks",
-    "Could not open mailbox" : "Postkasti avamine ei õnnestunud",
     "Loading messages …" : "Laadin kirju…",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indekseering sinu kirju. Kui postkastid on väga suured, siis võib kuluda natuke aega.",
-    "Choose target mailbox" : "Vali sihtpostkast",
+    "Choose target folder" : "Vali sihtkaust",
     "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
     "Important info" : "Oluline teave",
     "Other" : "Muu",
@@ -396,31 +390,23 @@ OC.L10N.register(
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "E-posti konto {email} ja tema puhverdatud andmed eemaldatakse siit Nextcloudi serverist, kuid mitte sinu e-postiteenuse pakkuja juurest.",
     "Remove {email}" : "Eemalda fail: „{email}“",
     "Quota" : "Kvoot",
-    "Show only subscribed mailboxes" : "Näita vaid tellitud postkaste",
-    "Add mailbox" : "Lisa postkast",
-    "Mailbox name" : "Postkasti nimi",
+    "Add folder" : "Lisa kaust",
+    "Folder name" : "Kausta nimi",
     "Saving" : "Salvestan",
     "Move up" : "Liiguta ülespoole",
     "Move down" : "Liiguta allapoole",
-    "Show all subscribed mailboxes" : "Näita kõiki tellitud postkaste",
-    "Show all mailboxes" : "Näita kõiki postkaste",
+    "Show all folders" : "Näita kõiki kaustu",
     "Collapse mailboxes" : "Ahenda postkastid",
     "_{total} message_::_{total} messages_" : ["{total} kiri","{total} kirja"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lugemata kiri {total}-st kirjast","{unread} lugemata kirja {total}-st kirjast"],
     "All messages in mailbox will be deleted." : "Kõik kirjad sellest postkastist  kustutatakse.",
     "Clear mailbox {name}" : "Tühjenda postkast: {name}",
-    "Clear mailbox" : "Tühjenda postkast",
-    "The mailbox and all messages in it will be deleted." : "Postkast ja kõik temas leiduvad kirjad saavad järgnevaga kustutatud.",
-    "Delete mailbox" : "Kustuta postkast",
-    "Delete mailbox {name}" : "Kustuta postkast: {name}",
+    "Delete folder" : "Kustuta kaust",
     "An error occurred, unable to rename the mailbox." : "Tekkis viga ja postkasti nime muutmine pole võimalik.",
     "Please wait 10 minutes before repairing again" : "Enne uuesti parandamist palun oota 10 minutit",
     "Mark all as read" : "Märgi loetuks",
-    "Mark all messages of this mailbox as read" : "Märgi kõik selle postkasti kirjad loetuks",
-    "Add submailbox" : "Lisa alampostkast",
     "Rename" : "Muuda nime",
-    "Move mailbox" : "Teisalda postkast",
-    "Repair mailbox" : "Paranda postkasti",
+    "Move folder" : "Teisalda kausta",
     "Clear cache" : "Tühjenda puhver",
     "Clear locally cached data, in case there are issues with synchronization." : "Kui sünkroniseerimisel tekib vigu, siis kustuta kohalikus seadmes puhverdatud andmed.",
     "Subscribed" : "Tellitud",
@@ -435,7 +421,6 @@ OC.L10N.register(
     "Failed to save draft" : "Mustandi salvestamine ei õnnestu",
     "attachment" : "manus",
     "attached" : "manus on lisatud",
-    "No sent mailbox configured. Please pick one in the account settings." : "Väljuvate kirjade postkast on seadistamata. Palun see seda kasutajakonto seadistustes.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Sa üritad saata kirja, kus saaja ja koopia välja on hiidpalju aadresse. Kirjasaajate privaatsuse ja mugavuse nimel palun kasuta pimekoopia välja.",
     "Your message has no subject. Do you want to send it anyway?" : "Sinu e-kirjal puudub teema. Kas sa kindlasti soovid seda saata?",
     "You mentioned an attachment. Did you forget to add it?" : "Sa mainisid, et tahad manuse lisada. Kas see ununes?",
@@ -464,12 +449,9 @@ OC.L10N.register(
     "Save autoresponder" : "Salvesta automaatvastaja",
     "Could not open outbox" : "Saadetud kirjade postkasti ei olnud võimalik avada",
     "Pending or not sent messages will show up here" : "Ootel või saatmata kirjad saavad olema nähtavad siin.",
-    "Could not copy to \"Sent\" mailbox" : "Kirja on kopeerimine „Saadetud“ postkasti ei õnnestunud",
     "Mail server error" : "E-posti serveri viga",
     "Message could not be sent" : "Kirja polnud võimalik saata",
     "Message deleted" : "Kiri on kustutatud",
-    "Copy to \"Sent\" Mailbox" : "Kopeeri „Saadetud“ kirjade postkasti",
-    "Copy to Sent Mailbox" : "Kopeeri „Saadetud“ kirjade postkasti",
     "Phishing email" : "Kurikaela õngitsuskiri",
     "This email might be a phishing attempt" : "See e-kiri võib olla üks õngitsuskatse",
     "Hide suspicious links" : "Peida kahtlased lingid",
@@ -486,7 +468,6 @@ OC.L10N.register(
     "Show less" : "Näita vähem",
     "Show more" : "Näita rohkem",
     "Clear" : "Tühjenda",
-    "Search in mailbox" : "Otsi postkastist",
     "Close" : "Sulge",
     "Search parameters" : "Otsinguparameetrid",
     "Search subject" : "Otsi teemat",
@@ -740,8 +721,6 @@ OC.L10N.register(
     "Sending message…" : "Saadan kirja…",
     "Message sent" : "Kiri on saadetud",
     "Could not send message" : "Kirja saatmine ei õnnestu",
-    "Message copied to \"Sent\" mailbox" : "Kiri on kopeeritud „Saadetud“ postkasti",
-    "Could not copy message to \"Sent\" mailbox" : "Kirja on kopeerimine „Saadetud“ postkasti ei õnnestunud",
     "Could not load {tag}{name}{endtag}" : "Laadimine ei õnnestunud: {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Laadimisel tekkis viga: {tag}{name}{endtag}",
     "Could not load your message" : "Sinu kirja laadimine ei õnnestunud",
@@ -754,12 +733,39 @@ OC.L10N.register(
     "The link leads to %s" : "Link viitab siia: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
     "Continue to %s" : "Jätka siia: %s",
+    "Mailbox search" : "Postkasti otsing",
+    "No messages in this mailbox" : "Selles postkastis pole kirju",
+    "No trash mailbox configured" : "Prügikasti kaust on määramata",
     "Draft: " : "Kavand:",
+    "To archive a message please configure an archive mailbox in account settings" : "Kui tahad kirju arhiveerida, pead esmalt seadistustest valima arhiivikausta",
+    "Could not open mailbox" : "Postkasti avamine ei õnnestunud",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indekseering sinu kirju. Kui postkastid on väga suured, siis võib kuluda natuke aega.",
+    "Choose target mailbox" : "Vali sihtpostkast",
+    "Show only subscribed mailboxes" : "Näita vaid tellitud postkaste",
+    "Add mailbox" : "Lisa postkast",
+    "Mailbox name" : "Postkasti nimi",
+    "Show all subscribed mailboxes" : "Näita kõiki tellitud postkaste",
+    "Show all mailboxes" : "Näita kõiki postkaste",
+    "Clear mailbox" : "Tühjenda postkast",
+    "The mailbox and all messages in it will be deleted." : "Postkast ja kõik temas leiduvad kirjad saavad järgnevaga kustutatud.",
+    "Delete mailbox" : "Kustuta postkast",
+    "Delete mailbox {name}" : "Kustuta postkast: {name}",
+    "Mark all messages of this mailbox as read" : "Märgi kõik selle postkasti kirjad loetuks",
+    "Add submailbox" : "Lisa alampostkast",
+    "Move mailbox" : "Teisalda postkast",
+    "Repair mailbox" : "Paranda postkasti",
+    "No sent mailbox configured. Please pick one in the account settings." : "Väljuvate kirjade postkast on seadistamata. Palun see seda kasutajakonto seadistustes.",
+    "Could not copy to \"Sent\" mailbox" : "Kirja on kopeerimine „Saadetud“ postkasti ei õnnestunud",
+    "Copy to \"Sent\" Mailbox" : "Kopeeri „Saadetud“ kirjade postkasti",
+    "Copy to Sent Mailbox" : "Kopeeri „Saadetud“ kirjade postkasti",
+    "Search in mailbox" : "Otsi postkastist",
     "If all tests pass, then the actions will be executed" : "Kui kõik testid toimivad, siis tegevused käivitatakse",
     "If one test pass, then the actions will be executed" : "Kui üks test toimib, siis tegevused käivitatakse",
     "Tests" : "Testid",
     "New test" : "Uus test",
     "Actions" : "Tegevused",
-    "New action" : "Uus tegevus"
+    "New action" : "Uus tegevus",
+    "Message copied to \"Sent\" mailbox" : "Kiri on kopeeritud „Saadetud“ postkasti",
+    "Could not copy message to \"Sent\" mailbox" : "Kirja on kopeerimine „Saadetud“ postkasti ei õnnestunud"
 },
 "nplurals=2; plural=(n != 1);");
