@@ -98,7 +98,6 @@ OC.L10N.register(
     "Sieve script editor" : "Sieve script editorea",
     "Mail server" : "Posta-zerbitzaria",
     "Sieve server" : "Sieve zerbitzaria",
-    "Mailbox search" : "Postontziko bilaketa",
     "Update alias" : "Eguneratu aliasa",
     "Rename alias" : "Aliasa berrizendatu",
     "Show update alias form" : "Erakutsi alias inprimakiaren eguneratzea",
@@ -229,7 +228,7 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "Mezu guztietako etiketak ezabatuko dira.",
     "Plain text" : "Testu arrunta",
     "Rich text" : "Testu aberastua",
-    "No messages in this mailbox" : "Mezurik ez postontzi honetan",
+    "No messages in this folder" : "Mezurik ez karpeta honetan",
     "No messages" : "Mezurik ez",
     "Blind copy recipients only" : "Kopia itsuen jasotzaileek besterik ez",
     "No subject" : "Gairik ez",
@@ -241,7 +240,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Ezarri gogorarazpena asteburu honetarako",
     "Next week – {timeLocale}" : "Hurrengo astea – {timeLocale}",
     "Set reminder for next week" : "Ezarri gogorarazpena hurrengo asterako",
-    "No trash mailbox configured" : "Ez da zakarrontzirik konfiguratu",
     "Could not delete message" : "Ezin izan da mezua ezabatu",
     "Could not archive message" : "Ezin izan da mezua artxibatu",
     "Thread was snoozed" : "Haria geroko utzi da",
@@ -320,12 +318,9 @@ OC.L10N.register(
     "Add internal address" : "Gehitu barneko helbidea",
     "Add internal email or domain" : "Gehitu barneko helbide elektronikoa edo domeinua",
     "Itinerary for {type} is not supported yet" : "{type} motarentzako ibilbidea ez da onartzen oraindik",
-    "To archive a message please configure an archive mailbox in account settings" : "Mezu bat artxibatzeko, konfiguratu artxiboko postontzi bat kontuaren ezarpenetan",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Ez duzu mezu hau artxibo karpetara eramateko eta/edo mezu hau uneko karpetatik ezabatzeko baimenik",
-    "Could not open mailbox" : "Ezin izan da postontzia ireki",
     "Loading messages …" : "Mezuak kargatzen ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Zure mezuak indexatzen. Honek denbora dezente har dezake postontzi handietan.",
-    "Choose target mailbox" : "Aukeratu helburuko postontzia",
+    "Choose target folder" : "Aukeratu helburuko karpeta",
     "No more submailboxes in here" : "Azpipostontzi gehiagorik ez hemen",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Mezuak automatikoki markatuko dira garrantzitsu bezala kontuan izanda zein mezurekin aritu zaren interakzioan edo zein markatu dituzun garratzitsu gisa. Hasieran garrantzia eskuz aldatu beharko duzu sistemari irakasteko, baina denborarekin hobetuko du.",
     "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "Erantzuteko eskatuz bidali zenituen emailak, baina egun batzuen ondoren erantzunik jasotzen ez dutenak hemen erakutsiko dira.",
@@ -387,31 +382,29 @@ OC.L10N.register(
     "Provisioned account is disabled" : "Hornitutako kontua desgaituta dago",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Mesedez, hasi saioa pasahitz bat erabiliz kontu hau gaitzeko. Uneko saioa pasahitzik gabeko autentifikazioa erabiltzen ari da, adibidez. SSO edo WebAuthn.",
     "Quota" : "Kuota",
-    "Show only subscribed mailboxes" : "Erakutsi harpidetutako postontziak soilik",
-    "Add mailbox" : "Gehitu postontzia",
-    "Mailbox name" : "Postontziaren izena",
+    "Show only subscribed folders" : "Erakutsi harpidetutako karpetak soilik",
+    "Add folder" : "Gehitu karpeta",
+    "Folder name" : "Karpetaren izena",
     "Saving" : "Gordetzen",
     "Move up" : "Eraman gora",
     "Move down" : "Eraman behera",
-    "Show all subscribed mailboxes" : "Erakutsi harpidetutako postontzi guztiak",
-    "Show all mailboxes" : "Erakutsi postontzi guztiak",
+    "Show all subscribed folders" : "Erakutsi harpidetutako karpeta guztiak",
+    "Show all folders" : "Erakutsi karpeta guztiak",
     "Collapse mailboxes" : "Tolestu postontziak",
     "_{total} message_::_{total} messages_" : ["Mezu {total}","{total} mezu"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} irakurri gabe {total} -etik","{unread} irakurri gabe {total} -etik"],
     "All messages in mailbox will be deleted." : "Postontziko mezu guztiak ezabatuko dira.",
     "Clear mailbox {name}" : "Garbitu {name} postontzia",
-    "Clear mailbox" : "Garbitu postontzia",
-    "The mailbox and all messages in it will be deleted." : "Postontzia eta bertan dauden mezu guztiak ezabatuko dira.",
-    "Delete mailbox" : "Ezabatu postontzia",
-    "Delete mailbox {name}" : "Ezabatu {name} postontzia",
+    "The folder and all messages in it will be deleted." : " \nKarpeta eta bertan dauden mezu guztiak ezabatuko dira.",
+    "Delete folder" : "Ezabatu karpeta",
+    "Delete folder {name}" : "Ezabatu {name} karpeta ",
     "An error occurred, unable to rename the mailbox." : "Akatsen bat gertatu da, ezin izan da postontzia berrizendatu.",
     "Please wait 10 minutes before repairing again" : "Mesedez, itxaron 10 minutu berriro konpondu aurretik",
     "Mark all as read" : "Markatu dena irakurrita bezala",
-    "Mark all messages of this mailbox as read" : "Markatu postontzi honetako mezu guztiak irakurrita bezala",
-    "Add submailbox" : "Gehitu azpipostontzia",
+    "Mark all messages of this folder as read" : "Markatu karpeta honetako mezu guztiak irakurrita bezala",
+    "Add subfolder" : "Gehitu azpi-karpeta bat",
     "Rename" : "Berrizendatu",
-    "Move mailbox" : "Mugitu postontzia",
-    "Repair mailbox" : "Konpondu postontzia",
+    "Move folder" : "Lekuz aldatu karpeta",
     "Clear cache" : "Garbitu cachea",
     "Clear locally cached data, in case there are issues with synchronization." : "Ezabatu lokalean katxeatutako datuak, sinkronizaziorik arazorik badagoen.",
     "Subscribed" : "Harpidetua",
@@ -426,7 +419,6 @@ OC.L10N.register(
     "Failed to save draft" : "Zirriborroa gordetzeak huts egin du",
     "attachment" : "eranskina",
     "attached" : "erantsita",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ez dago bidalitakoen postontzirik konfiguratuta. Aukeratu baten bat kontuaren ezarpenetan, mesedez.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "To eta / edo Cc-n hartzaile askori bidaltzen saiatzen ari zara. Hartzaileen helbideak ezkutatzeko Bcc erabili dezakezu.",
     "You mentioned an attachment. Did you forget to add it?" : "Eranskin bat aipatu duzu. Gehitzea ahaztu al zaizu?",
     "Message discarded" : "Mezua bertan behera utzi da",
@@ -450,12 +442,9 @@ OC.L10N.register(
     "Save autoresponder" : "Gorde autoerantzulea",
     "Could not open outbox" : "Ezin izan da irteera-postontzia ireki",
     "Pending or not sent messages will show up here" : "Bidali gabe dauden edo bidali gabeko mezuak hemen agertuko dira",
-    "Could not copy to \"Sent\" mailbox" : "Ezin izan da kopiatu \"Bidalitakoak\" postontzira",
     "Mail server error" : "Posta zerbitzariaren errorea",
     "Message could not be sent" : "Ezin izan da mezua bidali",
     "Message deleted" : "Mezua ezabatu da",
-    "Copy to \"Sent\" Mailbox" : "Kopiatu \"Bidalitakoak\" postontzira",
-    "Copy to Sent Mailbox" : "Kopiatu Bidalitakoak postontzira",
     "Phishing email" : "Pishing emaila",
     "This email might be a phishing attempt" : "Posta elektroniko hau phishing saiakera bat izan daiteke",
     "Hide suspicious links" : "Ezkutatu esteka susmagarriak",
@@ -472,7 +461,6 @@ OC.L10N.register(
     "Show less" : "Erakutsi gutxiago",
     "Show more" : "Erakutsi gehiago",
     "Clear" : "Garbitu",
-    "Search in mailbox" : "Bilatu postontzian",
     "Close" : "Itxi",
     "Search parameters" : "Bilaketa parametroak",
     "Search subject" : "Bilatu gaian",
@@ -744,8 +732,6 @@ OC.L10N.register(
     "Could not create snooze mailbox" : "Ezin izan da geroko utzitakoen postontzia sortu",
     "Message sent" : "Mezua bidalita",
     "Could not send message" : "Ezin izan da mezua bidali",
-    "Message copied to \"Sent\" mailbox" : "Mezua \"Bidalitakoak\" postontzira kopiatu da",
-    "Could not copy message to \"Sent\" mailbox" : "Ezin izan da mezua \"Bidalitakoak\" postontzira kopiatu",
     "Could not load {tag}{name}{endtag}" : "Ezin izan da {tag}{name}{endtag} kargatu",
     "There was a problem loading {tag}{name}{endtag}" : "Arazo bat egon da {tag}{name}{endtag} kargatzerakoan",
     "Could not load your message" : "Ezin izan da zure mezua kargatu",
@@ -758,12 +744,39 @@ OC.L10N.register(
     "The link leads to %s" : "Estekak hona bideratzen du: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
     "Continue to %s" : "Jarraitu hona: %s",
+    "Mailbox search" : "Postontziko bilaketa",
+    "No messages in this mailbox" : "Mezurik ez postontzi honetan",
+    "No trash mailbox configured" : "Ez da zakarrontzirik konfiguratu",
     "Draft: " : "Zirriborroa: ",
+    "To archive a message please configure an archive mailbox in account settings" : "Mezu bat artxibatzeko, konfiguratu artxiboko postontzi bat kontuaren ezarpenetan",
+    "Could not open mailbox" : "Ezin izan da postontzia ireki",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Zure mezuak indexatzen. Honek denbora dezente har dezake postontzi handietan.",
+    "Choose target mailbox" : "Aukeratu helburuko postontzia",
+    "Show only subscribed mailboxes" : "Erakutsi harpidetutako postontziak soilik",
+    "Add mailbox" : "Gehitu postontzia",
+    "Mailbox name" : "Postontziaren izena",
+    "Show all subscribed mailboxes" : "Erakutsi harpidetutako postontzi guztiak",
+    "Show all mailboxes" : "Erakutsi postontzi guztiak",
+    "Clear mailbox" : "Garbitu postontzia",
+    "The mailbox and all messages in it will be deleted." : "Postontzia eta bertan dauden mezu guztiak ezabatuko dira.",
+    "Delete mailbox" : "Ezabatu postontzia",
+    "Delete mailbox {name}" : "Ezabatu {name} postontzia",
+    "Mark all messages of this mailbox as read" : "Markatu postontzi honetako mezu guztiak irakurrita bezala",
+    "Add submailbox" : "Gehitu azpipostontzia",
+    "Move mailbox" : "Mugitu postontzia",
+    "Repair mailbox" : "Konpondu postontzia",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ez dago bidalitakoen postontzirik konfiguratuta. Aukeratu baten bat kontuaren ezarpenetan, mesedez.",
+    "Could not copy to \"Sent\" mailbox" : "Ezin izan da kopiatu \"Bidalitakoak\" postontzira",
+    "Copy to \"Sent\" Mailbox" : "Kopiatu \"Bidalitakoak\" postontzira",
+    "Copy to Sent Mailbox" : "Kopiatu Bidalitakoak postontzira",
+    "Search in mailbox" : "Bilatu postontzian",
     "If all tests pass, then the actions will be executed" : "Proba guztiak gaindituz gero, ekintzak burutu egingo dira",
     "If one test pass, then the actions will be executed" : "Proba bat gaindituz gero, ekintzak burutu egingo dira",
     "Tests" : "Probak",
     "New test" : "Proba berria",
     "Actions" : "Ekintzak",
-    "New action" : "Ekintza berria"
+    "New action" : "Ekintza berria",
+    "Message copied to \"Sent\" mailbox" : "Mezua \"Bidalitakoak\" postontzira kopiatu da",
+    "Could not copy message to \"Sent\" mailbox" : "Ezin izan da mezua \"Bidalitakoak\" postontzira kopiatu"
 },
 "nplurals=2; plural=(n != 1);");
