@@ -184,7 +184,7 @@ OC.L10N.register(
     "Confirm" : "تائید",
     "Plain text" : "متن ساده",
     "Rich text" : "متن غنی",
-    "No messages in this mailbox" : "No messages in this mailbox",
+    "No messages in this folder" : "هیچ پیامی در این پوشه وجود ندارد",
     "No messages" : "No messages",
     "Blind copy recipients only" : "فقط گیرندگان کپی کور",
     "No subject" : "No subject",
@@ -196,7 +196,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Set reminder for this weekend",
     "Next week – {timeLocale}" : "Next week – {timeLocale}",
     "Set reminder for next week" : "Set reminder for next week",
-    "No trash mailbox configured" : "No trash mailbox configured",
     "Could not delete message" : "Could not delete message",
     "Could not archive message" : "Could not archive message",
     "Thread was snoozed" : "Thread was snoozed",
@@ -265,12 +264,9 @@ OC.L10N.register(
     "Remove" : "حذف",
     "email" : "ایمیل",
     "Itinerary for {type} is not supported yet" : "برنامه سفر برای {نوع yet هنوز پشتیبانی نمی شود",
-    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
-    "Could not open mailbox" : "صندوق پستی امکان پذیر نیست",
     "Loading messages …" : "Loading messages …",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "نمایه سازی پیام های شما این می تواند کمی برای صندوق های پستی بزرگتر کمی طولانی شود.",
-    "Choose target mailbox" : "Choose target mailbox",
+    "Choose target folder" : "پوشهٔ هدف را انتخاب کنید",
     "No more submailboxes in here" : "No more submailboxes in here",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
     "Important info" : "Important info",
@@ -322,28 +318,23 @@ OC.L10N.register(
     "Provisioned account is disabled" : "Provisioned account is disabled",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn.",
     "Quota" : "سهم",
-    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
-    "Add mailbox" : "Add mailbox",
+    "Folder name" : "نام پوشه",
     "Saving" : "درحال ذخیره",
     "Move up" : "Move up",
     "Move down" : "حرکت به پایین",
-    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
-    "Show all mailboxes" : "Show all mailboxes",
+    "Show all folders" : "نمایش همه پوشه ها",
     "Collapse mailboxes" : "Collapse mailboxes",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
     "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
     "Clear mailbox {name}" : "Clear mailbox {name}",
-    "Clear mailbox" : "Clear mailbox",
-    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
-    "Delete mailbox" : "Delete mailbox",
-    "Delete mailbox {name}" : "Delete mailbox {name}",
+    "Delete folder" : "حذف پوشه",
     "An error occurred, unable to rename the mailbox." : "An error occurred, unable to rename the mailbox.",
     "Mark all as read" : "علامت همه به عنوان خوانده‌شده",
-    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
-    "Add submailbox" : "Add submailbox",
+    "Mark all messages of this folder as read" : "تمام پیام های این پوشه را به عنوان خوانده شده علامت گذاری کنید",
+    "Add subfolder" : "زیر پوشه را اضافه کنید",
     "Rename" : "تغییرنام",
-    "Move mailbox" : "Move mailbox",
+    "Move folder" : "Move folder",
     "Clear cache" : "پاک‌سازی انباره",
     "Clear locally cached data, in case there are issues with synchronization." : "Clear locally cached data, in case there are issues with synchronization.",
     "Subscribed" : "Subscribed",
@@ -356,7 +347,6 @@ OC.L10N.register(
     "Message saved" : "Message saved",
     "Failed to save message" : "Failed to save message",
     "Failed to save draft" : "Failed to save draft",
-    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses.",
     "Message discarded" : "Message discarded",
     "Could not discard message" : "Could not discard message",
@@ -388,7 +378,6 @@ OC.L10N.register(
     "Show less" : "Show less",
     "Show more" : "Show more",
     "Clear" : "پاک کردن",
-    "Search in mailbox" : "Search in mailbox",
     "Close" : "بسته",
     "Search parameters" : "Search parameters",
     "Body" : "متن",
@@ -611,7 +600,26 @@ OC.L10N.register(
     "The link leads to %s" : "پیوند منجر به%s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "ادامه دهید%s",
+    "No messages in this mailbox" : "No messages in this mailbox",
+    "No trash mailbox configured" : "No trash mailbox configured",
     "Draft: " : "پیش نویس:",
+    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
+    "Could not open mailbox" : "صندوق پستی امکان پذیر نیست",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "نمایه سازی پیام های شما این می تواند کمی برای صندوق های پستی بزرگتر کمی طولانی شود.",
+    "Choose target mailbox" : "Choose target mailbox",
+    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
+    "Add mailbox" : "Add mailbox",
+    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
+    "Show all mailboxes" : "Show all mailboxes",
+    "Clear mailbox" : "Clear mailbox",
+    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
+    "Delete mailbox" : "Delete mailbox",
+    "Delete mailbox {name}" : "Delete mailbox {name}",
+    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
+    "Add submailbox" : "Add submailbox",
+    "Move mailbox" : "Move mailbox",
+    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
+    "Search in mailbox" : "Search in mailbox",
     "Actions" : "کنش‌ها",
     "New action" : "New action"
 },
