@@ -165,7 +165,7 @@ OC.L10N.register(
     "Confirm" : "Vahvista",
     "Plain text" : "Raakateksti",
     "Rich text" : "Rikas teksti",
-    "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
+    "No messages in this folder" : "Tässä kansiossa ei ole viestejä",
     "No messages" : "Ei viestejä",
     "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
     "No subject" : "Ei aihetta",
@@ -234,9 +234,8 @@ OC.L10N.register(
     "domain" : "domaini",
     "Remove" : "Poista",
     "email" : "sähköposti",
-    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
     "Loading messages …" : "Ladataan viestejä …",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
+    "Choose target folder" : "Valitse kohdekansio",
     "Important info" : "Tärkeää tietoa",
     "Other" : "Muu",
     "The sender of this message has asked to be notified when you read this message." : "Tämän viestin lähettäjä on pyytänyt ilmoitusta, kun luet tämän viestin.",
@@ -279,27 +278,28 @@ OC.L10N.register(
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tili {email} ja tallennetut viesti poistetaan Nextcloudista, muttei sähköpostintarjoajaltasi.",
     "Remove {email}" : "Poista {email}",
     "Quota" : "Kiintiö",
-    "Show only subscribed mailboxes" : "Näytä vain tilatut postilaatikot",
-    "Add mailbox" : "Lisää postilaatikko",
+    "Show only subscribed folders" : "Näytä vain tilatut kansiot",
+    "Add folder" : "Lisää kansio",
+    "Folder name" : "Kansion nimi",
     "Saving" : "Tallennetaan",
     "Move up" : "Siirrä ylös",
     "Move down" : "Siirrä alas",
-    "Show all subscribed mailboxes" : "Näytä kaikki tilatut postilaatikot",
-    "Show all mailboxes" : "Näytä kaikki postilaatikot",
+    "Show all subscribed folders" : "Näytä kaikki tilatut kansiot",
+    "Show all folders" : "Näytä kaikki kansiot",
     "Collapse mailboxes" : "Supista postilaatikot",
     "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
     "All messages in mailbox will be deleted." : "Kaikki postilaatikon viestit poistetaan.",
     "Clear mailbox {name}" : "Tyhjennä postilaatikko {name}",
-    "Clear mailbox" : "Tyhjennä postilaatikko",
-    "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
-    "Delete mailbox" : "Poista postilaatikko",
-    "Delete mailbox {name}" : "Poista postilaatikko {name}",
+    "The folder and all messages in it will be deleted." : "Tämä kansio ja kaikki sen viestit poistetaan.",
+    "Delete folder" : "Poista kansio",
+    "Delete folder {name}" : "Poista kansio {name}",
     "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
     "Mark all as read" : "Merkitse kaikki luetuiksi",
-    "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
-    "Add submailbox" : "Lisää alipostilaatikko",
+    "Mark all messages of this folder as read" : "Merkitse tämän kansion kaikki viestit luetuiksi",
+    "Add subfolder" : "Lisää alikansio",
     "Rename" : "Nimeä uudelleen",
+    "Move folder" : "Siirrä kansio",
     "Clear cache" : "Tyhjennä välimuisti",
     "Clear locally cached data, in case there are issues with synchronization." : "Poista paikallisesti tallennetut tiedot, jos synkronoinnissa on ongelmia.",
     "Subscribed" : "Tilattu",
@@ -311,7 +311,6 @@ OC.L10N.register(
     "Message saved" : "Viesti tallennettu",
     "Failed to save message" : "Viestin tallentaminen epäonnistui",
     "Failed to save draft" : "Luonnoksen tallentaminen epäonnistui",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
     "Message discarded" : "Viesti hylätty",
     "Could not discard message" : "Viestiä ei voitu hylätä",
     "Minimize composer" : "Pienennä lähetysikkuna",
@@ -496,7 +495,21 @@ OC.L10N.register(
     "Redirect" : "Uudelleenohjaus",
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
     "Continue to %s" : "Jatka sivulle %s",
+    "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
     "Draft: " : "Luonnos: ",
+    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
+    "Show only subscribed mailboxes" : "Näytä vain tilatut postilaatikot",
+    "Add mailbox" : "Lisää postilaatikko",
+    "Show all subscribed mailboxes" : "Näytä kaikki tilatut postilaatikot",
+    "Show all mailboxes" : "Näytä kaikki postilaatikot",
+    "Clear mailbox" : "Tyhjennä postilaatikko",
+    "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
+    "Delete mailbox" : "Poista postilaatikko",
+    "Delete mailbox {name}" : "Poista postilaatikko {name}",
+    "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
+    "Add submailbox" : "Lisää alipostilaatikko",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
     "Actions" : "Toiminnot",
     "New action" : "Uusi toiminto"
 },
