@@ -101,10 +101,9 @@ OC.L10N.register(
     "Confirm" : "אימות",
     "Plain text" : "טקסט פשוט",
     "Rich text" : "טקסט עשיר",
-    "No messages in this mailbox" : "אין הודעות בתיבת הדוא״ל הזאת",
+    "No messages in this folder" : "אין הודעות בתיקייה זו",
     "No messages" : "אין הודעות",
     "Blind copy recipients only" : "נמענים נסתרים בלבד",
-    "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
     "Could not delete message" : "לא ניתן למחוק הודעה",
     "Unfavorite" : "ביטול כמועדף",
     "Favorite" : "סימון כמועדף",
@@ -134,8 +133,7 @@ OC.L10N.register(
     "Remove" : "הסרה",
     "email" : "דוא״ל",
     "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
-    "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
+    "Choose target folder" : "נא לבחור תיקיית יעד",
     "Important info" : "מידע חשוב",
     "Other" : "אחר",
     "Forward" : "העברה",
@@ -158,20 +156,21 @@ OC.L10N.register(
     "Remove account" : "הסרת חשבון",
     "Remove {email}" : "להסיר את {email}",
     "Quota" : "מכיסה",
-    "Add mailbox" : "הוספת תיבת דוא״ל",
+    "Show only subscribed folders" : "להציג תיקיות שבמינוי בלבד",
+    "Add folder" : "הוספת תיקייה",
+    "Folder name" : "שם התיקייה",
     "Saving" : "שמירה",
     "Move down" : "להוריד למטה",
-    "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
+    "Show all subscribed folders" : "להציג את כל התיקיות שבמינוי",
+    "Show all folders" : "הצגת כל התיקיות",
     "Collapse mailboxes" : "צמצום תיבות דוא״ל",
     "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
-    "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
-    "Delete mailbox" : "מחיקת תיבת דוא״ל",
-    "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
+    "Delete folder" : "מחק תיקייה",
     "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
     "Mark all as read" : "סימון הכול כנקרא",
-    "Mark all messages of this mailbox as read" : "סימון כל ההודעות בתיבת הדוא״ל הזו כנקראו",
-    "Add submailbox" : "הוספת תת־תיבת דוא״ל",
+    "Mark all messages of this folder as read" : "סימון כל ההודעות בתיקייה הזאת כנקראו",
+    "Add subfolder" : "הוספת תת־תיקייה",
     "Rename" : "שינוי שם",
     "Clear cache" : "פינוי מטמון",
     "Clear locally cached data, in case there are issues with synchronization." : "פינוי הנתונים שמאוחסנים מקומית במטמון, במקרה שיש תקלות בסנכרון.",
@@ -267,7 +266,18 @@ OC.L10N.register(
     "Redirect" : "הפנייה",
     "The link leads to %s" : "הקישור מוביל אל %s",
     "Continue to %s" : "ממשיך אל %s",
+    "No messages in this mailbox" : "אין הודעות בתיבת הדוא״ל הזאת",
+    "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
     "Draft: " : "טיוטה:",
+    "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
+    "Add mailbox" : "הוספת תיבת דוא״ל",
+    "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
+    "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
+    "Delete mailbox" : "מחיקת תיבת דוא״ל",
+    "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
+    "Mark all messages of this mailbox as read" : "סימון כל ההודעות בתיבת הדוא״ל הזו כנקראו",
+    "Add submailbox" : "הוספת תת־תיבת דוא״ל",
     "Actions" : "פעולות"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
