@@ -109,10 +109,9 @@ OC.L10N.register(
     "Confirm" : "Potvrdi",
     "Plain text" : "Običan tekst",
     "Rich text" : "Bogat tekst",
-    "No messages in this mailbox" : "Nema poruka u ovom sandučiću",
+    "No messages in this folder" : "Nema poruka u ovoj mapi",
     "No messages" : "Nema poruka",
     "Blind copy recipients only" : "Samo primatelji skrivenih kopija poruke",
-    "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
     "Could not delete message" : "Brisanje poruke nije uspjelo",
     "Unfavorite" : "Ukloni iz favorita",
     "Favorite" : "Favorit",
@@ -154,9 +153,7 @@ OC.L10N.register(
     "Remove" : "Ukloni",
     "email" : "e-pošta",
     "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
-    "Could not open mailbox" : "Nije moguće otvoriti sandučić",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksiranje poruka u tijeku. Ova radnja može potrajati za veće sandučiće.",
-    "Choose target mailbox" : "Odaberi ciljni sandučić",
+    "Choose target folder" : "Odaberi ciljnu mapu",
     "No more submailboxes in here" : "Ovdje više nema podsandučića",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
     "Important info" : "Važne informacije",
@@ -199,31 +196,32 @@ OC.L10N.register(
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} i podaci e-pošte spremljeni u predmemoriji uklonit će se iz Nextclouda, ali ne iz vašeg davatelja usluga e-pošte.",
     "Remove {email}" : "Ukloni {email}",
     "Quota" : "Kvota",
-    "Show only subscribed mailboxes" : "Prikaži samo pretplaćene sandučiće",
-    "Add mailbox" : "Dodaj sandučić",
+    "Show only subscribed folders" : "Prikaži samo pretplaćene mape",
+    "Add folder" : "Dodaj mapu",
+    "Folder name" : "Naziv mape",
     "Saving" : "Spremanje",
     "Move up" : "Premjesti gore",
     "Move down" : "Premjesti dolje",
-    "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
-    "Show all mailboxes" : "Prikaži sve sandučiće",
+    "Show all subscribed folders" : "Prikaži sve pretplaćene mape",
+    "Show all folders" : "Prikaži sve mape",
     "Collapse mailboxes" : "Sakrij sandučiće",
     "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
-    "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
-    "Delete mailbox" : "Izbriši sandučić",
-    "Delete mailbox {name}" : "Izbriši sandučić {name}",
+    "The folder and all messages in it will be deleted." : "Izbrisat će se mapa i sve poruke.",
+    "Delete folder" : "Izbriši mapu",
+    "Delete folder {name}" : "Izbriši mapu {name}",
     "An error occurred, unable to rename the mailbox." : "Došlo je do pogreške, nije moguće promijeniti naziv sandučića.",
     "Mark all as read" : "Označi sve kao pročitano",
-    "Mark all messages of this mailbox as read" : "Označi sve poruke u ovom sandučiću kao pročitane",
-    "Add submailbox" : "Dodaj podsandučić",
+    "Mark all messages of this folder as read" : "Označi sve poruke u ovoj mapi kao pročitane",
+    "Add subfolder" : "Dodaj podmapu",
     "Rename" : "Preimenuj",
+    "Move folder" : "Premjesti mapu",
     "Clear cache" : "Izbriši predmemoriju",
     "Clear locally cached data, in case there are issues with synchronization." : "Izbrišite podatke iz lokalnog međuspremnika u slučaju da postoje problemi sa sinkronizacijom.",
     "Subscribed" : "Pretplaćen",
     "Sync in background" : "Sinkronizacija u pozadini",
     "New message" : "Nova poruka",
     "Reply" : "Odgovori",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Pokušavate poslati poruku velikom broju primatelja koji su navedeni u poljima Za i/ili Cc. Razmislite o korištenju polja Bcc kako adrese primatelja ne bi bile vidljive.",
     "Error sending your message" : "Pogreška pri slanju poruke",
     "Retry" : "Pokušaj ponovno",
@@ -379,7 +377,22 @@ OC.L10N.register(
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
     "Continue to %s" : "Idi do %s",
+    "No messages in this mailbox" : "Nema poruka u ovom sandučiću",
+    "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
     "Draft: " : "Skica: ",
+    "Could not open mailbox" : "Nije moguće otvoriti sandučić",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksiranje poruka u tijeku. Ova radnja može potrajati za veće sandučiće.",
+    "Choose target mailbox" : "Odaberi ciljni sandučić",
+    "Show only subscribed mailboxes" : "Prikaži samo pretplaćene sandučiće",
+    "Add mailbox" : "Dodaj sandučić",
+    "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
+    "Show all mailboxes" : "Prikaži sve sandučiće",
+    "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
+    "Delete mailbox" : "Izbriši sandučić",
+    "Delete mailbox {name}" : "Izbriši sandučić {name}",
+    "Mark all messages of this mailbox as read" : "Označi sve poruke u ovom sandučiću kao pročitane",
+    "Add submailbox" : "Dodaj podsandučić",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
     "Actions" : "Radnje"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
