@@ -185,7 +185,7 @@ OC.L10N.register(
     "Confirm" : "Megerősítés",
     "Plain text" : "Egyszerű szöveg",
     "Rich text" : "Formázott szöveg",
-    "No messages in this mailbox" : "Nincs üzenet ebben a postafiókban",
+    "No messages in this folder" : "Nincs üzenet a mappában!",
     "No messages" : "Nincs üzenet",
     "Blind copy recipients only" : "Csak a rejtett másolatok címzettjei",
     "No subject" : "Nincs tárgy",
@@ -197,7 +197,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Emlékeztető beállítása erre a hétvégére",
     "Next week – {timeLocale}" : "Következő hét – {timeLocale}",
     "Set reminder for next week" : "Emlékeztető beállítása a következő hétre",
-    "No trash mailbox configured" : "Nincs mappa beállítva a törölt üzenetek számára",
     "Could not delete message" : "Nem sikerült törölni az üzenetet",
     "Could not archive message" : "Az üzenet archiválása sikertelen",
     "Thread was snoozed" : "Fel lett függesztve a szál/folyamat",
@@ -276,12 +275,9 @@ OC.L10N.register(
     "Add internal address" : "Belső cím hozzáadása",
     "Add internal email or domain" : "Belső e-mail vagy tartomány hozzáadása",
     "Itinerary for {type} is not supported yet" : "A(z) {type} útiterve még nem támogatott",
-    "To archive a message please configure an archive mailbox in account settings" : "Egy üzenet archiválásához állítsa be az archiváláshoz használt postafiókot a fiókbeállításokban",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nem helyezheti át ezt az üzenetet az archiválási mappába vagy törölheti a jelenlegi mappából",
-    "Could not open mailbox" : "Nem sikerült megnyitni a postaládát",
     "Loading messages …" : "Üzenetek betöltése…",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Üzenetek indexelése folyamatban. Ez a folyamat tovább tarthat a nagyobb méretű postafiókok esetén.",
-    "Choose target mailbox" : "Válasszon cél postafiókot",
+    "Choose target folder" : "Válasszon célmappát",
     "No more submailboxes in here" : "Nem találhatók további alpostafiókok",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Az üzeneteket automatikusan fontosként jelöli meg az alapján, hogy mely üzenetekre reagált, vagy jelölt meg fontosként. Kezdetben lehet, hogy kézzel megváltoztatnia a fontosságot és ezzel kell tanítania a rendszert, de ez az idő múlásával javulni fog.",
     "Follow up" : "Emlékeztető",
@@ -337,29 +333,24 @@ OC.L10N.register(
     "Provisioned account is disabled" : "A felügyelt fiók le van tiltva",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Jelentkezzen be a jelszóval, hogy engedélyezze a fiókot. A jelenlegi munkamenet jelszó nélküli hitelesítést használ, például SSO-t vagy WebAuthnt.",
     "Quota" : "Kvóta",
-    "Show only subscribed mailboxes" : "Csak a feliratkozott postafiókok megjelenítése",
-    "Add mailbox" : "Postaláda hozzáadása",
-    "Mailbox name" : "Postafiók név",
+    "Add folder" : "Könyvtár hozzáadása",
+    "Folder name" : "Mappanév",
     "Saving" : "Mentés",
     "Move up" : "Mozgatás fel",
     "Move down" : "Mozgatás le",
-    "Show all subscribed mailboxes" : "Összes feliratkozott postafiók megjelenítése",
-    "Show all mailboxes" : "Összes postafiók megjelenítése",
+    "Show all folders" : "Minden mappa megjelenítése",
     "Collapse mailboxes" : "Postaládák összecsukása",
     "_{total} message_::_{total} messages_" : ["{total} üzenet","{total} üzenet"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} olvasatlan az összesen {total} üzenetből","{unread} olvasatlan az összesen {total} üzenetből"],
     "All messages in mailbox will be deleted." : "A postaládában lévő összes üzenet végleges törlésre kerül.",
     "Clear mailbox {name}" : "A(z) {name} postaláda ürítése",
-    "Clear mailbox" : "Postaláda ürítése",
-    "The mailbox and all messages in it will be deleted." : "A postafiók és az abban található összes üzenet törlődik.",
-    "Delete mailbox" : "Fiók törlése",
-    "Delete mailbox {name}" : "A(z) {name} postafiók törlése",
+    "Delete folder" : "Mappa törlése",
     "An error occurred, unable to rename the mailbox." : "Hiba történt, nem sikerült átnevezni a postafiókot.",
     "Mark all as read" : "Összes megjelölése olvasottként",
-    "Mark all messages of this mailbox as read" : "Postafiók összes üzenetének megjelölése olvasottként",
-    "Add submailbox" : "Alpostaláda hozzáadása",
+    "Mark all messages of this folder as read" : "A mappában található összes üzenet megjelölése olvasottként",
+    "Add subfolder" : "Almappa hozzáadás",
     "Rename" : "Átnevezés",
-    "Move mailbox" : "Postaláda áthelyezése",
+    "Move folder" : "Mappa áthelyezése",
     "Clear cache" : "Gyorsítótár ürítése",
     "Clear locally cached data, in case there are issues with synchronization." : "Törölje a helyileg gyorsítótárazott adatokat, ha a szinkronizálással kapcsolatban problémák merülnének fel.",
     "Subscribed" : "Feliratkozott",
@@ -374,7 +365,6 @@ OC.L10N.register(
     "Failed to save draft" : "Nem sikerült menteni a piszkozatot",
     "attachment" : "melléklet",
     "attached" : "mellékelve",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nincs beállítva mappa az elküldött üzenetek számára. Állítson be egyet a fiókbeállításokban.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Sok címzettnek próbál küldeni a Címzett vagy a Másolat mezőben. Fontolja meg a Rejtett másolat használatát a címzettek elrejtéséhez.",
     "You mentioned an attachment. Did you forget to add it?" : "Mellékletet említett. Nem felejtette el hozzáadni?",
     "Message discarded" : "Üzenet elvetése",
@@ -407,7 +397,6 @@ OC.L10N.register(
     "Show less" : "Kevesebb megjelenítése",
     "Show more" : "Több megjelenítése",
     "Clear" : "Törlés",
-    "Search in mailbox" : "Keresés a postaládában",
     "Close" : "Bezárás",
     "Search parameters" : "Keresési paraméterek",
     "Body" : "Törzs",
@@ -645,7 +634,27 @@ OC.L10N.register(
     "The link leads to %s" : "A hivatkozás ide mutat: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarja megnyitni azt az oldalt, akkor térjen vissza a <a href=\"%s\">Levelezéshez</a>.",
     "Continue to %s" : "Folytatás ide: %s",
+    "No messages in this mailbox" : "Nincs üzenet ebben a postafiókban",
+    "No trash mailbox configured" : "Nincs mappa beállítva a törölt üzenetek számára",
     "Draft: " : "Piszkozat: ",
+    "To archive a message please configure an archive mailbox in account settings" : "Egy üzenet archiválásához állítsa be az archiváláshoz használt postafiókot a fiókbeállításokban",
+    "Could not open mailbox" : "Nem sikerült megnyitni a postaládát",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Üzenetek indexelése folyamatban. Ez a folyamat tovább tarthat a nagyobb méretű postafiókok esetén.",
+    "Choose target mailbox" : "Válasszon cél postafiókot",
+    "Show only subscribed mailboxes" : "Csak a feliratkozott postafiókok megjelenítése",
+    "Add mailbox" : "Postaláda hozzáadása",
+    "Mailbox name" : "Postafiók név",
+    "Show all subscribed mailboxes" : "Összes feliratkozott postafiók megjelenítése",
+    "Show all mailboxes" : "Összes postafiók megjelenítése",
+    "Clear mailbox" : "Postaláda ürítése",
+    "The mailbox and all messages in it will be deleted." : "A postafiók és az abban található összes üzenet törlődik.",
+    "Delete mailbox" : "Fiók törlése",
+    "Delete mailbox {name}" : "A(z) {name} postafiók törlése",
+    "Mark all messages of this mailbox as read" : "Postafiók összes üzenetének megjelölése olvasottként",
+    "Add submailbox" : "Alpostaláda hozzáadása",
+    "Move mailbox" : "Postaláda áthelyezése",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nincs beállítva mappa az elküldött üzenetek számára. Állítson be egyet a fiókbeállításokban.",
+    "Search in mailbox" : "Keresés a postaládában",
     "Actions" : "Műveletek",
     "New action" : "Új művelet"
 },
