@@ -40,7 +40,9 @@ OC.L10N.register(
     "Move" : "Mover",
     "Remove account" : "Remover conto",
     "Quota" : "Quota",
+    "Folder name" : "Nomine de dossier",
     "Saving" : "Salveguardante",
+    "Show all folders" : "Monstrar tote dossiers",
     "Rename" : "Renominar",
     "Reply" : "Responder",
     "Add" : "Adder",
