@@ -167,7 +167,7 @@ OC.L10N.register(
     "Confirm" : "Conferma",
     "Plain text" : "Testo semplice",
     "Rich text" : "Testo formattato",
-    "No messages in this mailbox" : "Nessun messaggio in questa casella di posta",
+    "No messages in this folder" : "Nessun messaggio in questa cartella",
     "No messages" : "Nessun messaggio",
     "Blind copy recipients only" : "Solo destinatari in copia nascosta",
     "No subject" : "Nessun oggetto",
@@ -179,7 +179,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Imposta promemoria per questo fine settimana",
     "Next week – {timeLocale}" : "Prossima settimana – {timeLocale}",
     "Set reminder for next week" : "Imposta promemoria per la prossima settimana",
-    "No trash mailbox configured" : "Nessuna casella del cestino configurata",
     "Could not delete message" : "Impossibile eliminare il messaggio",
     "Could not archive message" : "Impossibile archiviare il messaggio",
     "Encrypted message" : "Messaggio cifrato",
@@ -243,12 +242,9 @@ OC.L10N.register(
     "domain" : "dominio",
     "Remove" : "Rimuovi",
     "Itinerary for {type} is not supported yet" : "L'itinerario per {type} non è ancora supportato",
-    "To archive a message please configure an archive mailbox in account settings" : "Per archiviare un messaggio, configura una casella di posta archivio nelle impostazioni dell'account.",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Non ti è consentito spostare questo messaggio nella cartella degli archivi e/o eliminare questo messaggio dalla cartella corrente.",
-    "Could not open mailbox" : "Impossibile aprire la casella di posta",
     "Loading messages …" : "Caricamento messaggi...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indicizzazione dei tuoi messaggi. Può richiedere più tempo per le caselle di posta più grandi.",
-    "Choose target mailbox" : "Scegli la casella di posta di destinazione",
+    "Choose target folder" : "Scegli la cartella di destinazione",
     "No more submailboxes in here" : "Qui non ci sono altre sotto-caselle di posta",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "I messaggi saranno automaticamente contrassegnati come importanti in base ai messaggi con cui hai interagito o contrassegnati come importanti. All'inizio potresti dover cambiare manualmente l'importanza per addestrare il sistema, ma migliorerà nel tempo.",
     "Important info" : "Informazione importante",
@@ -292,24 +288,26 @@ OC.L10N.register(
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "L'account per {email} e i dati di posta elettronica memorizzati nella cache saranno rimossi da Nextcloud, ma non dal tuo fornitore di posta elettronica.",
     "Remove {email}" : "Rimuovi {email}",
     "Quota" : "Quote",
-    "Show only subscribed mailboxes" : "Mostra solo le caselle di posta sottoscritte",
-    "Add mailbox" : "Aggiungi casella di posta",
+    "Show only subscribed folders" : "Mostra solo le cartelle sottoscritte",
+    "Add folder" : "Aggiungi cartella",
+    "Folder name" : "Nome della cartella",
     "Saving" : "Salvataggio",
     "Move up" : "Sposta su",
     "Move down" : "Sposta giù",
-    "Show all subscribed mailboxes" : "Mostra tutte le caselle di posta sottoscritte",
-    "Show all mailboxes" : "Mostra tutte le caselle di posta",
+    "Show all subscribed folders" : "Mostra tutte le cartelle sottoscritte",
+    "Show all folders" : "Mostra tutte le cartelle",
     "Collapse mailboxes" : "Contrai le caselle di posta",
     "_{total} message_::_{total} messages_" : ["{total} messaggio","{total} messaggi","{total} messaggi"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non letto di {total}","{unread} non letti di {total}","{unread} non letti di {total}"],
-    "The mailbox and all messages in it will be deleted." : "La casella postale e tutti i messaggi in essa saranno eliminati.",
-    "Delete mailbox" : "Elimina casella di posta",
-    "Delete mailbox {name}" : "Elimina la casella di posta {name}",
+    "The folder and all messages in it will be deleted." : "La cartella e tutti i messaggi in essa saranno eliminati.",
+    "Delete folder" : "Elimina cartella",
+    "Delete folder {name}" : "Elimina cartella {name}",
     "An error occurred, unable to rename the mailbox." : "Si è verificato un errore, impossibile rinominare la casella di posta.",
     "Mark all as read" : "Marca tutti come letti",
-    "Mark all messages of this mailbox as read" : "Marca tutti i messaggi di questa casella di posta come letti",
-    "Add submailbox" : "Aggiungi sotto-casella di posta",
+    "Mark all messages of this folder as read" : "Marca tutti i messaggi di questa cartella come letti",
+    "Add subfolder" : "Aggiungi sottocartella",
     "Rename" : "Rinomina",
+    "Move folder" : "Sposta cartella",
     "Clear cache" : "Svuota cache",
     "Clear locally cached data, in case there are issues with synchronization." : "Cancella i dati locali in cache, nel caso ci siano problemi di sincronizzazione.",
     "Subscribed" : "Sottoscritta",
@@ -324,7 +322,6 @@ OC.L10N.register(
     "Failed to save draft" : "Impossibile salvare la bozza",
     "attachment" : "allegato",
     "attached" : "allegato",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nessuna casella di posta inviata configurata. Scegline una nelle impostazioni dell'account.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Stai tentando di inviare a troppi destinatari in A e/o CC. Considera l'idea di utilizzare CCN per nascondere gli indirizzi dei destinatari.",
     "You mentioned an attachment. Did you forget to add it?" : "Hai menzionato un allegato. Hai dimenticato di aggiungerlo?",
     "Message discarded" : "Messaggio scartato",
@@ -351,7 +348,6 @@ OC.L10N.register(
     "Show less" : "Mostra meno",
     "Show more" : "Mostra più",
     "Clear" : "Pulisci",
-    "Search in mailbox" : "Cerca nella casella di posta",
     "Close" : "Chiudi",
     "Search parameters" : "Parametri di ricerca",
     "Search subject" : "Cerca nell'oggetto",
@@ -554,7 +550,24 @@ OC.L10N.register(
     "Redirect" : "Redirigi",
     "The link leads to %s" : "Il collegamento conduce a %s",
     "Continue to %s" : "Continua su %s",
+    "No messages in this mailbox" : "Nessun messaggio in questa casella di posta",
+    "No trash mailbox configured" : "Nessuna casella del cestino configurata",
     "Draft: " : "Bozza:",
+    "To archive a message please configure an archive mailbox in account settings" : "Per archiviare un messaggio, configura una casella di posta archivio nelle impostazioni dell'account.",
+    "Could not open mailbox" : "Impossibile aprire la casella di posta",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indicizzazione dei tuoi messaggi. Può richiedere più tempo per le caselle di posta più grandi.",
+    "Choose target mailbox" : "Scegli la casella di posta di destinazione",
+    "Show only subscribed mailboxes" : "Mostra solo le caselle di posta sottoscritte",
+    "Add mailbox" : "Aggiungi casella di posta",
+    "Show all subscribed mailboxes" : "Mostra tutte le caselle di posta sottoscritte",
+    "Show all mailboxes" : "Mostra tutte le caselle di posta",
+    "The mailbox and all messages in it will be deleted." : "La casella postale e tutti i messaggi in essa saranno eliminati.",
+    "Delete mailbox" : "Elimina casella di posta",
+    "Delete mailbox {name}" : "Elimina la casella di posta {name}",
+    "Mark all messages of this mailbox as read" : "Marca tutti i messaggi di questa casella di posta come letti",
+    "Add submailbox" : "Aggiungi sotto-casella di posta",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nessuna casella di posta inviata configurata. Scegline una nelle impostazioni dell'account.",
+    "Search in mailbox" : "Cerca nella casella di posta",
     "Actions" : "Azioni"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
