@@ -100,7 +100,6 @@ OC.L10N.register(
     "Sieve script editor" : "Sieveスクリプトエディタ",
     "Mail server" : "メールサーバー",
     "Sieve server" : "Sieveサーバー",
-    "Mailbox search" : "メールボックスの検索",
     "Update alias" : "エイリアスを更新する",
     "Rename alias" : "エイリアスの名前を変更する",
     "Show update alias form" : "エイリアスの更新フォームを表示する",
@@ -231,7 +230,7 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "全てのメッセージからタグが削除されました",
     "Plain text" : "プレーンテキスト",
     "Rich text" : "リッチテキスト",
-    "No messages in this mailbox" : "このメールボックスにメッセージはありません",
+    "No messages in this folder" : "このフォルダーにメッセージはありません",
     "No messages" : "メッセージはありません",
     "Blind copy recipients only" : "BCC受信者のみ",
     "No subject" : "件名無し",
@@ -243,7 +242,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "今週末のリマインダーを設定する",
     "Next week – {timeLocale}" : "来週 – {timeLocale}",
     "Set reminder for next week" : "来週のリマインダーを設定する",
-    "No trash mailbox configured" : "ゴミ箱メールボックスが設定されていません",
     "Could not delete message" : "メッセージを削除できませんでした",
     "Could not archive message" : "メッセージをアーカイブすることができませんでした",
     "Thread was snoozed" : "スレッドがスヌーズされました",
@@ -323,12 +321,9 @@ OC.L10N.register(
     "Add internal address" : "内部アドレスを追加する",
     "Add internal email or domain" : "内部のメールアドレスまたはドメインを追加する",
     "Itinerary for {type} is not supported yet" : "{type} タイプの旅程はまだサポートされていません",
-    "To archive a message please configure an archive mailbox in account settings" : "メッセージをアーカイブするためにはアカウント設定からアーカイブメールボックスの設定をしてください",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "このメッセージをアーカイブフォルダに移動したり、現在のフォルダから削除するは許可されていません",
-    "Could not open mailbox" : "メールボックスを開けませんでした",
     "Loading messages …" : "メッセージの読み込み中…",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "メールをインデックスしています。大きいメールボックスの場合はしばらくお待ちください。",
-    "Choose target mailbox" : "対象のメールボックスを選択してください",
+    "Choose target folder" : "ターゲットフォルダーを選択",
     "No more submailboxes in here" : "サブメールボックスはありません",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "あなたの過去の操作を元にしてメールには自動的に重要マークがつけられます。最初のうちは重要マークを手動でつけたり外したりしてシステムに重要なメールを教える必要がありますが、精度は徐々に向上します。",
     "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "返信が必要なメッセージを送信したが、数日経っても返信がない場合は、ここに表示されます。",
@@ -390,31 +385,27 @@ OC.L10N.register(
     "Provisioned account is disabled" : "プロビジョニングされたアカウントは無効です",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "このアカウントを有効にするには、パスワードを使ってログインしてください。現在のセッションはシングルサインオンやWebAuthnなどのパスワードレス認証を使用しています。",
     "Quota" : "クオータ",
-    "Show only subscribed mailboxes" : "購読したメールボックスのみ表示",
-    "Add mailbox" : "メールボックスを追加",
-    "Mailbox name" : "メールボックス名",
+    "Show only subscribed folders" : "登録されているフォルダーのみ表示",
+    "Add folder" : "フォルダーを追加",
+    "Folder name" : "フォルダー名",
     "Saving" : "保存しています",
     "Move up" : "上に移動",
     "Move down" : "下に移動",
-    "Show all subscribed mailboxes" : "購読したメールボックスを全て表示",
-    "Show all mailboxes" : "全てのメールボックスを表示",
+    "Show all subscribed folders" : "登録されているフォルダーを全て表示",
+    "Show all folders" : "すべてのフォルダーを表示",
     "Collapse mailboxes" : "メールボックスを非表示",
     "_{total} message_::_{total} messages_" : ["{total} メッセージ"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} メッセージの内 {unread} 件が未開封"],
     "All messages in mailbox will be deleted." : "メールボックスにある全てのメッセージが削除されます。",
     "Clear mailbox {name}" : "メールボックス{name}を削除する",
-    "Clear mailbox" : "メールボックスをクリアする",
-    "The mailbox and all messages in it will be deleted." : "メールボックスと中にある全てのメッセージが削除されます。",
-    "Delete mailbox" : "メールボックスを削除",
-    "Delete mailbox {name}" : "メールボックス「{name}」を削除",
+    "Delete folder" : "フォルダーを削除",
     "An error occurred, unable to rename the mailbox." : "エラー:メールボックスの名前を変更できませんでした。",
     "Please wait 10 minutes before repairing again" : "再度修復する前に10分間お待ちください。",
     "Mark all as read" : "すべて既読にする",
-    "Mark all messages of this mailbox as read" : "このフォルダのすべてのメッセージを開封済みにする",
-    "Add submailbox" : "サブメールボックスを追加",
+    "Mark all messages of this folder as read" : "このフォルダのすべてのメッセージを開封済みにする",
+    "Add subfolder" : "サブフォルダを追加",
     "Rename" : "名前を変更",
-    "Move mailbox" : "メールボックスを移動する",
-    "Repair mailbox" : "メールボックスを修復する",
+    "Move folder" : "フォルダーを移動",
     "Clear cache" : "キャッシュをクリア",
     "Clear locally cached data, in case there are issues with synchronization." : "同期の問題を解消を解消するために、ローカルにキャッシュされたデータを消去",
     "Subscribed" : "購読",
@@ -429,7 +420,6 @@ OC.L10N.register(
     "Failed to save draft" : "下書き保存が失敗しました",
     "attachment" : "アタッチメント",
     "attached" : "添付",
-    "No sent mailbox configured. Please pick one in the account settings." : "送信済みのメールボックスはまだ設定されていません。アカウント設定から設定してください",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "ToやCcで多くの受信者に送信しようとしています。受信者のアドレスを隠すためにBccを使用することを検討してください。",
     "You mentioned an attachment. Did you forget to add it?" : "添付ファイルがあると言及しました。追加するのを忘れましたか？",
     "Message discarded" : "メッセージは破棄されました",
@@ -453,12 +443,9 @@ OC.L10N.register(
     "Save autoresponder" : "自動応答を保存する",
     "Could not open outbox" : "送信トレイを開けませんでした",
     "Pending or not sent messages will show up here" : "保留中または未送信のメッセージはここに表示されます",
-    "Could not copy to \"Sent\" mailbox" : "\"送信済み\"メールボックスにコピーできませんでした",
     "Mail server error" : "メールサーバーエラー",
     "Message could not be sent" : "メッセージを送信できませんでした",
     "Message deleted" : "メッセージを削除しました",
-    "Copy to \"Sent\" Mailbox" : "「送信済み」メールボックスにコピー",
-    "Copy to Sent Mailbox" : "送信済みのメールボックスにコピーする",
     "Phishing email" : "フィッシングメール",
     "This email might be a phishing attempt" : "このメールはフィッシングの可能性があります",
     "Hide suspicious links" : "不審なリンクを隠す",
@@ -475,7 +462,6 @@ OC.L10N.register(
     "Show less" : "表示を減らす",
     "Show more" : "表示を増やす",
     "Clear" : "クリア",
-    "Search in mailbox" : "メールボックス内の検索",
     "Close" : "閉じる",
     "Search parameters" : "パラメータを検索する",
     "Search subject" : "件名を検索する",
@@ -751,8 +737,6 @@ OC.L10N.register(
     "Could not create snooze mailbox" : "スヌーズメールボックスを作成できませんでした",
     "Message sent" : "メッセージ送信済",
     "Could not send message" : "メッセージを送信できませんでした",
-    "Message copied to \"Sent\" mailbox" : "メッセージが\"送信済み\"メールボックスにコピーされました",
-    "Could not copy message to \"Sent\" mailbox" : "メッセージを”送信済み”メールボックスにコピーできませんでした",
     "Could not load {tag}{name}{endtag}" : "{tag} {name} {endtag}を読み込めませんでした",
     "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag} の読み込み中に問題が発生しました",
     "Could not load your message" : "あなたのメッセージを読み込めませんでした",
@@ -765,12 +749,39 @@ OC.L10N.register(
     "The link leads to %s" : "リンクが %s につながります",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ページにアクセスしたくない場合は、<a href=\"%s\">メール</a>に戻ることができます",
     "Continue to %s" : "%s にリダイレクトする",
+    "Mailbox search" : "メールボックスの検索",
+    "No messages in this mailbox" : "このメールボックスにメッセージはありません",
+    "No trash mailbox configured" : "ゴミ箱メールボックスが設定されていません",
     "Draft: " : "下書き",
+    "To archive a message please configure an archive mailbox in account settings" : "メッセージをアーカイブするためにはアカウント設定からアーカイブメールボックスの設定をしてください",
+    "Could not open mailbox" : "メールボックスを開けませんでした",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "メールをインデックスしています。大きいメールボックスの場合はしばらくお待ちください。",
+    "Choose target mailbox" : "対象のメールボックスを選択してください",
+    "Show only subscribed mailboxes" : "購読したメールボックスのみ表示",
+    "Add mailbox" : "メールボックスを追加",
+    "Mailbox name" : "メールボックス名",
+    "Show all subscribed mailboxes" : "購読したメールボックスを全て表示",
+    "Show all mailboxes" : "全てのメールボックスを表示",
+    "Clear mailbox" : "メールボックスをクリアする",
+    "The mailbox and all messages in it will be deleted." : "メールボックスと中にある全てのメッセージが削除されます。",
+    "Delete mailbox" : "メールボックスを削除",
+    "Delete mailbox {name}" : "メールボックス「{name}」を削除",
+    "Mark all messages of this mailbox as read" : "このフォルダのすべてのメッセージを開封済みにする",
+    "Add submailbox" : "サブメールボックスを追加",
+    "Move mailbox" : "メールボックスを移動する",
+    "Repair mailbox" : "メールボックスを修復する",
+    "No sent mailbox configured. Please pick one in the account settings." : "送信済みのメールボックスはまだ設定されていません。アカウント設定から設定してください",
+    "Could not copy to \"Sent\" mailbox" : "\"送信済み\"メールボックスにコピーできませんでした",
+    "Copy to \"Sent\" Mailbox" : "「送信済み」メールボックスにコピー",
+    "Copy to Sent Mailbox" : "送信済みのメールボックスにコピーする",
+    "Search in mailbox" : "メールボックス内の検索",
     "If all tests pass, then the actions will be executed" : "すべてのテストがパスすれば、アクションが実行されます",
     "If one test pass, then the actions will be executed" : "テストが1つでもパスすれば、アクションが実行されます",
     "Tests" : "テスト",
     "New test" : "新しいテスト",
     "Actions" : "アクション",
-    "New action" : "新しいアクション"
+    "New action" : "新しいアクション",
+    "Message copied to \"Sent\" mailbox" : "メッセージが\"送信済み\"メールボックスにコピーされました",
+    "Could not copy message to \"Sent\" mailbox" : "メッセージを”送信済み”メールボックスにコピーできませんでした"
 },
 "nplurals=1; plural=0;");
