@@ -84,7 +84,6 @@ OC.L10N.register(
     "Autoresponder" : "Autoresponder",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days.",
     "Mail server" : "Mail server",
-    "Mailbox search" : "Mailbox search",
     "Update alias" : "Update alias",
     "Rename alias" : "Rename alias",
     "Show update alias form" : "Show update alias form",
@@ -196,7 +195,6 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "The tag will be deleted from all messages.",
     "Plain text" : "Plain text",
     "Rich text" : "Rich text",
-    "No messages in this mailbox" : "No messages in this mailbox",
     "No messages" : "No messages",
     "Blind copy recipients only" : "Blind copy recipients only",
     "No subject" : "No subject",
@@ -208,7 +206,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Set reminder for this weekend",
     "Next week – {timeLocale}" : "Next week – {timeLocale}",
     "Set reminder for next week" : "Set reminder for next week",
-    "No trash mailbox configured" : "No trash mailbox configured",
     "Could not delete message" : "Could not delete message",
     "Could not archive message" : "Could not archive message",
     "Thread was snoozed" : "Thread was snoozed",
@@ -283,12 +280,9 @@ OC.L10N.register(
     "Remove" : "Remove",
     "email" : "email",
     "Itinerary for {type} is not supported yet" : "Itinerary for {type} is not supported yet",
-    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
-    "Could not open mailbox" : "Could not open mailbox",
     "Loading messages …" : "Loading messages …",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexing your messages. This can take a bit longer for larger mailboxes.",
-    "Choose target mailbox" : "Choose target mailbox",
+    "Choose target folder" : "Choose target folder",
     "No more submailboxes in here" : "No more submailboxes in here",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
     "Important info" : "Important info",
@@ -342,29 +336,19 @@ OC.L10N.register(
     "Provisioned account is disabled" : "Provisioned account is disabled",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn.",
     "Quota" : "Quota",
-    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
-    "Add mailbox" : "Add mailbox",
-    "Mailbox name" : "Mailbox name",
+    "Folder name" : "Folder name",
     "Saving" : "Saving",
     "Move up" : "Move up",
     "Move down" : "Move down",
-    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
-    "Show all mailboxes" : "Show all mailboxes",
     "Collapse mailboxes" : "Collapse mailboxes",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
     "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
     "Clear mailbox {name}" : "Clear mailbox {name}",
-    "Clear mailbox" : "Clear mailbox",
-    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
-    "Delete mailbox" : "Delete mailbox",
-    "Delete mailbox {name}" : "Delete mailbox {name}",
+    "Delete folder" : "Delete folder",
     "An error occurred, unable to rename the mailbox." : "An error occurred, unable to rename the mailbox.",
     "Mark all as read" : "Mark all as read",
-    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
-    "Add submailbox" : "Add submailbox",
     "Rename" : "Rename",
-    "Move mailbox" : "Move mailbox",
     "Clear cache" : "Clear cache",
     "Clear locally cached data, in case there are issues with synchronization." : "Clear locally cached data, in case there are issues with synchronization.",
     "Subscribed" : "Subscribed",
@@ -379,7 +363,6 @@ OC.L10N.register(
     "Failed to save draft" : "Failed to save draft",
     "attachment" : "attachment",
     "attached" : "attached",
-    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses.",
     "You mentioned an attachment. Did you forget to add it?" : "You mentioned an attachment. Did you forget to add it?",
     "Message discarded" : "Message discarded",
@@ -415,7 +398,6 @@ OC.L10N.register(
     "Show less" : "Show less",
     "Show more" : "Show more",
     "Clear" : "Clear",
-    "Search in mailbox" : "Search in mailbox",
     "Close" : "Close",
     "Search parameters" : "Search parameters",
     "Search subject" : "Search subject",
@@ -653,7 +635,28 @@ OC.L10N.register(
     "The link leads to %s" : "The link leads to %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Continue to %s",
+    "Mailbox search" : "Mailbox search",
+    "No messages in this mailbox" : "No messages in this mailbox",
+    "No trash mailbox configured" : "No trash mailbox configured",
     "Draft: " : "Draft: ",
+    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
+    "Could not open mailbox" : "Could not open mailbox",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexing your messages. This can take a bit longer for larger mailboxes.",
+    "Choose target mailbox" : "Choose target mailbox",
+    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
+    "Add mailbox" : "Add mailbox",
+    "Mailbox name" : "Mailbox name",
+    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
+    "Show all mailboxes" : "Show all mailboxes",
+    "Clear mailbox" : "Clear mailbox",
+    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
+    "Delete mailbox" : "Delete mailbox",
+    "Delete mailbox {name}" : "Delete mailbox {name}",
+    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
+    "Add submailbox" : "Add submailbox",
+    "Move mailbox" : "Move mailbox",
+    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
+    "Search in mailbox" : "Search in mailbox",
     "Actions" : "Actions"
 },
 "nplurals=2; plural=(n!=1);");
