@@ -80,7 +80,10 @@ OC.L10N.register(
     "Move" : "გადატანა",
     "Remove account" : "ანგარიშის გაუქმება",
     "Quota" : "კვოტა",
+    "Folder name" : "დირექტორიის სახელი",
     "Saving" : "მიმდინარეობს შენახვა",
+    "Show all folders" : "ყველა დირექტორიის ჩვენება",
+    "Delete folder" : "ფოლდერის წაშლა",
     "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
     "Rename" : "სახელის შეცვლა",
     "Clear cache" : "კეშის გასუფთავება",
