@@ -83,7 +83,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "수신 메시지에 대한 자동 응답입니다. 메시지를 수신한 경우, 이 자동 응답이 최대 4일에 한 번 해당 발신자에게 발송됩니다.",
     "Filters" : "필터",
     "Mail server" : "메일 서버",
-    "Mailbox search" : "편지함 검색",
     "Update alias" : "별칭 갱신",
     "Rename alias" : "별칭 변경",
     "Show update alias form" : "별칭 양식 갱신 표시",
@@ -191,7 +190,7 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "태그가 모든 메시지로부터 삭제됩니다.",
     "Plain text" : "평문",
     "Rich text" : "서식 있는 텍스트",
-    "No messages in this mailbox" : "이 편지함에 메시지가 없음",
+    "No messages in this folder" : "이 폴더에 메시지가 없음",
     "No messages" : "메시지가 없음",
     "No subject" : "제목 없음",
     "Later today – {timeLocale}" : "오늘 나중 – {timeLocale}",
@@ -202,7 +201,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "알림을 주말로 설정",
     "Next week – {timeLocale}" : "다음주 – {timeLocale}",
     "Set reminder for next week" : "알림을 다음주로 설정",
-    "No trash mailbox configured" : "휴지통 편지함이 설정되지 않음",
     "Could not delete message" : "메시지를 삭제할 수 없음",
     "Could not archive message" : "메시지를 보관할 수 없음",
     "Thread was snoozed" : "쓰레드가 다시 알림 설정됨",
@@ -276,12 +274,9 @@ OC.L10N.register(
     "domain" : "도메인",
     "Remove" : "삭제",
     "email" : "이메일",
-    "To archive a message please configure an archive mailbox in account settings" : "메일을 보관하기 위해서는 계정 설정에서 보관 편지함을 설정하십시오",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "이 메시지를 보관 폴더로 옮기거나 현재 폴더에서 삭제할 수 없습니다",
-    "Could not open mailbox" : "편지함을 열 수 없음",
     "Loading messages …" : "메시지를 불러오는 중 ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "메시지를 색인 중입니다. 편지함이 클 경우 오래 걸릴 수 있습니다.",
-    "Choose target mailbox" : "대상 편지함 선택",
+    "Choose target folder" : "폴더 선택",
     "No more submailboxes in here" : "더 이상의 하위 편지함 없음",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "사용자의 메시지 상호작용, 중요 표시 정보 등을 바탕으로 특정 메시지가 자동으로 중요 표시됩니다. 초기 단계에서는 시스템의 학습을 위해 사용자가 중요 여부를 수동으로 변경하게 될 수 있으나, 이는 점차 개선될 것입니다.",
     "Important info" : "중요 정보",
@@ -333,29 +328,25 @@ OC.L10N.register(
     "Provisioned account is disabled" : "프로비전된 계정을 비활성화 했습니다",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "이 계정을 활성화 하기 위해 암호를 사용하여 로그인 하십시오. 현재 세션은 무암호 인증을 사용하고 있습니다. 예) SSO, WebAuthn",
     "Quota" : "할당량",
-    "Show only subscribed mailboxes" : "구독 중인 편지함만 표시",
-    "Add mailbox" : "편지함 추가",
-    "Mailbox name" : "편지함 이름",
+    "Add folder" : "폴더 추가",
+    "Folder name" : "폴더 이름",
     "Saving" : "저장 중",
     "Move up" : "위로 이동",
     "Move down" : "아래로 이동",
-    "Show all subscribed mailboxes" : "구독 중인 모든 편지함 표시",
-    "Show all mailboxes" : "모든 편지함 표시",
+    "Show all subscribed folders" : "구독 폴더 모두 표시",
+    "Show all folders" : "모든 폴더 보기",
     "Collapse mailboxes" : "편지함 접기",
     "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 개 중 {unread} 개 읽지 않음"],
     "All messages in mailbox will be deleted." : "편지함에 있는 모든 메시지가 삭제됩니다",
     "Clear mailbox {name}" : "편지함 {name} 비우기",
-    "Clear mailbox" : "편지함 비우기",
-    "The mailbox and all messages in it will be deleted." : "편지함과 해당 편지함의 모든 메시지가 삭제됩니다",
-    "Delete mailbox" : "편지함 삭제",
-    "Delete mailbox {name}" : "편지함 {name} 비우기",
+    "Delete folder" : "폴더 삭제",
+    "Delete folder {name}" : "{name} 폴더 삭제",
     "An error occurred, unable to rename the mailbox." : "오류가 발생하여 편지함의 이름을 변경할 수 없습니다.",
     "Mark all as read" : "모두 읽은 것으로 표시",
-    "Mark all messages of this mailbox as read" : "편지함에 있는 모든 메시지를 읽음 처리하기",
-    "Add submailbox" : "하위 편지함 추가",
+    "Add subfolder" : "하위 폴더 추가",
     "Rename" : "이름 바꾸기",
-    "Move mailbox" : "편지함 이동",
+    "Move folder" : "폴더 이동",
     "Clear cache" : "Clear cache",
     "Clear locally cached data, in case there are issues with synchronization." : "동기화 관련 문제가 발생했을 경우 로컬에서 캐시된 데이터를 비우십시오.",
     "Subscribed" : "구독함",
@@ -370,7 +361,6 @@ OC.L10N.register(
     "Failed to save draft" : "초안을 저장할 수 없음",
     "attachment" : "첨부파일",
     "attached" : "첨부됨",
-    "No sent mailbox configured. Please pick one in the account settings." : "보낸 편지함이 설정되지 않았습니다. 계정 설정에서 지정하십시오.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "다수의 수신자와 참조에게 메시지를 발신하려고 합니다. 수신자 주소를 숨기기 위해 Bcc 사용을 고려하십시오.",
     "You mentioned an attachment. Did you forget to add it?" : "메시지에서 첨부파일을 언급했습니다. 첨부 여부를 확인하셨습니까?",
     "Message discarded" : "메시지 폐기됨",
@@ -404,7 +394,6 @@ OC.L10N.register(
     "Show less" : "적게 보기",
     "Show more" : "더 보기",
     "Clear" : "비우기",
-    "Search in mailbox" : "편지함에서 검색",
     "Close" : "닫기",
     "Search parameters" : "검색 인자",
     "Search subject" : "제목 검색",
@@ -644,7 +633,28 @@ OC.L10N.register(
     "The link leads to %s" : "이 링크가 %s을(를) 향함",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
     "Continue to %s" : "%s(으)로 이동",
+    "Mailbox search" : "편지함 검색",
+    "No messages in this mailbox" : "이 편지함에 메시지가 없음",
+    "No trash mailbox configured" : "휴지통 편지함이 설정되지 않음",
     "Draft: " : "초안:",
+    "To archive a message please configure an archive mailbox in account settings" : "메일을 보관하기 위해서는 계정 설정에서 보관 편지함을 설정하십시오",
+    "Could not open mailbox" : "편지함을 열 수 없음",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "메시지를 색인 중입니다. 편지함이 클 경우 오래 걸릴 수 있습니다.",
+    "Choose target mailbox" : "대상 편지함 선택",
+    "Show only subscribed mailboxes" : "구독 중인 편지함만 표시",
+    "Add mailbox" : "편지함 추가",
+    "Mailbox name" : "편지함 이름",
+    "Show all subscribed mailboxes" : "구독 중인 모든 편지함 표시",
+    "Show all mailboxes" : "모든 편지함 표시",
+    "Clear mailbox" : "편지함 비우기",
+    "The mailbox and all messages in it will be deleted." : "편지함과 해당 편지함의 모든 메시지가 삭제됩니다",
+    "Delete mailbox" : "편지함 삭제",
+    "Delete mailbox {name}" : "편지함 {name} 비우기",
+    "Mark all messages of this mailbox as read" : "편지함에 있는 모든 메시지를 읽음 처리하기",
+    "Add submailbox" : "하위 편지함 추가",
+    "Move mailbox" : "편지함 이동",
+    "No sent mailbox configured. Please pick one in the account settings." : "보낸 편지함이 설정되지 않았습니다. 계정 설정에서 지정하십시오.",
+    "Search in mailbox" : "편지함에서 검색",
     "Actions" : "동작"
 },
 "nplurals=1; plural=0;");
