@@ -154,7 +154,7 @@ OC.L10N.register(
     "An error occurred, unable to delete the tag." : "Įvyko klaida, nepavyko ištrinti žymos.",
     "Plain text" : "Grynasis tekstas",
     "Rich text" : "Raiškusis tekstas",
-    "No messages in this mailbox" : "Šioje pašto dėžutėje laiškų nėra",
+    "No messages in this folder" : "Šiame aplanke laiškų nėra",
     "No messages" : "Nėra laiškų",
     "No subject" : "Be temos",
     "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
@@ -208,9 +208,8 @@ OC.L10N.register(
     "Remove" : "Šalinti",
     "email" : "elektroninis paštas",
     "Add internal address" : "Pridėti vidinį adresą",
-    "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
     "Loading messages …" : "Įkeliami laiškai…",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksuojami jūsų laiškai. Didelėse pašto dėžutėse tai gali užtrukti šiek tiek ilgiau.",
+    "Choose target folder" : "Pasirinkite paskirties aplanką",
     "Important info" : "Svarbi informacija",
     "Other" : "Kita",
     "The sender of this message has asked to be notified when you read this message." : "Šio laiško siuntėjas paprašė, kad jam būtų pranešta, kai perskaitysite šį laišką.",
@@ -249,28 +248,28 @@ OC.L10N.register(
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Paskyra {email} ir podėlyje esantys el. pašto duomenys bus pašalinti iš Nextcloud, tačiau nebus pašalinti iš jūsų el. pašto teikėjo puslapio.",
     "Remove {email}" : "Šalinti {email}",
     "Quota" : "Leidžiamas duomenų kiekis",
-    "Show only subscribed mailboxes" : "Rodyti tik prenumeruotas pašto dėžutes",
-    "Add mailbox" : "Pridėti pašto dėžutę",
-    "Mailbox name" : "Pašto dėžutės pavadinimas",
+    "Show only subscribed folders" : "Rodyti tik prenumeruotus aplankus",
+    "Add folder" : "Pridėti aplanką",
+    "Folder name" : "Aplanko pavadinimas",
     "Saving" : "Įrašoma",
     "Move up" : "Pakelti",
     "Move down" : "Nuleisti",
-    "Show all subscribed mailboxes" : "Rodyti visas prenumeruotas pašto dėžutes",
-    "Show all mailboxes" : "Rodyti visas pašto dėžutes",
+    "Show all subscribed folders" : "Rodyti visus prenumeruotus aplankus",
+    "Show all folders" : "Rodyti visus aplankus",
     "Collapse mailboxes" : "Suskleisti pašto dėžutes",
     "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
     "All messages in mailbox will be deleted." : "Visi pašto dėžutėje esantys laiškai bus ištrinti.",
     "Clear mailbox {name}" : "Išvalyti pašto dėžutę {name}",
-    "Clear mailbox" : "Išvalyti pašto dėžutę",
-    "The mailbox and all messages in it will be deleted." : "Pašto dėžutė ir visi joje esantys laiškai bus ištrinti.",
-    "Delete mailbox" : "Ištrinti pašto dėžutę",
-    "Delete mailbox {name}" : "Ištrinti pašto dėžutę {name}",
+    "The folder and all messages in it will be deleted." : "Aplankas ir visi jame esantys laiškai bus ištrinti.",
+    "Delete folder" : "Ištrinti aplanką",
+    "Delete folder {name}" : "Ištrinti aplanką {name}",
     "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
     "Mark all as read" : "Žymėti visus kaip skaitytus",
-    "Mark all messages of this mailbox as read" : "Žymėti visus laiškus šioje pašto dėžutėje kaip skaitytus",
+    "Mark all messages of this folder as read" : "Žymėti visus laiškus šiame aplanke kaip skaitytus",
+    "Add subfolder" : "Pridėti poaplankį",
     "Rename" : "Pervadinti",
-    "Move mailbox" : "Perkelti pašto dėžutę",
+    "Move folder" : "Perkelti aplanką",
     "Clear cache" : "Išvalyti podėlį",
     "Subscribed" : "Prenumeruotas",
     "Sync in background" : "Sinchronizuoti fone",
@@ -307,7 +306,6 @@ OC.L10N.register(
     "Show less" : "Rodyti mažiau",
     "Show more" : "Rodyti daugiau",
     "Clear" : "Išvalyti",
-    "Search in mailbox" : "Ieškoti pašto dėžutėje",
     "Close" : "Užverti",
     "Date" : "Data",
     "Tags" : "Žymos",
@@ -442,7 +440,22 @@ OC.L10N.register(
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
     "Continue to %s" : "Tęsti į %s",
+    "No messages in this mailbox" : "Šioje pašto dėžutėje laiškų nėra",
     "Draft: " : "Juodraštis: ",
+    "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksuojami jūsų laiškai. Didelėse pašto dėžutėse tai gali užtrukti šiek tiek ilgiau.",
+    "Show only subscribed mailboxes" : "Rodyti tik prenumeruotas pašto dėžutes",
+    "Add mailbox" : "Pridėti pašto dėžutę",
+    "Mailbox name" : "Pašto dėžutės pavadinimas",
+    "Show all subscribed mailboxes" : "Rodyti visas prenumeruotas pašto dėžutes",
+    "Show all mailboxes" : "Rodyti visas pašto dėžutes",
+    "Clear mailbox" : "Išvalyti pašto dėžutę",
+    "The mailbox and all messages in it will be deleted." : "Pašto dėžutė ir visi joje esantys laiškai bus ištrinti.",
+    "Delete mailbox" : "Ištrinti pašto dėžutę",
+    "Delete mailbox {name}" : "Ištrinti pašto dėžutę {name}",
+    "Mark all messages of this mailbox as read" : "Žymėti visus laiškus šioje pašto dėžutėje kaip skaitytus",
+    "Move mailbox" : "Perkelti pašto dėžutę",
+    "Search in mailbox" : "Ieškoti pašto dėžutėje",
     "Actions" : "Veiksmai",
     "New action" : "Naujas veiksmas"
 },
