@@ -161,7 +161,7 @@ OC.L10N.register(
     "Confirm" : "Потврди",
     "Plain text" : "Обичен текст",
     "Rich text" : "Богат текст",
-    "No messages in this mailbox" : "Нема пораки во ова сандаче",
+    "No messages in this folder" : "Нема пораки во оваа папка",
     "No messages" : "Нема пораки",
     "Blind copy recipients only" : "Само приматели на слепи копии",
     "No subject" : "Нема наслов",
@@ -171,7 +171,6 @@ OC.L10N.register(
     "Set reminder for tomorrow" : "Постави потсетник за утре",
     "Set reminder for this weekend" : "Постави потсетник за овој викенд",
     "Set reminder for next week" : "Постави потсетник за наредната недела",
-    "No trash mailbox configured" : "Нема конфигурирано сандаче за отпадоци",
     "Could not delete message" : "Неможе да се избрише пораката",
     "This message is unread" : "Оваа порака не е прочитана",
     "Favorite" : "Омилени",
@@ -216,10 +215,8 @@ OC.L10N.register(
     "Remove" : "Отстрани ",
     "email" : "е-пошта",
     "Itinerary for {type} is not supported yet" : "Итинерар за {type} сеуште не е поддржан",
-    "Could not open mailbox" : "Неможе да се отвори сандачето",
     "Loading messages …" : "Вчитување пораки ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Индексирање на пораките. Ова може да трае многу долго за големи сандачиња.",
-    "Choose target mailbox" : "Изберете дојдовно сандаче",
+    "Choose target folder" : "Избери папка",
     "No more submailboxes in here" : "Нема повеќе подсандачиња тука",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Пораките автоматски ќе бидат означени како важни врз основа на кои пораки сте комуницирале или сте ги означиле како важни. На почетокот можеби ќе треба рачно да ја менувате важноста да го научите системот, но тоа ќе се подобрува со текот на времето.",
     "Important info" : "Важна информација",
@@ -261,27 +258,26 @@ OC.L10N.register(
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Сметката за {email} и зачуваните податоци ќе бидат избришани, но нема да бидат избришани од провајдерот на електронската пошта.",
     "Remove {email}" : "Одстрани {email}",
     "Quota" : "Квота",
-    "Show only subscribed mailboxes" : "Прикажи само претплатени сандачиња",
-    "Add mailbox" : "Додади сандаче",
+    "Show only subscribed folders" : "Прикажи само претплатени папки",
+    "Add folder" : "Додади папка",
+    "Folder name" : "Име на папка",
     "Saving" : "Зачувува",
     "Move up" : "Помести горе",
     "Move down" : "Помести доле",
-    "Show all subscribed mailboxes" : "Прикажи ги сите сандачиња со претплата",
-    "Show all mailboxes" : "Прикажи ги сите сандачиња",
+    "Show all subscribed folders" : "Прикажи ги сите претплатени папки",
+    "Show all folders" : "Прикажи ги сите папки",
     "Collapse mailboxes" : "Сокриј сандачиња",
     "_{total} message_::_{total} messages_" : ["{total} порака","{total} пораки"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитани од {total}"],
     "Clear mailbox {name}" : "Исчисти сандаче {name}",
-    "Clear mailbox" : "Исчисти сандаче",
-    "The mailbox and all messages in it will be deleted." : "Сандачето и сеите пораки во него ќе бидат избришани.",
-    "Delete mailbox" : "Избриши сандаче",
-    "Delete mailbox {name}" : "Избриши сандаче {name}",
+    "The folder and all messages in it will be deleted." : "Папката и сите пораки во неа ќе бидат избришани.",
+    "Delete folder" : "Избриши папка",
+    "Delete folder {name}" : "Избриши папка {name}",
     "An error occurred, unable to rename the mailbox." : "Настана грешка, неможе да се промени името на сандачето.",
     "Mark all as read" : "Означи ги сите како прочитани",
-    "Mark all messages of this mailbox as read" : "Означи ги како прочитани сите пораки од ова сандаче ",
-    "Add submailbox" : "Додади подсандаче",
+    "Mark all messages of this folder as read" : "Означи ги сите пораки во оваа папка како прочитани",
+    "Add subfolder" : "Додади подпапка",
     "Rename" : "Преименувај",
-    "Move mailbox" : "Премести сандаче",
     "Clear cache" : "Избриши го кешот",
     "Clear locally cached data, in case there are issues with synchronization." : "Исчистете ги локално зачуваните податоци, во случај да има проблеми со синхронизацијата.",
     "Subscribed" : "Претплатени",
@@ -291,7 +287,6 @@ OC.L10N.register(
     "Edit message" : "Уреди порака",
     "Draft" : "Шаблон",
     "Reply" : "Одговор",
-    "No sent mailbox configured. Please pick one in the account settings." : "Нема сандаче за испратени пораки. Изберете сандаче во параметрите на сметката.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Се обидувате да испратите до многу примачи во До и/или Cc. Можете да користите Bcc за да ги скриете адресите на примачите.",
     "Message discarded" : "Пораката е отфрлена",
     "Could not discard message" : "Неможе да се отфрли порака",
@@ -317,7 +312,6 @@ OC.L10N.register(
     "Show less" : "Помалку",
     "Show more" : "Прикажи повеќе",
     "Clear" : "Исчисти",
-    "Search in mailbox" : "Барај во сандачето",
     "Close" : "Затвори",
     "Search parameters" : "Параметри за пребарување",
     "Date" : "Датум",
@@ -430,7 +424,25 @@ OC.L10N.register(
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
     "Continue to %s" : "Продолжи до %s",
+    "No messages in this mailbox" : "Нема пораки во ова сандаче",
+    "No trash mailbox configured" : "Нема конфигурирано сандаче за отпадоци",
     "Draft: " : "Шаблон:",
+    "Could not open mailbox" : "Неможе да се отвори сандачето",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Индексирање на пораките. Ова може да трае многу долго за големи сандачиња.",
+    "Choose target mailbox" : "Изберете дојдовно сандаче",
+    "Show only subscribed mailboxes" : "Прикажи само претплатени сандачиња",
+    "Add mailbox" : "Додади сандаче",
+    "Show all subscribed mailboxes" : "Прикажи ги сите сандачиња со претплата",
+    "Show all mailboxes" : "Прикажи ги сите сандачиња",
+    "Clear mailbox" : "Исчисти сандаче",
+    "The mailbox and all messages in it will be deleted." : "Сандачето и сеите пораки во него ќе бидат избришани.",
+    "Delete mailbox" : "Избриши сандаче",
+    "Delete mailbox {name}" : "Избриши сандаче {name}",
+    "Mark all messages of this mailbox as read" : "Означи ги како прочитани сите пораки од ова сандаче ",
+    "Add submailbox" : "Додади подсандаче",
+    "Move mailbox" : "Премести сандаче",
+    "No sent mailbox configured. Please pick one in the account settings." : "Нема сандаче за испратени пораки. Изберете сандаче во параметрите на сметката.",
+    "Search in mailbox" : "Барај во сандачето",
     "Actions" : "Акции",
     "New action" : "Нова акција"
 },
