@@ -46,6 +46,7 @@ OC.L10N.register(
     "Decline" : "Зөвшөөрөхгүй",
     "Remove" : "Устгах",
     "email" : "цахим шуудан",
+    "Choose target folder" : "Зорилтот хавтасыг сонгох",
     "Other" : "Бусад",
     "Forward" : "дамжих",
     "Translate" : "Орчуулга",
@@ -58,7 +59,9 @@ OC.L10N.register(
     "Loading …" : "Уншиж байна...",
     "Remove account" : "Аккаунт устгах",
     "Quota" : " хувь хэмжээ",
+    "Folder name" : "Хавтасны нэр",
     "Saving" : "хадгаламж",
+    "Show all folders" : "Бүх хавтас харуулах",
     "Rename" : "Нэрлэнэ үү",
     "New message" : "шинэ зурвас",
     "Reply" : "хариулт",
