@@ -95,7 +95,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisk svar på innkommende meldinger. Hvis noen sender deg flere meldinger, vil dette automatiserte svaret bli sendt maksimalt en gang hver 4. dag.",
     "Filters" : "Filtere",
     "Mail server" : "E-postserver",
-    "Mailbox search" : "Søk i postboks",
     "Update alias" : "Oppdater alias",
     "Rename alias" : "Gi alias nytt navn",
     "Show update alias form" : "Vis skjema for alias oppdatering",
@@ -225,7 +224,7 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "Merkelappen slettes fra alle meldinger.",
     "Plain text" : "Ren tekst",
     "Rich text" : "Rik tekst",
-    "No messages in this mailbox" : "Ingen meldinger i denne postboksen",
+    "No messages in this folder" : "Ingen meldinger i denne mappen",
     "No messages" : "Ingen meldinger",
     "Blind copy recipients only" : "Kun blind kopi mottakere",
     "No subject" : "Ingen emne",
@@ -237,7 +236,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Sett påminnelse for denne helgen",
     "Next week – {timeLocale}" : "Neste uke – {timeLocale}",
     "Set reminder for next week" : "Sett påminnelse for neste uke",
-    "No trash mailbox configured" : "Ingen søppelpostkasse konfigurert",
     "Could not delete message" : "Kunne ikke slette melding",
     "Could not archive message" : "Kunne ikke arkivere melding",
     "Thread was snoozed" : "Tråden ble slumret",
@@ -316,12 +314,9 @@ OC.L10N.register(
     "Add internal address" : "Legg til intern adresse",
     "Add internal email or domain" : "Legg til intern e-post eller domene",
     "Itinerary for {type} is not supported yet" : "Reiserute for {type} støttes ikke ennå",
-    "To archive a message please configure an archive mailbox in account settings" : "For å arkivere en melding, vennligst konfigurer en arkivpostkasse i kontoinnstillinger",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Du har ikke lov til å flytte denne meldingen til arkivmappen og/eller slette denne meldingen fra gjeldende mappe",
-    "Could not open mailbox" : "Kunne ikke åpne postboksen",
     "Loading messages …" : "Laster meldinger ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indekser meldingene dine. Dette kan ta litt lengre tid for større postbokser.",
-    "Choose target mailbox" : "Velg målpostboks",
+    "Choose target folder" : "Velg målmappe",
     "No more submailboxes in here" : "Ingen flere underpostbokser her",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meldinger blir automatisk merket som viktige basert på hvilke meldinger du har interagert med eller merket som viktige. I begynnelsen må du kanskje endre viktigheten manuelt for å lære systemet, men det vil forbedres over tid.",
     "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "Meldinger sendt av deg som krever svar, men ikke mottok en etter et par dager, vises her.",
@@ -383,29 +378,22 @@ OC.L10N.register(
     "Provisioned account is disabled" : "Klargjort konto er deaktivert",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Vennligst logg inn med et passord for å aktivere denne kontoen. Den nåværende økten bruker passordløs autentisering, for eksempel SSO eller WebAuthn.",
     "Quota" : "Kvote",
-    "Show only subscribed mailboxes" : "Vis kun abonnerte postbokser",
-    "Add mailbox" : "Legg til postboks",
-    "Mailbox name" : "Postboksnavn",
+    "Add folder" : "Legg til mappe",
+    "Folder name" : "Mappenavn",
     "Saving" : "Lagrer",
     "Move up" : "Flytt opp",
     "Move down" : "Flytt ned",
-    "Show all subscribed mailboxes" : "Vis alle postbokser du abonnerer på",
-    "Show all mailboxes" : "Vis alle postbokser",
+    "Show all folders" : "Vis alle mapper",
     "Collapse mailboxes" : "Skjul postkasser",
     "_{total} message_::_{total} messages_" : ["{total} melding","{total} meldinger"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ulest av {total}","{unread} uleste av {total}"],
     "All messages in mailbox will be deleted." : "Alle meldinger i postkassen blir slettet.",
     "Clear mailbox {name}" : "Tøm postboks {name}",
-    "Clear mailbox" : "Tøm postboks",
-    "The mailbox and all messages in it will be deleted." : "Postboksen og alle meldinger i den vil bli slettet.",
-    "Delete mailbox" : "Slett postboks",
-    "Delete mailbox {name}" : "Slett postboks {name}",
+    "Delete folder" : "Slett mappe",
     "An error occurred, unable to rename the mailbox." : "Det oppsto en feil, kan ikke gi nytt navn til postboks.",
     "Mark all as read" : "Marker alle som lest",
-    "Mark all messages of this mailbox as read" : "Merk alle meldinger i denne postkassen som lest",
-    "Add submailbox" : "Legg til underpostboks",
     "Rename" : "Endre navn",
-    "Move mailbox" : "Flytt postboks",
+    "Move folder" : "Flytt mappe",
     "Clear cache" : "Tøm hurtiglager",
     "Clear locally cached data, in case there are issues with synchronization." : "Slett lokalt bufrede data, i tilfelle det er problemer med synkronisering.",
     "Subscribed" : "Abonnerer",
@@ -420,7 +408,6 @@ OC.L10N.register(
     "Failed to save draft" : "Lagring av utkast feilet",
     "attachment" : "vedlegg",
     "attached" : "vedlagt",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postboks konfigurert. Vennligs velg en i kontoinnstillingene.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver å sende til mange mottakere i Til og/eller Kopi. Vurder å bruke Blindkopi for å skjule mottakeradressene.",
     "You mentioned an attachment. Did you forget to add it?" : "Du nevnte et vedlegg. Glemte du å legge det ved?",
     "Message discarded" : "Meldingen forkastet",
@@ -444,12 +431,9 @@ OC.L10N.register(
     "Save autoresponder" : "Lagre autosvar",
     "Could not open outbox" : "Kunne ikke åpne utboksen",
     "Pending or not sent messages will show up here" : "Ventende eller ikke sendte meldinger vises her",
-    "Could not copy to \"Sent\" mailbox" : "Kunne ikke kopiere til \"Sendt\"-postboks",
     "Mail server error" : "Feil i e-postserveren",
     "Message could not be sent" : "Melding kunne ikke bli sendt",
     "Message deleted" : "Melding slettet",
-    "Copy to \"Sent\" Mailbox" : "Kopier til \"Sendt\"-postboks",
-    "Copy to Sent Mailbox" : "Kopier til Sendt-postboks",
     "Phishing email" : "Nettfisking e-post",
     "Hide suspicious links" : "Skjul mistenkelige koblinger",
     "Show suspicious links" : "Vis mistenkelige koblinger",
@@ -465,7 +449,6 @@ OC.L10N.register(
     "Show less" : "Vis mindre",
     "Show more" : "Vis mer",
     "Clear" : "Tøm",
-    "Search in mailbox" : "Søk i postboks",
     "Close" : "Lukk",
     "Search parameters" : "Søkeparametere",
     "Search subject" : "Søk emne",
@@ -713,8 +696,6 @@ OC.L10N.register(
     "Could not create snooze mailbox" : "Kan ikke opprette slumrepostboks",
     "Message sent" : "Melding sendt",
     "Could not send message" : "Kunne ikke sende melding",
-    "Message copied to \"Sent\" mailbox" : "Melding kopiert til \"Sendt\"-postboks",
-    "Could not copy message to \"Sent\" mailbox" : "Kunne ikke kopiere melding til \"Sendt\"-postboks",
     "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Det oppsto et problem under lasting av {tag}{name}{endtag}",
     "Could not load your message" : "Kunne ikke laste meldingene dine",
@@ -727,8 +708,34 @@ OC.L10N.register(
     "The link leads to %s" : "Denne lenken leder til %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke vil besøke den siden, kan du gå tilbake til <a href=\"%s\">E-post</a>",
     "Continue to %s" : "Fortsett til %s",
+    "Mailbox search" : "Søk i postboks",
+    "No messages in this mailbox" : "Ingen meldinger i denne postboksen",
+    "No trash mailbox configured" : "Ingen søppelpostkasse konfigurert",
     "Draft: " : "Kladd:",
+    "To archive a message please configure an archive mailbox in account settings" : "For å arkivere en melding, vennligst konfigurer en arkivpostkasse i kontoinnstillinger",
+    "Could not open mailbox" : "Kunne ikke åpne postboksen",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indekser meldingene dine. Dette kan ta litt lengre tid for større postbokser.",
+    "Choose target mailbox" : "Velg målpostboks",
+    "Show only subscribed mailboxes" : "Vis kun abonnerte postbokser",
+    "Add mailbox" : "Legg til postboks",
+    "Mailbox name" : "Postboksnavn",
+    "Show all subscribed mailboxes" : "Vis alle postbokser du abonnerer på",
+    "Show all mailboxes" : "Vis alle postbokser",
+    "Clear mailbox" : "Tøm postboks",
+    "The mailbox and all messages in it will be deleted." : "Postboksen og alle meldinger i den vil bli slettet.",
+    "Delete mailbox" : "Slett postboks",
+    "Delete mailbox {name}" : "Slett postboks {name}",
+    "Mark all messages of this mailbox as read" : "Merk alle meldinger i denne postkassen som lest",
+    "Add submailbox" : "Legg til underpostboks",
+    "Move mailbox" : "Flytt postboks",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postboks konfigurert. Vennligs velg en i kontoinnstillingene.",
+    "Could not copy to \"Sent\" mailbox" : "Kunne ikke kopiere til \"Sendt\"-postboks",
+    "Copy to \"Sent\" Mailbox" : "Kopier til \"Sendt\"-postboks",
+    "Copy to Sent Mailbox" : "Kopier til Sendt-postboks",
+    "Search in mailbox" : "Søk i postboks",
     "Actions" : "Handlinger",
-    "New action" : "Ny handling"
+    "New action" : "Ny handling",
+    "Message copied to \"Sent\" mailbox" : "Melding kopiert til \"Sendt\"-postboks",
+    "Could not copy message to \"Sent\" mailbox" : "Kunne ikke kopiere melding til \"Sendt\"-postboks"
 },
 "nplurals=2; plural=(n != 1);");
