@@ -66,7 +66,9 @@ OC.L10N.register(
     "Move" : "Move",
     "Loading …" : "Cargament…",
     "Quota" : "Quota",
+    "Folder name" : "Nom del dorsièr",
     "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
+    "Delete folder" : "Suprimir dossièr",
     "Mark all as read" : "Marcar totes coma legits",
     "Rename" : "Tornar nommar",
     "Clear cache" : "Voidar l'escondedor",
