@@ -185,7 +185,6 @@ OC.L10N.register(
     "Confirm" : "Potwierdź",
     "Plain text" : "Zwykły tekst",
     "Rich text" : "Tekst sformatowany",
-    "No messages in this mailbox" : "Brak wiadomości w skrzynce pocztowej",
     "No messages" : "Brak wiadomości",
     "Blind copy recipients only" : "Tylko dla niewidocznych kopii",
     "No subject" : "Brak tematu",
@@ -197,7 +196,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Ustaw przypomnienie na ten weekend",
     "Next week – {timeLocale}" : "Następny tydzień – {timeLocale}",
     "Set reminder for next week" : "Ustaw przypomnienie na przyszły tydzień",
-    "No trash mailbox configured" : "Nie skonfigurowano skrzynki pocztowej dla kosza",
     "Could not delete message" : "Nie udało się usunąć wiadomości",
     "Could not archive message" : "Nie udało się zarchiwizować wiadomości",
     "Encrypted message" : "Zaszyfrowana wiadomość",
@@ -263,10 +261,8 @@ OC.L10N.register(
     "Remove" : "Usuń",
     "email" : "e-mail",
     "Itinerary for {type} is not supported yet" : "Trasa dla {type} nie jest jeszcze obsługiwana",
-    "Could not open mailbox" : "Nie można otworzyć skrzynki pocztowej",
     "Loading messages …" : "Wczytywanie wiadomości…",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksowanie wiadomości. W przypadku większych skrzynek pocztowych może to potrwać trochę dłużej.",
-    "Choose target mailbox" : "Wybierz docelową skrzynkę pocztową",
+    "Choose target folder" : "Wybierz katalog docelowy",
     "No more submailboxes in here" : "Nie ma więcej skrzynek podrzędnych",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Wiadomości będą automatycznie oznaczane jako ważne na podstawie wiadomości, z którymi wchodziłeś w interakcję lub które oznaczałeś jako ważne. Na początku być może trzeba będzie ręcznie zmienić ważność dla uczenia systemu, ale z czasem będzie się poprawiać.",
     "Follow up" : "Follow up",
@@ -325,30 +321,28 @@ OC.L10N.register(
     "Provisioned account is disabled" : "Zabezpieczone konto jest wyłączone",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Zaloguj się przy użyciu hasła, aby włączyć to konto. Bieżąca sesja korzysta z uwierzytelniania bez hasła, m.in. SSO lub WebAuthn.",
     "Quota" : "Limit",
-    "Show only subscribed mailboxes" : "Pokaż tylko subskrybowane skrzynki pocztowe",
-    "Add mailbox" : "Dodaj skrzynkę pocztową",
-    "Mailbox name" : "Nazwa skrzynki ",
+    "Show only subscribed folders" : "Pokaż tylko subskrybowane foldery",
+    "Add folder" : "Dodaj katalog",
+    "Folder name" : "Nazwa katalogu",
     "Saving" : "Zapisywanie",
     "Move up" : "Przenieś wyżej",
     "Move down" : "Przenieś niżej",
-    "Show all subscribed mailboxes" : "Pokaż wszystkie subskrybowane skrzynki pocztowe",
-    "Show all mailboxes" : "Pokaż wszystkie skrzynki pocztowe",
+    "Show all subscribed folders" : "Pokaż wszystkie subskrybowane foldery",
+    "Show all folders" : "Pokaż wszystkie foldery",
     "Collapse mailboxes" : "Zwiń skrzynki pocztowe",
     "_{total} message_::_{total} messages_" : ["{total} wiadomość","{total} wiadomości","{total} wiadomości","{total} wiadomości"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nieprzeczytana z {total}","{unread} nieprzeczytane z {total}","{unread} nieprzeczytanych z {total}","{unread} nieprzeczytanych z {total}"],
     "All messages in mailbox will be deleted." : "Wszystkie wiadomości w skrzynce pocztowej zostaną usunięte.",
     "Clear mailbox {name}" : "Wyczyść skrzynkę pocztową {name}",
-    "Clear mailbox" : "Wyczyść skrzynkę pocztową",
-    "The mailbox and all messages in it will be deleted." : "Skrzynka pocztowa i wszystkie zawarte w niej wiadomości zostaną usunięte.",
-    "Delete mailbox" : "Usuń skrzynkę pocztową",
-    "Delete mailbox {name}" : "Usuń skrzynkę pocztową {name}",
+    "The folder and all messages in it will be deleted." : "Folder i wszystkie zawarte w nim wiadomości zostaną usunięte.",
+    "Delete folder" : "Usuń katalog",
+    "Delete folder {name}" : "Usuń folder {name}",
     "An error occurred, unable to rename the mailbox." : "Wystąpił błąd, nie można zmienić nazwy skrzynki pocztowej.",
     "Mark all as read" : "Oznacz wszystkie jako przeczytane",
-    "Mark all messages of this mailbox as read" : "Oznacz wszystkie wiadomości w tej skrzynce pocztowej jako przeczytane",
-    "Add submailbox" : "Dodaj skrzynkę podrzędną",
+    "Mark all messages of this folder as read" : "Oznacz wszystkie wiadomości w tym folderze jako przeczytane",
+    "Add subfolder" : "Dodaj podfolder",
     "Rename" : "Zmień nazwę",
-    "Move mailbox" : "Przenieś skrzynkę",
-    "Repair mailbox" : "Napraw skrzynkę",
+    "Move folder" : "Przenieś katalog",
     "Clear cache" : "Wyczyść pamięć podręczną",
     "Clear locally cached data, in case there are issues with synchronization." : "Wyczyść lokalnie buforowane dane, w przypadku problemów z synchronizacją.",
     "Subscribed" : "Zasubskrybowano",
@@ -363,7 +357,6 @@ OC.L10N.register(
     "Failed to save draft" : "Nie udało się zapisać szkicu",
     "attachment" : "załącznik",
     "attached" : "załączono",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nie skonfigurowano żadnej skrzynki pocztowej dla wysyłanych wiadomości. Wybierz którąś w ustawieniach konta.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Próbujesz wysłać do wielu odbiorców w Do i/lub DW. Rozważ użycie UDW, aby ukryć adresy odbiorców.",
     "Message discarded" : "Wiadomość odrzucona",
     "Could not discard message" : "Nie udało się odrzucić wiadomości",
@@ -395,7 +388,6 @@ OC.L10N.register(
     "Show less" : "Pokaż mniej",
     "Show more" : "Pokaż więcej",
     "Clear" : "Wyczyść ",
-    "Search in mailbox" : "Szukaj w skrzynce pocztowej",
     "Close" : "Zamknij",
     "Search parameters" : "Wyszukaj parametry",
     "Body" : "Treść",
@@ -593,7 +585,27 @@ OC.L10N.register(
     "The link leads to %s" : "Link prowadzi do %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
     "Continue to %s" : "Kontynuuj do %s",
+    "No messages in this mailbox" : "Brak wiadomości w skrzynce pocztowej",
+    "No trash mailbox configured" : "Nie skonfigurowano skrzynki pocztowej dla kosza",
     "Draft: " : "Wersja robocza:",
+    "Could not open mailbox" : "Nie można otworzyć skrzynki pocztowej",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksowanie wiadomości. W przypadku większych skrzynek pocztowych może to potrwać trochę dłużej.",
+    "Choose target mailbox" : "Wybierz docelową skrzynkę pocztową",
+    "Show only subscribed mailboxes" : "Pokaż tylko subskrybowane skrzynki pocztowe",
+    "Add mailbox" : "Dodaj skrzynkę pocztową",
+    "Mailbox name" : "Nazwa skrzynki ",
+    "Show all subscribed mailboxes" : "Pokaż wszystkie subskrybowane skrzynki pocztowe",
+    "Show all mailboxes" : "Pokaż wszystkie skrzynki pocztowe",
+    "Clear mailbox" : "Wyczyść skrzynkę pocztową",
+    "The mailbox and all messages in it will be deleted." : "Skrzynka pocztowa i wszystkie zawarte w niej wiadomości zostaną usunięte.",
+    "Delete mailbox" : "Usuń skrzynkę pocztową",
+    "Delete mailbox {name}" : "Usuń skrzynkę pocztową {name}",
+    "Mark all messages of this mailbox as read" : "Oznacz wszystkie wiadomości w tej skrzynce pocztowej jako przeczytane",
+    "Add submailbox" : "Dodaj skrzynkę podrzędną",
+    "Move mailbox" : "Przenieś skrzynkę",
+    "Repair mailbox" : "Napraw skrzynkę",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nie skonfigurowano żadnej skrzynki pocztowej dla wysyłanych wiadomości. Wybierz którąś w ustawieniach konta.",
+    "Search in mailbox" : "Szukaj w skrzynce pocztowej",
     "Actions" : "Akcje",
     "New action" : "Nowa akcja"
 },
