@@ -117,6 +117,7 @@ OC.L10N.register(
     "domain" : "domínio",
     "Remove" : "Remover",
     "email" : "email",
+    "Choose target folder" : "Escolher pasta de destino",
     "Important info" : "Informação importante",
     "Other" : "Outro",
     "Notify the sender" : "Notificar o remetente",
@@ -146,11 +147,12 @@ OC.L10N.register(
     "Remove account" : "Remover conta",
     "Remove {email}" : "Remover {email}",
     "Quota" : "Quota",
-    "Add mailbox" : "Adicionar caixa de",
+    "Folder name" : "Nome da pasta",
     "Saving" : "A guardar",
     "Move up" : "Mover para cima",
     "Move down" : "Mover para baixo",
-    "Show all mailboxes" : "Mostrar todas as caixas de entrada",
+    "Show all folders" : "Mostrar todas as pastas",
+    "Delete folder" : "Apagar pasta",
     "Mark all as read" : "Marcar todas como lidas",
     "Rename" : "Renomear",
     "Clear cache" : "Limpar cache",
@@ -235,6 +237,8 @@ OC.L10N.register(
     "The link leads to %s" : "A ligação aponta para %s",
     "Continue to %s" : "Continuar para %s",
     "Draft: " : "Rascunho:",
+    "Add mailbox" : "Adicionar caixa de",
+    "Show all mailboxes" : "Mostrar todas as caixas de entrada",
     "Actions" : "Ações",
     "New action" : "Nova ação"
 },
