@@ -79,7 +79,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Răspuns automat la mesajele primite. Dacă cineva vă trimite câteva mesaje, acest răspuns automat va fi trimis cel mult o dată la 4 zile.",
     "Filters" : "Filtre",
     "Mail server" : "Server mail",
-    "Mailbox search" : "Căutare mail",
     "Update alias" : "Actualizează aliasul",
     "Rename alias" : "Redenumește aliasul",
     "Show update alias form" : "Afișează forma de actualizare alias",
@@ -173,7 +172,6 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "Eticheta va fi ștearsă pentru toate mesajele.",
     "Plain text" : "Text simplu",
     "Rich text" : "Text formatat",
-    "No messages in this mailbox" : "Nu există mesaje",
     "No messages" : "Niciun mesaj",
     "Blind copy recipients only" : "Doar destinatarii din copia blind",
     "No subject" : "Fără subiect",
@@ -185,7 +183,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Setează memo pentru acest weekend",
     "Next week – {timeLocale}" : "Săptămâna viitoare– {timeLocale}",
     "Set reminder for next week" : "Setează memo pentru săptămâna viitoare",
-    "No trash mailbox configured" : "Nu este configurat un folder pentru mesajele șterse",
     "Could not delete message" : "Mesajul nu a putut fi șters",
     "Could not archive message" : "Mesajul nu s-a putut arhiva",
     "Thread was snoozed" : "Conversația a fost amânată",
@@ -258,12 +255,9 @@ OC.L10N.register(
     "domain" : "domeniu",
     "Remove" : "Elimină",
     "email" : "email",
-    "To archive a message please configure an archive mailbox in account settings" : "Pentru arhivarea mesajelor configurați un folder de arhivare în setările contului",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nu aveți permisiunea să mutați mesajul în folderul de arhivare și/sau șterge mesajul din folderul curent",
-    "Could not open mailbox" : "Cutia poștală nu se poate deschide",
     "Loading messages …" : "Se încarcă mesajele ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Se indexează mesajele. Aceasta poate dura ceva mai mult pentru cutiile poștale mai încărcate.",
-    "Choose target mailbox" : "Selectați folderul destinație",
+    "Choose target folder" : "Alege directorul destinație",
     "No more submailboxes in here" : "Nu mai sunt subfoldere",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Mesajul va fi marcat automat ca important în funcție de mesajele cu care ați interacționat sau pe care le-ați marcat ca importante. La început ar trebui să setați manual importanța pentru antrenarea sistemului, dar aceasta se va îmbunătăți în timp.",
     "Important info" : "Informații importante",
@@ -315,29 +309,19 @@ OC.L10N.register(
     "Provisioned account is disabled" : "Contul configurat este dezactivat",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Logați-vă cu o parolă pentru a activa acest cont. Sesiunea curentă utilizează autentificarea fără parolă, de ex. SSO sau WebAuthn.",
     "Quota" : "Procent",
-    "Show only subscribed mailboxes" : "Arată doar căsuțele abonate",
-    "Add mailbox" : "Adaugă mailbox",
-    "Mailbox name" : "Nume mailbox",
+    "Folder name" : "Denumire director",
     "Saving" : "Se salvează",
     "Move up" : "Mută înainte",
     "Move down" : "Mută în jos",
-    "Show all subscribed mailboxes" : "Afișează toate căsuțele abonate",
-    "Show all mailboxes" : "Afișează toate folderele",
+    "Show all folders" : "Arată toate directoarele",
     "Collapse mailboxes" : "Restrânge folderele",
     "_{total} message_::_{total} messages_" : ["{total} mesaj","{total} mesaje","{total} mesaje"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} necitit din {total}","{unread} necitite din {total}","{unread} necitite din {total}"],
     "All messages in mailbox will be deleted." : "Vor fi șterse toate mesajele din acest folder",
     "Clear mailbox {name}" : "Golește folderul {name}",
-    "Clear mailbox" : "Golește folderul",
-    "The mailbox and all messages in it will be deleted." : "Se ca șterge folderul și toate mesajele.",
-    "Delete mailbox" : "Șterge folderul",
-    "Delete mailbox {name}" : "Șterge mailbox {name}",
     "An error occurred, unable to rename the mailbox." : "Eroare la redenumirea mailbox.",
     "Mark all as read" : "Marcaţi tot ca fiind citit",
-    "Mark all messages of this mailbox as read" : "Marchează toate mesajele din acest folder ca citite",
-    "Add submailbox" : "Adaugă subfolder",
     "Rename" : "Redenumire",
-    "Move mailbox" : "Mută cutia poștală",
     "Clear cache" : "Șterge cache",
     "Clear locally cached data, in case there are issues with synchronization." : "Ștergeți datele din cache local în cazul problemelor de sincronizare.",
     "Subscribed" : "Abonat",
@@ -351,7 +335,6 @@ OC.L10N.register(
     "Failed to save draft" : "Eroare la salvarea schiței",
     "attachment" : "atașament",
     "attached" : "atașat",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nu este configurat un folder pentru mesaje trimise. Selectați unul în setările contului.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Încercați să trimiteți la prea mulți destinatari la Către și/sau Cc. încercați să folosiți Bcc pentru ascunderea adreselor destinatarilor.",
     "You mentioned an attachment. Did you forget to add it?" : "Ați menționat un atașament. Ați uitat cumva să-l adăugați?",
     "Message discarded" : "Mesaj eliminat",
@@ -384,7 +367,6 @@ OC.L10N.register(
     "Contact name …" : "Nume contact ...",
     "Add" : "Adaugă",
     "Clear" : "Șterge ",
-    "Search in mailbox" : "Cautare în folder",
     "Close" : "Închide",
     "Search parameters" : "Parametri de căutare",
     "Search subject" : "Caută subiect",
@@ -524,7 +506,28 @@ OC.L10N.register(
     "The link leads to %s" : "Link-ul duce la %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Dacă nu doriți să vizitați acea pagină, vă puteți întoarce la <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Continuă către %s",
+    "Mailbox search" : "Căutare mail",
+    "No messages in this mailbox" : "Nu există mesaje",
+    "No trash mailbox configured" : "Nu este configurat un folder pentru mesajele șterse",
     "Draft: " : "Schiță:",
+    "To archive a message please configure an archive mailbox in account settings" : "Pentru arhivarea mesajelor configurați un folder de arhivare în setările contului",
+    "Could not open mailbox" : "Cutia poștală nu se poate deschide",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Se indexează mesajele. Aceasta poate dura ceva mai mult pentru cutiile poștale mai încărcate.",
+    "Choose target mailbox" : "Selectați folderul destinație",
+    "Show only subscribed mailboxes" : "Arată doar căsuțele abonate",
+    "Add mailbox" : "Adaugă mailbox",
+    "Mailbox name" : "Nume mailbox",
+    "Show all subscribed mailboxes" : "Afișează toate căsuțele abonate",
+    "Show all mailboxes" : "Afișează toate folderele",
+    "Clear mailbox" : "Golește folderul",
+    "The mailbox and all messages in it will be deleted." : "Se ca șterge folderul și toate mesajele.",
+    "Delete mailbox" : "Șterge folderul",
+    "Delete mailbox {name}" : "Șterge mailbox {name}",
+    "Mark all messages of this mailbox as read" : "Marchează toate mesajele din acest folder ca citite",
+    "Add submailbox" : "Adaugă subfolder",
+    "Move mailbox" : "Mută cutia poștală",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nu este configurat un folder pentru mesaje trimise. Selectați unul în setările contului.",
+    "Search in mailbox" : "Cautare în folder",
     "Actions" : "Acțiuni"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
