@@ -96,7 +96,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматический ответ на входящие сообщения. Если кто-то отправит вам несколько сообщений, этот автоматический ответ будет отправляться не чаще одного раза в 4 дня.",
     "Filters" : "Фильтры",
     "Mail server" : "Почтовый сервер",
-    "Mailbox search" : "Поиск по почтовому ящику",
     "Update alias" : "Обновить псевдоним",
     "Rename alias" : "Переименовать псевдоним",
     "Show update alias form" : "Показать обновления для формы alias",
@@ -223,7 +222,7 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "Тег будет удален из всех сообщений.",
     "Plain text" : "Простой текст",
     "Rich text" : "Текст с форматированием",
-    "No messages in this mailbox" : "В этой папке нет сообщений",
+    "No messages in this folder" : "В этой папке нет сообщений",
     "No messages" : "Нет ни одного сообщения",
     "Blind copy recipients only" : "Только получатели скрытой копии",
     "No subject" : "Без темы",
@@ -235,7 +234,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Установить напоминание на эти выходные",
     "Next week – {timeLocale}" : "Следующая неделя – {timeLocale}",
     "Set reminder for next week" : "Установить напоминание на следующую неделю",
-    "No trash mailbox configured" : "Папка «Удалённые» не настроена",
     "Could not delete message" : "Не удалось удалить сообщение",
     "Could not archive message" : "Не удалось заархивировать письмо",
     "Encrypted message" : "Зашифрованное сообщение",
@@ -304,12 +302,9 @@ OC.L10N.register(
     "Add internal address" : "Добавить внутренний адрес",
     "Add internal email or domain" : "Добавить внутреннюю электронную почту или домен",
     "Itinerary for {type} is not supported yet" : "Маршруты типа {type} пока не поддерживаются",
-    "To archive a message please configure an archive mailbox in account settings" : "Чтобы заархивировать сообщение, настройте архивный почтовый ящик в настройках учетной записи.",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Вам не разрешено перемещать это сообщение в архивную папку и/или удалять это сообщение из текущей папки.",
-    "Could not open mailbox" : "Невозможно открыть папку",
     "Loading messages …" : "Загрузка сообщений...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Выполняется индексация сообщений, это займёт некоторое время.",
-    "Choose target mailbox" : "Выберите папку",
+    "Choose target folder" : "Выбор папки назначения",
     "No more submailboxes in here" : "Вложенные папки отсутствуют",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Письма будут автоматически отмечаться важными на основе анализа ваших действий и присвоения метки «Важно». В первое время, возможно, потребуется обучить систему присвоением и удалением меток вручную.",
     "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "Здесь будут отображаться отправленные вами сообщения, требующие ответа, но не полученные в течение нескольких дней.",
@@ -371,29 +366,27 @@ OC.L10N.register(
     "Provisioned account is disabled" : "Предоставленный аккаунт отключен",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Пожалуйста, войдите в систему, используя пароль, чтобы активировать эту учетную запись. Текущий сеанс использует аутентификацию без пароля, например. Единый вход или WebAuthn.",
     "Quota" : "Квота",
-    "Show only subscribed mailboxes" : "Показать только папки из подписки",
-    "Add mailbox" : "Добавить папку",
-    "Mailbox name" : "Имя почтового ящика",
+    "Show only subscribed folders" : "Показывать только папки из подписки",
+    "Add folder" : "Добавить папку",
+    "Folder name" : "Имя папки",
     "Saving" : "Сохранение",
     "Move up" : "Переместить выше",
     "Move down" : "Переместить ниже",
-    "Show all subscribed mailboxes" : "Показать все папки из подписки",
-    "Show all mailboxes" : "Показать все папки",
+    "Show all subscribed folders" : "Показать все папки из подписки",
     "Collapse mailboxes" : "Свернуть папки",
     "_{total} message_::_{total} messages_" : ["{total} письмо","{total} письма","{total} писем","{total} письма"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}"],
     "All messages in mailbox will be deleted." : "Все сообщения в почтовом ящике будут удалены.",
     "Clear mailbox {name}" : "Очистить почтовый ящик {name}",
-    "Clear mailbox" : "Очистить почтовый ящик",
-    "The mailbox and all messages in it will be deleted." : "Папка и все письма в ней будут удалены.",
-    "Delete mailbox" : "Удалить папку",
-    "Delete mailbox {name}" : "Удалить папку {name}",
+    "The folder and all messages in it will be deleted." : "Папка и все находящиеся в ней письма будут удалены",
+    "Delete folder" : "Удалить папку",
+    "Delete folder {name}" : "Удалить папку «{name}»",
     "An error occurred, unable to rename the mailbox." : "Ошибка переименования папки.",
     "Mark all as read" : "Пометить всё как прочитанное",
-    "Mark all messages of this mailbox as read" : "Пометить все сообщения в папке как прочитанные",
-    "Add submailbox" : "Добавить вложенную папку",
+    "Mark all messages of this folder as read" : "Пометить все сообщения в этой папке как прочитанные",
+    "Add subfolder" : "Добавить подпапку",
     "Rename" : "Переименовать",
-    "Move mailbox" : "Переместить почтовый ящик",
+    "Move folder" : "Переместить папку",
     "Clear cache" : "Очистить кэш",
     "Clear locally cached data, in case there are issues with synchronization." : "Очистить локальный кэш данных в случае проблем с синхронизацией.",
     "Subscribed" : "Подписано",
@@ -408,7 +401,6 @@ OC.L10N.register(
     "Failed to save draft" : "Не удалось сохранить черновик",
     "attachment" : "вложение",
     "attached" : "прикрепить",
-    "No sent mailbox configured. Please pick one in the account settings." : "Не настроена папка исходящих сообщений. Выберите ее в параметрах учётной записи.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Вы пытаетесь отправить письмо очень большому количеству получателей, указанных в полях «Кому» или «Коп». Для сокрытия адреса эл. почты получателя, укажите его в поле «Скр. коп.».",
     "You mentioned an attachment. Did you forget to add it?" : "Вы упомянули вложение. Вы забыли добавить его?",
     "Message discarded" : "Внесение изменений отменено",
@@ -430,12 +422,9 @@ OC.L10N.register(
     "Save autoresponder" : "Сохранить автоответчик",
     "Could not open outbox" : "Не удалось открыть исходящие",
     "Pending or not sent messages will show up here" : "В этой папке будут представлены отложенные и неотправленные сообщения",
-    "Could not copy to \"Sent\" mailbox" : "Не удалось скопировать в почтовый ящик «Отправленные»",
     "Mail server error" : "Ошибка почтового сервера",
     "Message could not be sent" : "Сообщение не может быть отправлено",
     "Message deleted" : "Сообщение удалено",
-    "Copy to \"Sent\" Mailbox" : "Копировать в почтовый ящик «Отправленные»",
-    "Copy to Sent Mailbox" : "Копировать в почтовый ящик «Отправленные»",
     "Phishing email" : "Фишинговое письмо",
     "Hide suspicious links" : "Скрыть подозрительные ссылки",
     "Show suspicious links" : "Показать подозрительные ссылки",
@@ -451,7 +440,6 @@ OC.L10N.register(
     "Show less" : "Показывать меньше",
     "Show more" : "Показывать больше",
     "Clear" : "Очистить",
-    "Search in mailbox" : "Искать в почтовом ящике",
     "Close" : "Закрыть",
     "Search parameters" : "Параметры поиска",
     "Search subject" : "Тема поиска",
@@ -691,8 +679,6 @@ OC.L10N.register(
     "Could not create snooze mailbox" : "Не удалось создать почтовый ящик для отсрочки",
     "Message sent" : "Сообщение отправлено",
     "Could not send message" : "Не удалось отправить сообщение",
-    "Message copied to \"Sent\" mailbox" : "Сообщение скопировано в почтовый ящик «Отправленные»",
-    "Could not copy message to \"Sent\" mailbox" : "Не удалось скопировать сообщение в почтовый ящик «Отправленные»",
     "Could not load {tag}{name}{endtag}" : "Не удалось загрузить {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Проблема при загрузке {tag}{name}{endtag}",
     "Could not load your message" : "Ошибка получения вашего сообщения",
@@ -705,8 +691,34 @@ OC.L10N.register(
     "The link leads to %s" : "Эта ссылка ведёт на %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Если вы не хотите посещать эту страницу, вы можете вернуться в <a href=\"%s\">Почту</a>",
     "Continue to %s" : "Продолжать %s",
+    "Mailbox search" : "Поиск по почтовому ящику",
+    "No messages in this mailbox" : "В этой папке нет сообщений",
+    "No trash mailbox configured" : "Папка «Удалённые» не настроена",
     "Draft: " : "Черновик:",
+    "To archive a message please configure an archive mailbox in account settings" : "Чтобы заархивировать сообщение, настройте архивный почтовый ящик в настройках учетной записи.",
+    "Could not open mailbox" : "Невозможно открыть папку",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Выполняется индексация сообщений, это займёт некоторое время.",
+    "Choose target mailbox" : "Выберите папку",
+    "Show only subscribed mailboxes" : "Показать только папки из подписки",
+    "Add mailbox" : "Добавить папку",
+    "Mailbox name" : "Имя почтового ящика",
+    "Show all subscribed mailboxes" : "Показать все папки из подписки",
+    "Show all mailboxes" : "Показать все папки",
+    "Clear mailbox" : "Очистить почтовый ящик",
+    "The mailbox and all messages in it will be deleted." : "Папка и все письма в ней будут удалены.",
+    "Delete mailbox" : "Удалить папку",
+    "Delete mailbox {name}" : "Удалить папку {name}",
+    "Mark all messages of this mailbox as read" : "Пометить все сообщения в папке как прочитанные",
+    "Add submailbox" : "Добавить вложенную папку",
+    "Move mailbox" : "Переместить почтовый ящик",
+    "No sent mailbox configured. Please pick one in the account settings." : "Не настроена папка исходящих сообщений. Выберите ее в параметрах учётной записи.",
+    "Could not copy to \"Sent\" mailbox" : "Не удалось скопировать в почтовый ящик «Отправленные»",
+    "Copy to \"Sent\" Mailbox" : "Копировать в почтовый ящик «Отправленные»",
+    "Copy to Sent Mailbox" : "Копировать в почтовый ящик «Отправленные»",
+    "Search in mailbox" : "Искать в почтовом ящике",
     "Actions" : "Действия",
-    "New action" : "Создать действие"
+    "New action" : "Создать действие",
+    "Message copied to \"Sent\" mailbox" : "Сообщение скопировано в почтовый ящик «Отправленные»",
+    "Could not copy message to \"Sent\" mailbox" : "Не удалось скопировать сообщение в почтовый ящик «Отправленные»"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
