@@ -105,14 +105,12 @@ OC.L10N.register(
     "Confirm" : "Cunfirma",
     "Plain text" : "Testu simple",
     "Rich text" : "Testu formatadu",
-    "No messages in this mailbox" : "Perunu messàgiu in custa casella de posta",
     "No messages" : "Perunu messàgiu",
     "Blind copy recipients only" : "Isceti persones destinatàrias in còpia cuada",
     "Set reminder for later today" : "Cunfigura un'apuntu pro luego",
     "Set reminder for tomorrow" : "Cunfigura un'apuntu pro cras",
     "Set reminder for this weekend" : "Cunfigura un'apuntu pro custu fine de chida",
     "Set reminder for next week" : "Cunfigura un'apuntu pro chida chi benit",
-    "No trash mailbox configured" : "Peruna casella de àliga cunfigurada",
     "Could not delete message" : "No at fatu a cantzellare su messàgiu",
     "Unfavorite" : "Boga dae is preferidos",
     "Favorite" : "Preferidu",
@@ -153,9 +151,7 @@ OC.L10N.register(
     "email" : "posta eletrònica",
     "Add internal address" : "Agiunghe indiritzu internu",
     "Itinerary for {type} is not supported yet" : "S'itineràriu pro {type} no est ancora suportadu",
-    "Could not open mailbox" : "No at fatu a abèrrere sa casella de posta",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Inditzizende is messàgios. S'at a pòdere istentare unu pagu de prus cun casellas de posta prus mannas.",
-    "Choose target mailbox" : "Sèbera casella de posta de destinatzione",
+    "Choose target folder" : "Sèbera cartella de destinatzione",
     "No more submailboxes in here" : "Non b'at àteras suta-cartellas inoghe",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Is messàgios s'ant a marcare in manera automàtica comente importantes in sa base de is messàgios cun is chi as tènnidu interatziones o chi si sunt marcados comente importantes. Fortzis a su cumintzu as a dèpere cambiare a manu s'importàntzia pro ddu imparare a su sistema, ma at a megiorare in su tempus.",
     "Important info" : "Informatzione importante",
@@ -198,30 +194,23 @@ OC.L10N.register(
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Su contu pro {email} e is datos de posta eletrònica allogados in sa memòria temporànea s'ant a bogare dae Nextcloud, ma no dae su frunidore de posta eletrònica tuo.",
     "Remove {email}" : "Boga•nche {email}",
     "Quota" : "Cuota",
-    "Show only subscribed mailboxes" : "Mustra isceti casellas de posta sutascritas",
-    "Add mailbox" : "Agiunghe casella de posta",
+    "Folder name" : "Nùmene de sa cartella",
     "Saving" : "Sarvende",
     "Move up" : "Tràmuda fache a susu",
     "Move down" : "Tràmuda fache a bàsciu",
-    "Show all subscribed mailboxes" : "Mustra totu is casellas de posta sutascritas",
-    "Show all mailboxes" : "Mustra totu is casellas de posta",
     "Collapse mailboxes" : "Istringhe is casellas de posta",
     "_{total} message_::_{total} messages_" : ["{total} messàgios","{total} messàgios"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non lèghidos de {total}","{unread} unread of {total}"],
-    "The mailbox and all messages in it will be deleted." : "Sa casella de posta e is messàgios chi cuntenet ant a èssere cantzellados.",
-    "Delete mailbox" : "Cantzella casella de posta",
-    "Delete mailbox {name}" : "Cantzella casella de posta {name}",
+    "Delete folder" : "Cantzella sa cartella",
     "An error occurred, unable to rename the mailbox." : "B'at àpidu un'errore, no at fatu a torrare a numenare sa casella de posta.",
     "Mark all as read" : "Marca totu comente lèghidu",
-    "Mark all messages of this mailbox as read" : "Marca totu is messàgios de custa casella de posta comente lèghidos",
-    "Add submailbox" : "Agiunghe una sutacasella de posta",
+    "Move folder" : "Tràmuda sa cartella",
     "Clear cache" : "Lìmpia memòria temporànea",
     "Clear locally cached data, in case there are issues with synchronization." : "Lìmpia is datos locales allogados in sa memòria temporànea, s'in casu mai b'apant problemas cun sa sincronizatzione.",
     "Subscribed" : "Sutaiscritu",
     "Sync in background" : "Sincronizatzione in segunu pianu",
     "New message" : "Messàgiu nou",
     "Reply" : "Responde",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nissuna casella de posta imbiada cunfigurada. Sèbera·nde una in sa cunfiguratzione de su contu.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Ses proende a imbiare a tropu persones in A e/o Cc. Cunsìdera de impreare Bcc pro cuare is indiritzos de is chi retzint.",
     "Error sending your message" : "Errore in s'imbiu de su messàgiu",
     "Retry" : "Torra a proare",
@@ -358,7 +347,22 @@ OC.L10N.register(
     "Redirect" : "Torra a deretare",
     "The link leads to %s" : "Su ligòngiu deretat a %s",
     "Continue to %s" : "Sighi in %s",
+    "No messages in this mailbox" : "Perunu messàgiu in custa casella de posta",
+    "No trash mailbox configured" : "Peruna casella de àliga cunfigurada",
     "Draft: " : "Brutacòpia:",
+    "Could not open mailbox" : "No at fatu a abèrrere sa casella de posta",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Inditzizende is messàgios. S'at a pòdere istentare unu pagu de prus cun casellas de posta prus mannas.",
+    "Choose target mailbox" : "Sèbera casella de posta de destinatzione",
+    "Show only subscribed mailboxes" : "Mustra isceti casellas de posta sutascritas",
+    "Add mailbox" : "Agiunghe casella de posta",
+    "Show all subscribed mailboxes" : "Mustra totu is casellas de posta sutascritas",
+    "Show all mailboxes" : "Mustra totu is casellas de posta",
+    "The mailbox and all messages in it will be deleted." : "Sa casella de posta e is messàgios chi cuntenet ant a èssere cantzellados.",
+    "Delete mailbox" : "Cantzella casella de posta",
+    "Delete mailbox {name}" : "Cantzella casella de posta {name}",
+    "Mark all messages of this mailbox as read" : "Marca totu is messàgios de custa casella de posta comente lèghidos",
+    "Add submailbox" : "Agiunghe una sutacasella de posta",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nissuna casella de posta imbiada cunfigurada. Sèbera·nde una in sa cunfiguratzione de su contu.",
     "New test" : "Proa noa",
     "Actions" : "Atziones",
     "New action" : "Atzione noa"
