@@ -74,7 +74,6 @@ OC.L10N.register(
     "Default folders" : "Privzete mape",
     "Filters" : "Filtri",
     "Mail server" : "Poštni strežnik",
-    "Mailbox search" : "Iskanje po poštnem predalu",
     "Update alias" : "Posodobi vzdevek",
     "Rename alias" : "Preimenuj vzdevek",
     "Show update alias form" : "Pokaži obrazec za posodobitev vzdevka",
@@ -173,7 +172,7 @@ OC.L10N.register(
     "Confirm" : "Potrdi",
     "Plain text" : "Besedilno",
     "Rich text" : "Obogateno besedilo",
-    "No messages in this mailbox" : "V poštnem predalu ni sporočil.",
+    "No messages in this folder" : "V tej mapi ni sporočil",
     "No messages" : "Ni sporočil",
     "Blind copy recipients only" : "Le prejemniki skrite kopije",
     "No subject" : "Ni zadeve",
@@ -185,7 +184,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Nastavi opomnik za ta teden",
     "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
     "Set reminder for next week" : "Nastavi opomnik za naslednji teden",
-    "No trash mailbox configured" : "Ni nastavljenega poštne mape za smeti",
     "Could not delete message" : "Sporočila ni mogoče izbrisati",
     "Could not archive message" : "Ni mogoče arhivirati sporočila",
     "Encrypted message" : "Šifrirano sporočilo",
@@ -248,10 +246,8 @@ OC.L10N.register(
     "Remove" : "Odstrani",
     "email" : "elektronska pošta",
     "Itinerary for {type} is not supported yet" : "{type} – vrsta prevoza še ni podprta",
-    "Could not open mailbox" : "Ni mogoče odpreti poštnega predala",
     "Loading messages …" : "Poteka nalaganje sporočil ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Poteka ustvarjanje kazala sporočil. Opravilo je lahko dolgotrajno pri velikih poštnih predalih.",
-    "Choose target mailbox" : "Izbor ciljnega poštnega predala",
+    "Choose target folder" : "Izbor ciljne mape",
     "No more submailboxes in here" : "V tem predalu ni drugih predalov",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Sporočila bodo samodejno označena kot pomembna na podlagi do sedaj označenih takih sporočil. V začetku bo verjetno treba kakšno označiti še ročno, a se bo sistem s časom izboljševal.",
     "Important info" : "Pomembno",
@@ -297,28 +293,28 @@ OC.L10N.register(
     "Remove {email}" : "Odstrani {email}",
     "Provisioned account is disabled" : "Povezan račun je onemogočen",
     "Quota" : "Količinska omejitev",
-    "Show only subscribed mailboxes" : "Pokaži le naročene poštne predale",
-    "Add mailbox" : "Dodaj poštni predal",
+    "Show only subscribed folders" : "Pokaži le naročene mape",
+    "Add folder" : "Dodaj mapo",
+    "Folder name" : "Ime mape",
     "Saving" : "Poteka shranjevanje ...",
     "Move up" : "Premakni višje",
     "Move down" : "Premakni navzdol",
-    "Show all subscribed mailboxes" : "Pokaži vse naročene poštne predale",
-    "Show all mailboxes" : "Pokaži vse poštne predale",
+    "Show all subscribed folders" : "Pokaži vse naročene mape",
+    "Show all folders" : "Pokaži vse mape",
     "Collapse mailboxes" : "Skrči poštne predale",
     "_{total} message_::_{total} messages_" : ["{total} sporočilo","{total} sporočili","{total} sporočila","{total} sporočil"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neprebrano od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebranih od skupno {total}"],
     "All messages in mailbox will be deleted." : "Vsa sporočila v poštnem predalu bodo izbrisana.",
     "Clear mailbox {name}" : "Počisti poštni predal {name}",
-    "Clear mailbox" : "Počisti poštni predal",
-    "The mailbox and all messages in it will be deleted." : "Poštni predal in vsa vključena sporočila bodo izbrisana.",
-    "Delete mailbox" : "Izbriši poštni predal",
-    "Delete mailbox {name}" : "Izbriši poštni predal {name}",
+    "The folder and all messages in it will be deleted." : "Mapa in vsa sporočila bodo izbrisana.",
+    "Delete folder" : "Izbriši mapo",
+    "Delete folder {name}" : "Izbriši mapo {name}",
     "An error occurred, unable to rename the mailbox." : "Prišlo je do napake; poštnega predala ni mogoče preimenovati.",
     "Mark all as read" : "Označi vse kot prebrano",
-    "Mark all messages of this mailbox as read" : "Označi vsa sporočila v tej mapi kot prebrana",
-    "Add submailbox" : "Dodaj podrejeni poštni predal",
+    "Mark all messages of this folder as read" : "Označi vsa sporočila v tej mapi kot prebrana",
+    "Add subfolder" : "Dodaj podmapo",
     "Rename" : "Preimenuj",
-    "Move mailbox" : "Premakni poštni predal",
+    "Move folder" : "Premakni mapo",
     "Clear cache" : "Počisti predpomnilnik",
     "Clear locally cached data, in case there are issues with synchronization." : "Počisti krajevno predpomnjena sporočila, v primeru morebitnih težav z usklajevanjem.",
     "Subscribed" : "Naročeno",
@@ -331,7 +327,6 @@ OC.L10N.register(
     "Message saved" : "Sporočilo je shranjeno",
     "Failed to save message" : "Shranjevanje sporočila je spodletelo",
     "Failed to save draft" : "Shranjevanje osnutka je spodletelo",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ni določenega predala za pošiljanje. Izberite ga med nastavitvami računa.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Poskušate poslati prevelikemu številu naslovnikov in prejemnikov kopije sporočila. Razmislite o uporabi skrite kopije za izbrane naslove.",
     "Message discarded" : "Sporočilo je izbrisano",
     "Could not discard message" : "Sporočila ni mogoče zavreči",
@@ -357,7 +352,6 @@ OC.L10N.register(
     "Show less" : "Pokaži manj",
     "Show more" : "Pokaži več",
     "Clear" : "Počisti",
-    "Search in mailbox" : "Preišči poštni predal",
     "Close" : "Zapri",
     "Search parameters" : "Poišči parametre",
     "Body" : "Besedilo",
@@ -540,7 +534,26 @@ OC.L10N.register(
     "Redirect" : "Preusmeri",
     "The link leads to %s" : "Povezava vodi do %s",
     "Continue to %s" : "Nadaljuj na %s",
+    "Mailbox search" : "Iskanje po poštnem predalu",
+    "No messages in this mailbox" : "V poštnem predalu ni sporočil.",
+    "No trash mailbox configured" : "Ni nastavljenega poštne mape za smeti",
     "Draft: " : "Osnutek:",
+    "Could not open mailbox" : "Ni mogoče odpreti poštnega predala",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Poteka ustvarjanje kazala sporočil. Opravilo je lahko dolgotrajno pri velikih poštnih predalih.",
+    "Choose target mailbox" : "Izbor ciljnega poštnega predala",
+    "Show only subscribed mailboxes" : "Pokaži le naročene poštne predale",
+    "Add mailbox" : "Dodaj poštni predal",
+    "Show all subscribed mailboxes" : "Pokaži vse naročene poštne predale",
+    "Show all mailboxes" : "Pokaži vse poštne predale",
+    "Clear mailbox" : "Počisti poštni predal",
+    "The mailbox and all messages in it will be deleted." : "Poštni predal in vsa vključena sporočila bodo izbrisana.",
+    "Delete mailbox" : "Izbriši poštni predal",
+    "Delete mailbox {name}" : "Izbriši poštni predal {name}",
+    "Mark all messages of this mailbox as read" : "Označi vsa sporočila v tej mapi kot prebrana",
+    "Add submailbox" : "Dodaj podrejeni poštni predal",
+    "Move mailbox" : "Premakni poštni predal",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ni določenega predala za pošiljanje. Izberite ga med nastavitvami računa.",
+    "Search in mailbox" : "Preišči poštni predal",
     "Actions" : "Dejanja"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
