@@ -129,7 +129,7 @@ OC.L10N.register(
     "Confirm" : "Bekräfta",
     "Plain text" : "Oformaterad text",
     "Rich text" : "Formaterad text",
-    "No messages in this mailbox" : "Inga meddelanden i den här brevlådan",
+    "No messages in this folder" : "Inga meddelanden i denna mapp",
     "No messages" : "Inga meddelanden",
     "Blind copy recipients only" : "Endast mottagare för blindkopior",
     "No subject" : "Ingen ämnesrad",
@@ -141,7 +141,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
     "Next week – {timeLocale}" : "Nästa vecka – {timeLocale}",
     "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
-    "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
     "Could not delete message" : "Kunde inte radera meddelande",
     "Could not archive message" : "Kunde inte arkivera meddelandet",
     "Unfavorite" : "Inte favorit",
@@ -186,10 +185,8 @@ OC.L10N.register(
     "Remove" : "Ta bort",
     "email" : "e-post",
     "Itinerary for {type} is not supported yet" : "Resplan för {type} stöds inte än",
-    "Could not open mailbox" : "Kunde inte öppna brevlådan",
     "Loading messages …" : "Läser in meddelanden …",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexera dina meddelanden. Det kan ta lite längre tid för större brevlådor.",
-    "Choose target mailbox" : "Välj markerad inkorg",
+    "Choose target folder" : "Välj målmapp",
     "No more submailboxes in here" : "Inga fler undermappar här",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meddelanden kommer automatiskt att markeras som viktiga baserat på vilka meddelanden du interagerade med eller har markerat som viktiga. I början kan du behöva ändra vikten manuellt, men det kommer att förbättras med tiden.",
     "Important info" : "Viktig info",
@@ -229,21 +226,26 @@ OC.L10N.register(
     "Remove account" : "Ta bort konto",
     "Remove {email}" : "Ta bort {email}",
     "Quota" : "Kvot",
-    "Show only subscribed mailboxes" : "Visa endast prenumererade brevlådor",
-    "Add mailbox" : "Lägg till brevlåda",
+    "Show only subscribed folders" : "Visa endast mappar som du prenumererar på",
+    "Add folder" : "Lägg till mapp",
+    "Folder name" : "Mappnamn",
     "Saving" : "Sparar",
     "Move up" : "Flytta upp",
     "Move down" : "Flytta ner",
-    "Show all subscribed mailboxes" : "Visa alla prenumererade brevlådor",
-    "Show all mailboxes" : "Visa alla brevlådor",
+    "Show all subscribed folders" : "Visa alla mappar som du prenumererar på",
+    "Show all folders" : "Visa alla kataloger",
     "Collapse mailboxes" : "Minimera brevlådor",
     "_{total} message_::_{total} messages_" : ["{total} meddelande","{total} meddelanden"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} av {total} oläst","{unread} av {total} oläst"],
-    "Delete mailbox" : "Radera brevlåda",
+    "The folder and all messages in it will be deleted." : "Denna mapp och alla meddelanden i den kommer att raderas.",
+    "Delete folder" : "Radera mapp",
+    "Delete folder {name}" : "Ta bort mapp {name}",
     "An error occurred, unable to rename the mailbox." : "Ett fel inträffade, det gick inte att byta namn på brevlådan.",
     "Mark all as read" : "Markera alla som lästa",
-    "Mark all messages of this mailbox as read" : "Markera alla meddelanden i den här brevlådan som lästa",
+    "Mark all messages of this folder as read" : "Markera alla meddelanden i den här mappen som lästa",
+    "Add subfolder" : "Skapa undermapp",
     "Rename" : "Byt namn",
+    "Move folder" : "Flytta mapp",
     "Clear cache" : "Rensa cachen",
     "Clear locally cached data, in case there are issues with synchronization." : "Rensa lokalt cachad data, ifall det finns problem med synkronisering.",
     "Subscribed" : "Prenumeration aktiverad",
@@ -269,7 +271,6 @@ OC.L10N.register(
     "Show less" : "Visa mindre",
     "Show more" : "Visa mer",
     "Clear" : "Rensa",
-    "Search in mailbox" : "Sök i brevlådan",
     "Close" : "Stäng",
     "Search parameters" : "Sökparametrar",
     "Body" : "Textyta",
@@ -378,7 +379,19 @@ OC.L10N.register(
     "Redirect" : "Omdirigera",
     "The link leads to %s" : "Länken pekar mot %s",
     "Continue to %s" : "Fortsätt till %s",
+    "No messages in this mailbox" : "Inga meddelanden i den här brevlådan",
+    "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
     "Draft: " : "Utkast:",
+    "Could not open mailbox" : "Kunde inte öppna brevlådan",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexera dina meddelanden. Det kan ta lite längre tid för större brevlådor.",
+    "Choose target mailbox" : "Välj markerad inkorg",
+    "Show only subscribed mailboxes" : "Visa endast prenumererade brevlådor",
+    "Add mailbox" : "Lägg till brevlåda",
+    "Show all subscribed mailboxes" : "Visa alla prenumererade brevlådor",
+    "Show all mailboxes" : "Visa alla brevlådor",
+    "Delete mailbox" : "Radera brevlåda",
+    "Mark all messages of this mailbox as read" : "Markera alla meddelanden i den här brevlådan som lästa",
+    "Search in mailbox" : "Sök i brevlådan",
     "Actions" : "Funktioner",
     "New action" : "Ny åtgärd"
 },
