@@ -58,6 +58,7 @@ OC.L10N.register(
     "Decline" : "Kataa",
     "More options" : "Mibadala zaidi",
     "Remove" : "Ondoa",
+    "Choose target folder" : "Chagua kasha lililolengwa",
     "Other" : "Mengine",
     "Forward" : "Mbele",
     "Translate" : "Tafsiri",
@@ -65,6 +66,9 @@ OC.L10N.register(
     "Loading …" : "Inapakia",
     "{usage} of {limit} used" : "{usage} ya {limit}imetumika",
     "Remove account" : "Ondoa akaunti",
+    "Add folder" : "Ongeza kisanduku",
+    "Folder name" : "Jina la kisanduku",
+    "Delete folder" : "Futa kisanduku",
     "Rename" : "Ipe jina jipya",
     "Subscribed" : "Iliyojisajili",
     "Edit message" : "Hariri ujumbe",
