@@ -43,6 +43,7 @@ OC.L10N.register(
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
     "Remove" : "ลบออก",
+    "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
     "Other" : "อื่น ๆ",
     "Forward" : "ส่งต่อ",
     "Translate" : "แปลภาษา",
@@ -52,7 +53,9 @@ OC.L10N.register(
     "Moving" : "กำลังย้าย",
     "Remove account" : "ลบบัญชี",
     "Quota" : "โควต้า",
+    "Folder name" : "ชื่อโฟลเดอร์",
     "Saving" : "กำลังบันทึก",
+    "Show all folders" : "แสดงโฟลเดอร์ทั้งหมด",
     "Mark all as read" : "เปลี่ยนทั้งหมดเป็นอ่านแล้ว",
     "Rename" : "เปลี่ยนชื่อ",
     "Clear cache" : "ล้างแคช",
