@@ -98,7 +98,6 @@ OC.L10N.register(
     "Sieve script editor" : "قوليازما تەھرىرلىگۈچ",
     "Mail server" : "خەت مۇلازىمېتىرى",
     "Sieve server" : "مۇلازىمېتىر",
-    "Mailbox search" : "خەت ساندۇقى ئىزدەش",
     "Update alias" : "نامىنى يېڭىلاش",
     "Rename alias" : "نامىنى ئۆزگەرتىڭ",
     "Show update alias form" : "يېڭىلاش نامىنى كۆرسىتىدۇ",
@@ -227,7 +226,6 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "خەتكۈچ بارلىق ئۇچۇرلاردىن ئۆچۈرۈلىدۇ.",
     "Plain text" : "تۈز تېكىست",
     "Rich text" : "مول تېكىست",
-    "No messages in this mailbox" : "بۇ خەت ساندۇقىدا ھېچقانداق ئۇچۇر يوق",
     "No messages" : "ھېچقانداق ئۇچۇر يوق",
     "Blind copy recipients only" : "پەقەت ئەمالار كۆپەيتكۈچى",
     "No subject" : "تېما يوق",
@@ -239,7 +237,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "بۇ ھەپتە ئاخىرىدا ئەسكەرتىش بەلگىلەڭ",
     "Next week – {timeLocale}" : "كېلەر ھەپتە - {timeLocale}",
     "Set reminder for next week" : "كېلەر ھەپتە ئەسكەرتىش بەلگىلەڭ",
-    "No trash mailbox configured" : "ئەخلەت خەت ساندۇقى سەپلەنمىگەن",
     "Could not delete message" : "ئۇچۇرنى ئۆچۈرەلمىدى",
     "Could not archive message" : "ئۇچۇرنى ئارخىپلاشتۇرالمىدى",
     "Thread was snoozed" : "تېما قىسقارتىلدى",
@@ -306,12 +303,9 @@ OC.L10N.register(
     "Add internal address" : "ئىچكى ئادرېس قوشۇڭ",
     "Add internal email or domain" : "ئىچكى ئېلېكترونلۇق خەت ياكى دائىرە قوشۇڭ",
     "Itinerary for {type} is not supported yet" : "{type} نىڭ لىنىيىسى تېخىچە قوللىمايدۇ",
-    "To archive a message please configure an archive mailbox in account settings" : "ئۇچۇرنى ئارخىپلاشتۇرۇش ئۈچۈن ھېسابات تەڭشىكىدە ئارخىپ خەت ساندۇقىنى سەپلەڭ",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "بۇ ئۇچۇرنى ئارخىپ قىسقۇچقا يۆتكەش ۋە / ياكى بۇ ھۆججەتنى نۆۋەتتىكى ھۆججەت قىسقۇچتىن ئۆچۈرۈشكە بولمايدۇ",
-    "Could not open mailbox" : "خەت ساندۇقىنى ئاچالمىدى",
     "Loading messages …" : "ئۇچۇرلارنى يۈكلەۋاتىدۇ…",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ئۇچۇرلىرىڭىزنى كۆرسەتمەكتە. چوڭراق خەت ساندۇقىغا بىر ئاز ئۇزۇن ۋاقىت كېتىدۇ.",
-    "Choose target mailbox" : "نىشان خەت ساندۇقىنى تاللاڭ",
+    "Choose target folder" : "نىشان ھۆججەت قىسقۇچىنى تاللاڭ",
     "No more submailboxes in here" : "بۇ يەردە باشقا خەت ساندۇقى يوق",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "سىز قايسى ئۇچۇرلار بىلەن ئالاقە قىلغان ياكى مۇھىم دەپ بەلگە قويۇلغان ئۇچۇرلار ئاپتوماتىك ھالدا مۇھىم دەپ بەلگە قىلىنىدۇ. باشتا سىز سىستېمىنى ئوقۇتۇشنىڭ مۇھىملىقىنى قولدا ئۆزگەرتىشىڭىز مۇمكىن ، ئەمما ۋاقىتنىڭ ئۆتۈشىگە ئەگىشىپ ياخشىلىنىدۇ.",
     "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "سىز ئەۋەتكەن جاۋابنى تەلەپ قىلىدىغان ، ئەمما بىر نەچچە كۈندىن كېيىن تاپشۇرۇۋالمىغان ئۇچۇرلار بۇ يەردە كۆرسىتىلىدۇ.",
@@ -372,29 +366,20 @@ OC.L10N.register(
     "Provisioned account is disabled" : "تەمىنلەنگەن ھېسابات چەكلەنگەن",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "بۇ ھېساباتنى قوزغىتىش ئۈچۈن پارول ئىشلىتىپ كىرىڭ. نۆۋەتتىكى يىغىن مەخپىي نومۇرسىز دەلىللەشنى ئىشلىتىۋاتىدۇ. SSO ياكى WebAuthn.",
     "Quota" : "Quota",
-    "Show only subscribed mailboxes" : "پەقەت مۇشتەرى بولغان خەت ساندۇقىنىلا كۆرسىتىڭ",
-    "Add mailbox" : "خەت ساندۇقى قوشۇڭ",
-    "Mailbox name" : "خەت ساندۇقىنىڭ ئىسمى",
+    "Add folder" : "قىسقۇچ قوشۇڭ",
+    "Folder name" : "ھۆججەت قىسقۇچنىڭ ئىسمى",
     "Saving" : "تېجەش",
     "Move up" : "يۆتكەڭ",
     "Move down" : "تۆۋەنگە يۆتكەڭ",
-    "Show all subscribed mailboxes" : "بارلىق مۇشتەرى بولغان خەت ساندۇقىنى كۆرسەت",
-    "Show all mailboxes" : "بارلىق خەت ساندۇقىنى كۆرسەت",
     "Collapse mailboxes" : "خەت ساندۇقىنى يىمىرىڭ",
     "All messages in mailbox will be deleted." : "خەت ساندۇقىدىكى بارلىق ئۇچۇرلار ئۆچۈرۈلىدۇ.",
     "Clear mailbox {name}" : "خەت ساندۇقىنى تازىلاش {name}",
-    "Clear mailbox" : "خەت ساندۇقىنى تازىلاش",
-    "The mailbox and all messages in it will be deleted." : "خەت ساندۇقى ۋە ئۇنىڭدىكى بارلىق ئۇچۇرلار ئۆچۈرۈلىدۇ.",
-    "Delete mailbox" : "خەت ساندۇقىنى ئۆچۈرۈڭ",
-    "Delete mailbox {name}" : "خەت ساندۇقىنى ئۆچۈرۈڭ {name}",
+    "Delete folder" : "ھۆججەت قىسقۇچنى ئۆچۈرۈڭ",
     "An error occurred, unable to rename the mailbox." : "خاتالىق يۈز بەردى ، خەت ساندۇقىنىڭ نامىنى ئۆزگەرتەلمىدى.",
     "Please wait 10 minutes before repairing again" : "قايتا رېمونت قىلىشتىن 10 مىنۇت ساقلاڭ",
     "Mark all as read" : "ھەممىنى ئوقۇغاندەك بەلگە قويۇڭ",
-    "Mark all messages of this mailbox as read" : "بۇ خەت ساندۇقىنىڭ بارلىق ئۇچۇرلىرىنى ئوقۇغاندەك بەلگە قويۇڭ",
-    "Add submailbox" : "تارماق خەت ساندۇقى قوشۇڭ",
     "Rename" : "ئات ئۆزگەرت",
-    "Move mailbox" : "خەت ساندۇقىنى يۆتكەڭ",
-    "Repair mailbox" : "خەت ساندۇقىنى رېمونت قىلىڭ",
+    "Move folder" : "ھۆججەت قىسقۇچنى يۆتكەڭ",
     "Clear cache" : "غەملەكنى تازىلاش",
     "Clear locally cached data, in case there are issues with synchronization." : "ماس قەدەمدە مەسىلە كۆرۈلسە ، يەرلىك ساقلانغان سانلىق مەلۇماتلارنى تازىلاڭ.",
     "Subscribed" : "مۇشتەرى بولدى",
@@ -409,7 +394,6 @@ OC.L10N.register(
     "Failed to save draft" : "لايىھەنى ساقلىيالمىدى",
     "attachment" : "attachment",
     "attached" : "باغلانغان",
-    "No sent mailbox configured. Please pick one in the account settings." : "ئەۋەتىلگەن خەت ساندۇقى سەپلەنمىگەن. ھېسابات تەڭشىكىدىن بىرنى تاللاڭ.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "سىز To ۋە / ياكى Cc دىكى نۇرغۇن تاپشۇرۇۋالغۇچىلارغا ئەۋەتمەكچى بولۇۋاتىسىز. تاپشۇرۇۋالغۇچىنىڭ ئادرېسىنى يوشۇرۇش ئۈچۈن Bcc نى ئىشلىتىشنى ئويلاڭ.",
     "You mentioned an attachment. Did you forget to add it?" : "قوشۇمچە ھۆججەتنى تىلغا ئالدىڭىز. ئۇنى قوشۇشنى ئۇنتۇپ قالدىڭىزمۇ؟",
     "Message discarded" : "ئۇچۇر تاشلىۋېتىلدى",
@@ -433,12 +417,9 @@ OC.L10N.register(
     "Save autoresponder" : "ئاپتوماتىك جاۋاب قايتۇرۇڭ",
     "Could not open outbox" : "خەت ساندۇقىنى ئاچالمىدى",
     "Pending or not sent messages will show up here" : "ساقلىنىۋاتقان ياكى ئەۋەتىلمىگەن ئۇچۇرلار بۇ يەردە كۆرۈنىدۇ",
-    "Could not copy to \"Sent\" mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرەلمىدى",
     "Mail server error" : "خەت مۇلازىمېتىر خاتالىقى",
     "Message could not be sent" : "ئۇچۇر ئەۋەتىلمىدى",
     "Message deleted" : "ئۇچۇر ئۆچۈرۈلدى",
-    "Copy to \"Sent\" Mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرۈڭ",
-    "Copy to Sent Mailbox" : "ئەۋەتىلگەن خەت ساندۇقىغا كۆچۈرۈڭ",
     "Phishing email" : "ئالدامچىلىق ئېلېكترونلۇق خەت",
     "This email might be a phishing attempt" : "بۇ ئېلېكترونلۇق خەت ئالدامچىلىق بولۇشى مۇمكىن",
     "Hide suspicious links" : "گۇمانلىق ئۇلىنىشلارنى يوشۇرۇڭ",
@@ -455,7 +436,6 @@ OC.L10N.register(
     "Show less" : "ئازراق كۆرسەت",
     "Show more" : "تېخىمۇ كۆپ كۆرسەت",
     "Clear" : "Clear",
-    "Search in mailbox" : "خەت ساندۇقىدىن ئىزدەڭ",
     "Close" : "ياپ",
     "Search parameters" : "ئىزدەش پارامېتىرلىرى",
     "Search subject" : "ئىزدەش تېمىسى",
@@ -726,8 +706,6 @@ OC.L10N.register(
     "Could not create snooze mailbox" : "ئۇخلاش خەت ساندۇقى قۇرالمىدى",
     "Message sent" : "ئۇچۇر ئەۋەتىلدى",
     "Could not send message" : "ئۇچۇر ئەۋەتەلمىدى",
-    "Message copied to \"Sent\" mailbox" : "ئۇچۇر «ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرۈلدى",
-    "Could not copy message to \"Sent\" mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا ئۇچۇر كۆچۈرەلمىدى",
     "Could not load {tag}{name}{endtag}" : "يۈكلىيەلمىدى {tag} {name} {endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "{tag} {name} {endtag} نى يۈكلەشتە مەسىلە كۆرۈلدى",
     "Could not load your message" : "ئۇچۇرىڭىزنى يۈكلىيەلمىدى",
@@ -740,12 +718,39 @@ OC.L10N.register(
     "The link leads to %s" : "ئۇلىنىش% s نى كەلتۈرۈپ چىقىرىدۇ",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ئەگەر ئۇ بەتنى زىيارەت قىلىشنى خالىمىسىڭىز ، <a href = \"% s\"> خەت </a> گە قايتسىڭىز بولىدۇ.",
     "Continue to %s" : "داۋاملىق% s",
+    "Mailbox search" : "خەت ساندۇقى ئىزدەش",
+    "No messages in this mailbox" : "بۇ خەت ساندۇقىدا ھېچقانداق ئۇچۇر يوق",
+    "No trash mailbox configured" : "ئەخلەت خەت ساندۇقى سەپلەنمىگەن",
     "Draft: " : "لايىھە: ",
+    "To archive a message please configure an archive mailbox in account settings" : "ئۇچۇرنى ئارخىپلاشتۇرۇش ئۈچۈن ھېسابات تەڭشىكىدە ئارخىپ خەت ساندۇقىنى سەپلەڭ",
+    "Could not open mailbox" : "خەت ساندۇقىنى ئاچالمىدى",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ئۇچۇرلىرىڭىزنى كۆرسەتمەكتە. چوڭراق خەت ساندۇقىغا بىر ئاز ئۇزۇن ۋاقىت كېتىدۇ.",
+    "Choose target mailbox" : "نىشان خەت ساندۇقىنى تاللاڭ",
+    "Show only subscribed mailboxes" : "پەقەت مۇشتەرى بولغان خەت ساندۇقىنىلا كۆرسىتىڭ",
+    "Add mailbox" : "خەت ساندۇقى قوشۇڭ",
+    "Mailbox name" : "خەت ساندۇقىنىڭ ئىسمى",
+    "Show all subscribed mailboxes" : "بارلىق مۇشتەرى بولغان خەت ساندۇقىنى كۆرسەت",
+    "Show all mailboxes" : "بارلىق خەت ساندۇقىنى كۆرسەت",
+    "Clear mailbox" : "خەت ساندۇقىنى تازىلاش",
+    "The mailbox and all messages in it will be deleted." : "خەت ساندۇقى ۋە ئۇنىڭدىكى بارلىق ئۇچۇرلار ئۆچۈرۈلىدۇ.",
+    "Delete mailbox" : "خەت ساندۇقىنى ئۆچۈرۈڭ",
+    "Delete mailbox {name}" : "خەت ساندۇقىنى ئۆچۈرۈڭ {name}",
+    "Mark all messages of this mailbox as read" : "بۇ خەت ساندۇقىنىڭ بارلىق ئۇچۇرلىرىنى ئوقۇغاندەك بەلگە قويۇڭ",
+    "Add submailbox" : "تارماق خەت ساندۇقى قوشۇڭ",
+    "Move mailbox" : "خەت ساندۇقىنى يۆتكەڭ",
+    "Repair mailbox" : "خەت ساندۇقىنى رېمونت قىلىڭ",
+    "No sent mailbox configured. Please pick one in the account settings." : "ئەۋەتىلگەن خەت ساندۇقى سەپلەنمىگەن. ھېسابات تەڭشىكىدىن بىرنى تاللاڭ.",
+    "Could not copy to \"Sent\" mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرەلمىدى",
+    "Copy to \"Sent\" Mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرۈڭ",
+    "Copy to Sent Mailbox" : "ئەۋەتىلگەن خەت ساندۇقىغا كۆچۈرۈڭ",
+    "Search in mailbox" : "خەت ساندۇقىدىن ئىزدەڭ",
     "If all tests pass, then the actions will be executed" : "ئەگەر بارلىق سىناقلار ئۆتۈپ كەتسە ، ھەرىكەتلەر ئىجرا بولىدۇ",
     "If one test pass, then the actions will be executed" : "ئەگەر بىر سىناقتىن ئۆتسە ، ئۇنداقتا ھەرىكەت ئىجرا بولىدۇ",
     "Tests" : "سىناق",
     "New test" : "يېڭى سىناق",
     "Actions" : "مەشغۇلاتلار",
-    "New action" : "يېڭى ھەرىكەت"
+    "New action" : "يېڭى ھەرىكەت",
+    "Message copied to \"Sent\" mailbox" : "ئۇچۇر «ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرۈلدى",
+    "Could not copy message to \"Sent\" mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا ئۇچۇر كۆچۈرەلمىدى"
 },
 "nplurals=2; plural=(n != 1);");
