@@ -85,7 +85,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматична відповідь на вхідні повідомлення. Якщо хтось надсилає вам кілька повідомлень, ця автоматична відповідь надсилатиметься щонайбільше раз на 4 дні.",
     "Filters" : "Фільтри",
     "Mail server" : "Поштовий сервер",
-    "Mailbox search" : "Пошук поштової скриньки",
     "Update alias" : "Оновити синонім",
     "Rename alias" : "Перейменувати синонім",
     "Show update alias form" : "Показати форму оновлення синоніму",
@@ -199,7 +198,7 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "Мітку буде вилучено зі всіх листів.",
     "Plain text" : "Простий текст",
     "Rich text" : "Текст з форматуванням",
-    "No messages in this mailbox" : "Відсутні листи у поштовій скриньці",
+    "No messages in this folder" : "Відсутні повідомлення у цій теці",
     "No messages" : "Відсутні повідомлення",
     "Blind copy recipients only" : "Лише отримувачі у прихованій копії",
     "No subject" : "Без теми",
@@ -209,7 +208,6 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Встановити нагадування на ці вихідні",
     "Next week – {timeLocale}" : "Наступного тижня - {timeLocale}",
     "Set reminder for next week" : "Встановити нагадування на наступний тиждень",
-    "No trash mailbox configured" : "Кошик для листів не налаштовано",
     "Could not delete message" : "Не вдалося вилучити лист",
     "Could not archive message" : "Не вдалося архівувати лист",
     "Thread was snoozed" : "Ланцюг відкладено",
@@ -283,12 +281,9 @@ OC.L10N.register(
     "domain" : "домен",
     "Remove" : "Вилучити",
     "email" : "електронна пошта",
-    "To archive a message please configure an archive mailbox in account settings" : "Для архівування повідомлення налаштуйте каталог архіву вашої поштової скринькі в налаштуваннях облікового запису",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "У вас відсутній доступ переміщувати це повідомлення до каталогу архіву та/або вилучати з поточного каталогу",
-    "Could not open mailbox" : "Неможливо відкрити поштову скриньку",
     "Loading messages …" : "Завантаження повідомлень ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Індексування повідомлень. Ця дія може забрати більше часу для поштових скриньок з великим обсягом повідомлень.",
-    "Choose target mailbox" : "Виберіть поштову скриньку призначення",
+    "Choose target folder" : "Виберіть каталог призначення",
     "No more submailboxes in here" : "Жодних вкладених поштових скриньок більше не знайдено тут",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Повідомлення автоматично будуть позначатися як важливі на основі повідомлень, з якими ви взаємодієте або позначаєте як важливі. Спочатку вам потрібно буде вручну змінювати важливість, щоб навчити систему, але з часом автоматичне визначення важливих повідомлень покращиться.",
     "Important info" : "Важлива інформація",
@@ -338,29 +333,26 @@ OC.L10N.register(
     "Remove {email}" : "Вилучити {email}",
     "Provisioned account is disabled" : "Автоматично налаштований обліковий запис вимкнено",
     "Quota" : "Обмеження",
-    "Show only subscribed mailboxes" : "Показувати лише передплачені поштові скриньки",
-    "Add mailbox" : "Додати поштову скриньку",
-    "Mailbox name" : "Назва поштової скриньки",
+    "Show only subscribed folders" : "Показувати лише підписані теки",
+    "Add folder" : "Додати теку",
+    "Folder name" : "Назва каталогу",
     "Saving" : "Збереження",
     "Move up" : "Пересунуту догори",
     "Move down" : "Пересунути вниз",
-    "Show all subscribed mailboxes" : "Показати всі поштові скриньки, на які підписано",
-    "Show all mailboxes" : "Показати всі поштові скриньки",
+    "Show all subscribed folders" : "Показати всі підписані теки",
+    "Show all folders" : "Переглянути всі теки",
     "Collapse mailboxes" : "Згорнути поштові скриньки",
     "_{total} message_::_{total} messages_" : ["{total} повідомлення","{total} повідомлення","{total} повідомлень","{total} повідомлень"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитано з {total}","{unread} непрочитано з {total}","{unread} непрочитано з {total}","{unread} непрочитано з {total}"],
     "All messages in mailbox will be deleted." : "Усі повідомлення у поштовій скриньці буде вилучено.",
     "Clear mailbox {name}" : "Очистити поштову скриньку {name}",
-    "Clear mailbox" : "Очистити поштову скриньку",
-    "The mailbox and all messages in it will be deleted." : "Поштову скриньку та всі повідомлення у скриньці буде вилучено.",
-    "Delete mailbox" : "Вилучили поштову скриньку",
-    "Delete mailbox {name}" : "Вилучити поштову скриньку {name}",
+    "Delete folder" : "Вилучити каталог",
     "An error occurred, unable to rename the mailbox." : "Сталася помилка. Неможливо перейменувати поштову скриньку.",
     "Mark all as read" : "Всі прочитані",
-    "Mark all messages of this mailbox as read" : "Позначити всі повідомлення з цієї поштової скриньки як прочитані",
-    "Add submailbox" : "Додати вкладену поштову скриньку",
+    "Mark all messages of this folder as read" : "Позначити усі повідомлення у цій теці як прочитані",
+    "Add subfolder" : "Додати підтеку",
     "Rename" : "Перейменувати",
-    "Move mailbox" : "Перемістити поштову скриньку",
+    "Move folder" : "Перемістити каталог",
     "Clear cache" : "Очистити кеш",
     "Clear locally cached data, in case there are issues with synchronization." : "Очистити локально кешовані дані у разі проблем з синхронізацією.",
     "Subscribed" : "Підписано",
@@ -375,7 +367,6 @@ OC.L10N.register(
     "Failed to save draft" : "Не вдалося зберегти чернетку",
     "attachment" : "вкладення",
     "attached" : "прикріплено",
-    "No sent mailbox configured. Please pick one in the account settings." : "Відсутня налаштована скринька відправлених повідомлено. Виберіть скриньку в налаштуваннях облікового запису.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Ви намагаєтесь надіслати лист занадто багатьом отримувачам, яких зазначили у полі \"Кому\" та/або \"Копія\". Розгляньте можливість використання полі \"Прихована копія\" для приховування адрес отримувачів.",
     "You mentioned an attachment. Did you forget to add it?" : "Ви згадали про вкладення. Чи ви часом не забули його долучити?",
     "Message discarded" : "Відхилено повідомлення",
@@ -399,11 +390,8 @@ OC.L10N.register(
     "Save autoresponder" : "Зберегти налаштування автовідповідача",
     "Could not open outbox" : "Не вдалося відкрити вихідну скриньку",
     "Pending or not sent messages will show up here" : "Тут відображатимуться незавершені або не надіслані повідомлення",
-    "Could not copy to \"Sent\" mailbox" : "Не вдалося скопіюати до \"Надіслані\"",
     "Message could not be sent" : "Повідомлення неможливо надіслати",
     "Message deleted" : "Повідомлення вилучено",
-    "Copy to \"Sent\" Mailbox" : "Копіювати до \"Надіслані\"",
-    "Copy to Sent Mailbox" : "Копіювати до \"Надіслані\"",
     "Copied email address to clipboard" : "Адресу електронної пошти скопійовано до буферу обміну",
     "Could not copy email address to clipboard" : "Не вдалося скопіювати адресу електронної пошти до буфера обміну",
     "Contacts with this address" : "Контакти з такою адресою",
@@ -415,7 +403,6 @@ OC.L10N.register(
     "Show less" : "Показувати менше",
     "Show more" : "Показати більше",
     "Clear" : "Очистити",
-    "Search in mailbox" : "Шукати в поштовій скринці",
     "Close" : "Закрити",
     "Search parameters" : "Параметри пошуку",
     "Search subject" : "Шукати в темі",
@@ -569,7 +556,31 @@ OC.L10N.register(
     "Redirect" : "Перенаправлення",
     "The link leads to %s" : "Посилання веде до %s",
     "Continue to %s" : "Перейти до %s",
+    "Mailbox search" : "Пошук поштової скриньки",
+    "No messages in this mailbox" : "Відсутні листи у поштовій скриньці",
+    "No trash mailbox configured" : "Кошик для листів не налаштовано",
     "Draft: " : "Чернетка:",
+    "To archive a message please configure an archive mailbox in account settings" : "Для архівування повідомлення налаштуйте каталог архіву вашої поштової скринькі в налаштуваннях облікового запису",
+    "Could not open mailbox" : "Неможливо відкрити поштову скриньку",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Індексування повідомлень. Ця дія може забрати більше часу для поштових скриньок з великим обсягом повідомлень.",
+    "Choose target mailbox" : "Виберіть поштову скриньку призначення",
+    "Show only subscribed mailboxes" : "Показувати лише передплачені поштові скриньки",
+    "Add mailbox" : "Додати поштову скриньку",
+    "Mailbox name" : "Назва поштової скриньки",
+    "Show all subscribed mailboxes" : "Показати всі поштові скриньки, на які підписано",
+    "Show all mailboxes" : "Показати всі поштові скриньки",
+    "Clear mailbox" : "Очистити поштову скриньку",
+    "The mailbox and all messages in it will be deleted." : "Поштову скриньку та всі повідомлення у скриньці буде вилучено.",
+    "Delete mailbox" : "Вилучили поштову скриньку",
+    "Delete mailbox {name}" : "Вилучити поштову скриньку {name}",
+    "Mark all messages of this mailbox as read" : "Позначити всі повідомлення з цієї поштової скриньки як прочитані",
+    "Add submailbox" : "Додати вкладену поштову скриньку",
+    "Move mailbox" : "Перемістити поштову скриньку",
+    "No sent mailbox configured. Please pick one in the account settings." : "Відсутня налаштована скринька відправлених повідомлено. Виберіть скриньку в налаштуваннях облікового запису.",
+    "Could not copy to \"Sent\" mailbox" : "Не вдалося скопіюати до \"Надіслані\"",
+    "Copy to \"Sent\" Mailbox" : "Копіювати до \"Надіслані\"",
+    "Copy to Sent Mailbox" : "Копіювати до \"Надіслані\"",
+    "Search in mailbox" : "Шукати в поштовій скринці",
     "Actions" : "Дії",
     "New action" : "Нова дія"
 },
