@@ -48,7 +48,9 @@ OC.L10N.register(
     "Move" : "Move",
     "Remove {email}" : " {email} ni o'chirish",
     "Quota" : "kvota",
+    "Folder name" : "Jild nomi",
     "Saving" : "Saving",
+    "Delete folder" : "Jildni o'chirish",
     "Rename" : "Nomini o'zgartirish",
     "Subscribed" : "Obuna boʻlgan",
     "Reply" : "Javob bering",
