@@ -92,14 +92,12 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Chọn một tệp để thêm dưới dạng tệp đính kèm",
     "Choose a file to share as a link" : "Chọn một tệp để chia sẻ dưới dạng liên kết",
     "Confirm" : "Xác nhận",
-    "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
     "No messages" : "Không có tin nhắn",
     "Blind copy recipients only" : "Chỉ người nhận bản sao ẩn",
     "Later today – {timeLocale}" : "Sau này - {timeLocale}",
     "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
     "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
     "Next week – {timeLocale}" : "Tuần sau - {timeLocale}",
-    "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
     "Could not delete message" : "Không thể xóa tin nhắn",
     "Favorite" : "Ưa thích",
     "Read" : "Đọc",
@@ -131,9 +129,7 @@ OC.L10N.register(
     "Remove" : "Xóa",
     "email" : "Thư điện tử",
     "Itinerary for {type} is not supported yet" : "Hành trình cho {type} chưa được hỗ trợ",
-    "Could not open mailbox" : "Không thể mở hộp thư",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Lập chỉ mục tin nhắn của bạn. Quá trình này có thể lâu hơn một chút đối với các hộp thư lớn.",
-    "Choose target mailbox" : "Chọn hộp thư mục tiêu",
+    "Choose target folder" : "Chọn thư mục đích",
     "No more submailboxes in here" : "Không còn hộp thư con nào ở đây",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Tin nhắn sẽ tự động được đánh dấu là quan trọng dựa trên những tin nhắn bạn đã tương tác hoặc được đánh dấu là quan trọng. Lúc đầu, bạn có thể phải thay đổi thủ công tầm quan trọng để dạy hệ thống, nhưng nó sẽ cải thiện theo thời gian.",
     "Important info" : "Thông tin quan trọng",
@@ -172,23 +168,16 @@ OC.L10N.register(
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tài khoản cho {email} và dữ liệu email đã lưu trong bộ nhớ cache sẽ bị xóa khỏi vWorkspace, nhưng không bị xóa khỏi nhà cung cấp dịch vụ email của bạn.",
     "Remove {email}" : "Xóa {email}",
     "Quota" : "Hạn ngạch",
-    "Show only subscribed mailboxes" : "Chỉ hiển thị các hộp thư đã đăng ký",
-    "Add mailbox" : "Thêm hộp thư",
+    "Folder name" : "Tên thư mục",
     "Saving" : "Tiết kiệm",
     "Move up" : "Di chuyển lên",
     "Move down" : "Di chuyển xuống",
-    "Show all subscribed mailboxes" : "Hiển thị tất cả các hộp thư đã đăng ký",
-    "Show all mailboxes" : "Hiển thị tất cả các hộp thư",
     "Collapse mailboxes" : "Thu gọn hộp thư",
     "_{total} message_::_{total} messages_" : ["{total} tin nhắn"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} thư chưa đọc trong tổng số {total} thư"],
-    "The mailbox and all messages in it will be deleted." : "Hộp thư và tất cả thư trong đó sẽ bị xóa.",
-    "Delete mailbox" : "Xóa hộp thư",
-    "Delete mailbox {name}" : "Xóa hộp thư {name}",
+    "Delete folder" : "Xoá thư mục",
     "An error occurred, unable to rename the mailbox." : "Đã xảy ra lỗi, không thể đổi tên hộp thư.",
     "Mark all as read" : "Đánh dấu tất cả như đã ",
-    "Mark all messages of this mailbox as read" : "Đánh dấu tất cả các thư của hộp thư này là đã đọc",
-    "Add submailbox" : "Thêm hộp thư con",
     "Rename" : "Đổi tên",
     "Clear cache" : "Xóa bộ nhớ ",
     "Clear locally cached data, in case there are issues with synchronization." : "Xóa dữ liệu được lưu trong bộ nhớ cache cục bộ, trong trường hợp có sự cố với đồng bộ hóa.",
@@ -196,7 +185,6 @@ OC.L10N.register(
     "Sync in background" : "Đồng bộ trong nền",
     "New message" : "Tin nhắn mới",
     "Reply" : "Trả lời",
-    "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
     "Error sending your message" : "Lỗi khi gửi tin nhắn",
     "Retry" : "Thử lại",
     "Contacts with this address" : "Liên hệ với địa chỉ này",
@@ -289,7 +277,22 @@ OC.L10N.register(
     "Redirect" : "Chuyển hướng",
     "The link leads to %s" : "Liên kết dẫn đến %s",
     "Continue to %s" : "Tiếp tục %s",
+    "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
+    "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
     "Draft: " : "Bản nháp: ",
+    "Could not open mailbox" : "Không thể mở hộp thư",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Lập chỉ mục tin nhắn của bạn. Quá trình này có thể lâu hơn một chút đối với các hộp thư lớn.",
+    "Choose target mailbox" : "Chọn hộp thư mục tiêu",
+    "Show only subscribed mailboxes" : "Chỉ hiển thị các hộp thư đã đăng ký",
+    "Add mailbox" : "Thêm hộp thư",
+    "Show all subscribed mailboxes" : "Hiển thị tất cả các hộp thư đã đăng ký",
+    "Show all mailboxes" : "Hiển thị tất cả các hộp thư",
+    "The mailbox and all messages in it will be deleted." : "Hộp thư và tất cả thư trong đó sẽ bị xóa.",
+    "Delete mailbox" : "Xóa hộp thư",
+    "Delete mailbox {name}" : "Xóa hộp thư {name}",
+    "Mark all messages of this mailbox as read" : "Đánh dấu tất cả các thư của hộp thư này là đã đọc",
+    "Add submailbox" : "Thêm hộp thư con",
+    "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
     "Actions" : "Hành động"
 },
 "nplurals=1; plural=0;");
